@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2003 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -10,15 +10,16 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
  * 
- * $Id: simple.c,v 1.4.2.3 2003/01/27 01:38:26 jsquyres Exp $
+ *	$Id: simple.c,v 1.8 2002/11/23 04:06:58 jsquyres Exp $
  *
  */
 
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-#include "mpi.h"
+#include <mpi.h>
 
 #define SIZE (65536)
 
