@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	GDB
+ * $HEADER$
  *
- *	$Id: bfstate.c,v 6.7.2.1 2002/10/09 19:48:36 brbarret Exp $
+ * $Id: bfstate.c,v 6.14 2003/02/27 03:01:10 jsquyres Exp $
  *
  *	Function:	- prints Trollius buffer status
  */
@@ -22,10 +20,13 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/types.h>
+#include <sys/param.h>
+#include <netdb.h>
 #include <unistd.h>
 
 #include <args.h>
 #include <bfreq.h>
+#include <etc_misc.h>
 #include <events.h>
 #include <net.h>
 #include <priority.h>
@@ -34,8 +35,8 @@
 /*
  * local functions
  */
-static void		help();
-static void		bfstate();
+static void		help(void);
+static void		bfstate(int);
 
 /*
  * local variables
@@ -51,11 +52,7 @@ static char		*usage =
 
 
 int
-main(argc, argv)
-
-int   			argc;    
-char   			*argv[];
-
+main(int argc, char *argv[])
 {
 	int		n_index;		/* index of node entry */
 	int		nodeid;			/* value of node entry */
@@ -63,10 +60,12 @@ char   			*argv[];
 
 	/* Ensure that we are not root */
 
+#ifndef LAM_ALLOW_RUN_AS_ROOT
 	if (getuid() == 0 || geteuid() == 0) {
 	  show_help(NULL, "deny-root", NULL);
 	  exit(EACCES);
 	}
+#endif
 
 /*
  * Parse the command line.
@@ -105,7 +104,10 @@ char   			*argv[];
  * Attach to kernel.
  */
 	if (kinit(PRCMD)) {
-	  show_help(NULL, "no-lamd", "bfstate", NULL);
+	  char hostname[MAXHOSTNAMELEN];
+	  gethostname(hostname, MAXHOSTNAMELEN);
+
+	  show_help(NULL, "no-lamd", "bfstate", hostname, NULL);
 	  exit(errno);
 	}
 
@@ -142,10 +144,7 @@ char   			*argv[];
  *	Accepts:	- node identifier
  */
 static void
-bfstate(nodeid)
-
-int			nodeid;
-
+bfstate(int nodeid)
 {
 	int		size;		/* # of return blocks */
 	int		limit;		/* # of blocks to print */
@@ -210,8 +209,7 @@ int			nodeid;
  *	Function:	- prints helpful information on the bfstate command
  */
 static void
-help()
-
+help(void)
 {
 	printf("\nSynopsis:	bfstate [options] <nodes>\n");
 	printf("\nDescription:	Print information on message buffers.\n");
