@@ -1,38 +1,18 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
- * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	GDB
+ * $HEADER$
  *
- *	$Id: doom.c,v 6.8 2000/10/12 00:21:52 jsquyres Exp $
+ * $Id: doom.c,v 6.16 2003/02/27 15:49:51 jsquyres Exp $
  *
  *	Function:	- deliver signals to Trollius processes
  *			- process selection by index, pid or blocked event
@@ -45,9 +25,12 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
+#include <sys/param.h>
+#include <netdb.h>
 #include <unistd.h>
 
 #include <args.h>
+#include <etc_misc.h>
 #include <ksignal.h>
 #include <net.h>
 #include <portable.h>
@@ -59,9 +42,9 @@
 /*
  * local functions
  */
-static void		help();
-static void		doom_lnode();
-static void		doom_rnode();
+static void		help(void);
+static void		doom_lnode(int4);
+static void		doom_rnode(int4, int4);
 
 /*
  * local variables
@@ -71,11 +54,7 @@ static char		*usage =
 
 
 int
-main(argc, argv)
-
-int			argc;
-char			*argv[];
-
+main(int argc, char *argv[])
 {
 	int		n_index;	/* index of node entry */
 	int		n_flags;	/* extra node entry info */
@@ -84,10 +63,12 @@ char			*argv[];
 
 	/* Ensure that we are not root */
 
+#ifndef LAM_ALLOW_RUN_AS_ROOT
 	if (getuid() == 0 || geteuid() == 0) {
 	  show_help(NULL, "deny-root", NULL);
 	  exit(EACCES);
 	}
+#endif
 
 /*
  * Parse the command line.
@@ -128,7 +109,10 @@ char			*argv[];
  * Attach to kernel.
  */
 	if (kinit(PRDOOM)) {
-	  show_help(NULL, "no-lamd", "doom", NULL);
+	  char hostname[MAXHOSTNAMELEN];
+	  gethostname(hostname, MAXHOSTNAMELEN);
+
+	  show_help(NULL, "no-lamd", "doom", hostname, NULL);
 	  exit(errno);
 	}
 
@@ -180,10 +164,7 @@ char			*argv[];
  *	Accepts:	- signal number
  */
 static void
-doom_lnode(signo)
-
-int4			signo;
-
+doom_lnode(int4 signo)
 {
 	int		fnotpid = FALSE;	/* non pid selectors */
 	int		p_index;		/* index of process entry */
@@ -225,11 +206,7 @@ int4			signo;
  *			- signal number
  */
 static void
-doom_rnode(nodeid, signo)
-
-int4			nodeid;
-int4			signo;
-
+doom_rnode(int4 nodeid, int4 signo)
 {
 	int		p_index;		/* index of process entry */
 	int4		p_value;		/* value of process entry */
@@ -255,8 +232,7 @@ int4			signo;
  *	Function:	- prints helpful information on the doom command
  */
 static void
-help()
-
+help(void)
 {
 	printf("\nSynopsis:\tdoom [options] <nodes> [processes]\n");
 	printf("\nDescription:	Deliver a signal to LAM processes.\n");
