@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	VSD/GDB
+ * $HEADER$
  *
- *	$Id: filedr.c,v 6.4.2.1 2002/10/09 19:48:36 brbarret Exp $
+ * $Id: filedr.c,v 6.11 2003/01/13 19:15:06 jsquyres Exp $
  *
  *	Function:	- file system diagnostic tool (file doctor)
  *			- tests the remote file system functions
@@ -29,9 +27,13 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/param.h>
+#include <netdb.h>
+#include <unistd.h>
 
 #include <args.h>
-#include <debug.h>
+#include <etc_misc.h>
+#include <lamdebug.h>
 #include <freq.h>
 #include <net.h>
 #include <terror.h>
@@ -103,7 +105,10 @@ char			*argv[];
  * Attach to kernel.
  */
 	if (kinit(0)) {
-	  show_help(NULL, "no-lamd", "filedr", NULL);
+	  char hostname[MAXHOSTNAMELEN];
+	  gethostname(hostname, MAXHOSTNAMELEN);
+
+	  show_help(NULL, "no-lamd", "filedr", hostname, NULL);
 	  exit(0);
 	}
 /*
