@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD/GDB
+ * $HEADER$
  *
- *	$Id: ipcdr.c,v 6.4.2.1 2002/10/09 19:48:37 brbarret Exp $
+ * $Id: ipcdr.c,v 6.11 2003/02/16 06:57:48 brbarret Exp $
  * 
  *	Function:	- IPC diagnosis tool
  *			- sends or receives messages of given length
@@ -30,9 +28,13 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <sys/param.h>
+#include <netdb.h>
+#include <unistd.h>
 
 #include <args.h>
-#include <debug.h>
+#include <etc_misc.h>
+#include <lamdebug.h>
 #include <events.h>
 #include <net.h>
 #include <priority.h>
@@ -101,7 +103,10 @@ char			*argv[];
  * Attach to the kernel.
  */
 	if (kinit(PRCMD)) {
-	  show_help(NULL, "no-lamd", "ipcdr", NULL);
+	  char hostname[MAXHOSTNAMELEN];
+	  gethostname(hostname, MAXHOSTNAMELEN);
+
+	  show_help(NULL, "no-lamd", "ipcdr", hostname, NULL);
 	  exit(errno);
 	}
 
