@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: lamclean.c,v 6.14 2003/02/27 03:01:11 jsquyres Exp $
+ * $Id: lamclean.c,v 6.15 2003/07/06 01:28:49 jsquyres Exp $
  *
  *	Function:	- command to clean out several daemons on all nodes
  */
@@ -38,10 +38,6 @@
 #include <trreq.h>
 #include <typical.h>
 
-/*
- * local functions
- */
-static void		help(void);
 
 int
 main(int argc, char *argv[])
@@ -71,8 +67,8 @@ main(int argc, char *argv[])
 	}
 
 	if (opt_taken('h')) {
-		help();
-		exit(0);
+          show_help("lamclean", "usage", NULL);
+          exit(0);
 	}
 
 	fl_verbose = opt_taken('v');
@@ -179,17 +175,3 @@ main(int argc, char *argv[])
 	kexit(0);
 	return(0);
 }
-
-/*
- *	help
- *
- *	Function:	- prints helpful information on this command
- */
-static void
-help(void)
-{
-	printf("\nSynopsis:	lamclean [options]\n");
-	printf("\nDescription:	Clean up resources on all nodes.\n");
-	printf("\nOptions:	-h\t\tPrint this help message.\n");
-	printf("\t\t-v\t\tBe verbose.\n");
-}
