@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2003 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2006 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -157,7 +157,7 @@ main(int argc, char **argv)
  * Get the job environment.
  */
     if (asc_environment(0,
-	    ao_taken(ad, "x") ? ao_param(ad, "x", 0, 0) : 0, &env))
+	    ao_taken(ad, "x") ? ao_param(ad, "x", 0, 0) : NULL, &env))
 	lamfail("lamexec");
 /*
  * Build the job.
