@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: lamgrow.c,v 6.20 2003/04/28 22:17:52 jsquyres Exp $
+ * $Id: lamgrow.c,v 6.23 2003/08/06 01:06:00 jsquyres Exp $
  * 
  *	Function:	- adds a node to an existing LAM session
  */
@@ -49,6 +49,7 @@
 #include <laminternal.h>
 #include <kio.h>
 #include <mpisys.h>
+#include <sfh.h>
 
 
 /*
@@ -117,10 +118,12 @@ main(int argc, char *argv[])
   ao_setopt(ad, "sessionprefix", 0, 1, 0);
   ao_setopt(ad, "sessionsuffix", 0, 1, 0);
 
+  lam_ssi_base_open(ad);
   lam_ssi_base_ao_setup(ad);
 
   if (ao_parse(ad, &argc, argv)) {
     show_help("lamgrow", "usage", NULL);
+    lam_ssi_base_close();
     exit(EUSAGE);
   }
 
@@ -130,6 +133,7 @@ main(int argc, char *argv[])
     show_help("lamgrow", "usage", NULL);
     sfh_argv_free(main_argv);
     ao_free(ad);
+    lam_ssi_base_close();
     kexit(0);
   }
 
@@ -162,8 +166,10 @@ main(int argc, char *argv[])
      its own error message if necessary, so exiting upon failure is
      sufficient here. */
 
-  if (lam_ssi_base_ao_process_args(ad) != 0)
+  if (lam_ssi_base_ao_process_args(ad) != 0) {
+    lam_ssi_base_close();
     kexit(errno);
+  }
 
   /* Initialize LAM. */
 
@@ -172,6 +178,7 @@ main(int argc, char *argv[])
     hostname[MAXHOSTNAMELEN - 1] = '\0';
 
     show_help(NULL, "no-lamd", "lamgrow", hostname, NULL);
+    lam_ssi_base_close();
     kexit(LAM_EEXIT);
   }
 
@@ -182,6 +189,7 @@ main(int argc, char *argv[])
     lamfail("lamgrow (getnall)");
   if (nnodes == 0) {
     errno = EIMPOSSIBLE;
+    lam_ssi_base_close();
     lamfail("lamgrow (getnall)");
   }
 
@@ -190,6 +198,7 @@ main(int argc, char *argv[])
   pnodes = malloc((unsigned) nnodes * sizeof(int4));
   if (pnodes == 0) {
     show_help(NULL, "system-call-fail", "malloc", NULL);
+    lam_ssi_base_close();
     kexit(errno);
   }
   getall(pnodes, nnodes);
@@ -200,8 +209,10 @@ main(int argc, char *argv[])
 
   /* Start the remote process */
 
-  if (do_lamboot(ad, &new_in_addr, &new_nodeid, &lamnet, &nlamnet) != 0)
+  if (do_lamboot(ad, &new_in_addr, &new_nodeid, &lamnet, &nlamnet) != 0) {
+    lam_ssi_base_close();
     kexit(1);
+  }
 
   /* Inform all pre-existing nodes of the new addition(s) */
 
@@ -235,6 +246,7 @@ ensure_unique(int *pnodes, int nnodes)
   pps = malloc((unsigned) PMAX * sizeof(struct pstate));
   if (pps == 0) {
     show_help(NULL, "system-call-fail", "malloc", NULL);
+    lam_ssi_base_close();
     kexit(errno);
   }
 
@@ -252,6 +264,7 @@ ensure_unique(int *pnodes, int nnodes)
 	   (pnodes[i] != getnodeid()))) {
 	fprintf(stderr, "lamgrow: already running on n%d\n", pnodes[i]);
 	free(pps);
+        lam_ssi_base_close();
 	kexit(EUSAGE);
       }
     }
@@ -278,14 +291,19 @@ do_lamboot(OPT *ad, struct sockaddr_in *addr, int *new_nodeid,
 
   /* Open the boot SSI */
 
-  if (lam_ssi_boot_open(ad, LAM_SSI_BOOT_LOCATION_ROOT) != 0)
+  if (lam_ssi_boot_open(ad) != 0 ||
+      lam_ssi_boot_select(LAM_SSI_BOOT_LOCATION_ROOT) != 0) {
+    lam_ssi_base_close();
     exit(1);
+  }
 
   /* Let the boot SSI parse the command line.  Relevant errors will be
      displayed before returning from this function. */
 
-  if (lam_ssi_boot.lsba_parse_options(ad, 0) != 0)
+  if (lam_ssi_boot.lsba_parse_options(ad, 0) != 0) {
+    lam_ssi_base_close();
     exit(1);
+  }
 
   /* Let the boot SSI generate a list of nodes.  Relevant errors will
      be displayed before returning from this function. */
@@ -294,8 +312,10 @@ do_lamboot(OPT *ad, struct sockaddr_in *addr, int *new_nodeid,
     ao_intparam(ad, "n", 0, 0, &iorigin);
   else
     iorigin = -1;
-  if (lam_ssi_boot.lsba_allocate_nodes(plamnet, nlamnet, &iorigin) != 0)
+  if (lam_ssi_boot.lsba_allocate_nodes(plamnet, nlamnet, &iorigin) != 0) {
+    lam_ssi_base_close();
     exit(1);
+  }
   lamnet = *plamnet;
 
   /* Find the new node */
@@ -319,8 +339,10 @@ do_lamboot(OPT *ad, struct sockaddr_in *addr, int *new_nodeid,
   /* Let the boot SSI do an error check on the nodes.  Relevant errors
      will be displayed before returning from this function. */
 
-  if (lam_ssi_boot.lsba_verify_nodes(lamnet, *nlamnet) != 0)
+  if (lam_ssi_boot.lsba_verify_nodes(lamnet, *nlamnet) != 0) {
+    lam_ssi_base_close();
     exit(1);
+  }
 
   /* Setup the _kio struct */
 
@@ -329,13 +351,16 @@ do_lamboot(OPT *ad, struct sockaddr_in *addr, int *new_nodeid,
   /* Let the boot SSI prepare to boot.  Relevant errors will be
      displayed before returning from this function. */
 
-  if (lam_ssi_boot.lsba_prepare_boot() != 0)
+  if (lam_ssi_boot.lsba_prepare_boot() != 0) {
+    lam_ssi_base_close();
     exit(1);
+  }
 
   /* Clean up on interrupt */
 
   if (signal(SIGINT, bail) == SIG_ERR) {
     show_help(NULL, "system-call-fail", "signal", NULL);
+    lam_ssi_base_close();
     kexit(errno);
   }
 
@@ -373,6 +398,7 @@ do_lamboot(OPT *ad, struct sockaddr_in *addr, int *new_nodeid,
      this point) */
 
   lam_ssi_boot_close();
+  lam_ssi_base_close();
 
   return ret;
 }
@@ -467,7 +493,7 @@ add_links(OPT *ad, int *pnodes, int nnodes,
 static void
 bail(int sig)
 {
-  show_help("boot", "about-to-wipe", "lamgrow", NULL);
+  show_help("boot", "about-to-lamwipe", "lamgrow", NULL);
   if (fl_verbose || fl_debug) 
     fprintf(stderr, "lamgrow did NOT complete successfully\n");
   cleanup(NULL);
