@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2003 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2006 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -178,6 +178,7 @@ main(int argc, char **argv)
   int status;
   int errno_save;
   char **env;
+  sigset_t sigmask;
 #if LAM_WANT_IMPI
   char *impi_server = 0;
   int impi_argc = 0;
@@ -195,6 +196,28 @@ main(int argc, char **argv)
   }
 #endif
 
+  /* It is possible that this mpriun will have been exec()'ed from a
+     re-started mpirun.  In this case, due to a complicated series of
+     events (described below), this process may have a boatload of
+     signals blocked.  So we always unblock all signals here.  In the
+     non-restart case, it does nothing.  But in the restart case,
+     we're zeroing out the blocked signal mask so that we can receive
+     signals (like ctrl-C/SIGINT). 
+
+     This happens in BLCR, for example, because when mpirun is
+     checkpointed, its thread and signal callbacks are invoked.
+     Before invoking them, BLCR blocks the boatload of signals
+     (presumably to prevent race conditions).  The BLCR CRLAM SSI
+     module eventually invokes cr_checkpoint().  Upon restart, we
+     return from cr_checkpoint() and still have all the signals
+     blocked.  But we don't return from the signal handler -- we
+     simply exec() a new mpirun.  Blocked signals are inherited across
+     exec(), hence the new mpirun starts up with a whole boatload of
+     blocked signals.
+  */
+  sigemptyset(&sigmask);
+  sigprocmask(SIG_SETMASK, &sigmask, NULL);
+
   main_argv = sfh_argv_dup(argv);
 
 /*
@@ -255,7 +278,6 @@ main(int argc, char **argv)
   if (ao_parse(ad, &argc, argv))  {
     errno_save = errno;
     show_help("mpirun", "usage", NULL);
-    sfh_argv_free(argv);
     sfh_argv_free(main_argv);
     ao_free(ad);
     lam_ssi_base_close();
@@ -273,7 +295,6 @@ main(int argc, char **argv)
  */
   if (ao_taken(ad, "h")) {
     show_help("mpirun", "usage", NULL);
-    sfh_argv_free(argv);
     sfh_argv_free(main_argv);
     ao_free(ad);
     lam_ssi_base_close();
@@ -284,7 +305,6 @@ main(int argc, char **argv)
  */
   if (set_mode()) {
     errno_save = errno;
-    sfh_argv_free(argv);
     sfh_argv_free(main_argv);
     ao_free(ad);
     lam_ssi_base_close();
@@ -299,7 +319,6 @@ main(int argc, char **argv)
     errno_save = errno;
     gethostname(hostname, MAXHOSTNAMELEN);
     show_help(NULL, "no-lamd", "mpirun", hostname, NULL);
-    sfh_argv_free(argv);
     sfh_argv_free(main_argv);
     ao_free(ad);
     lam_ssi_base_close();
@@ -316,8 +335,7 @@ main(int argc, char **argv)
   env = 0;
   if (asc_environment(!ao_taken(ad, "nx"),
                       ao_taken(ad, "x") ? 
-                      ao_param(ad, "x", 0, 0) : 0, &env)) {
-    sfh_argv_free(argv);
+                      ao_param(ad, "x", 0, 0) : NULL, &env)) {
     sfh_argv_free(main_argv);
     ao_free(ad);
     lam_ssi_base_close();
@@ -332,13 +350,6 @@ main(int argc, char **argv)
     kexit(errno);
   }
 
-#if 0
-/* 
- * Why is this bad here?  Causes a *single* duplicate free...! 
- */
-  sfh_argv_free(argv);
-#endif
-
   checkpoint_world_n = world_n = al_count(app);
   world = (struct _gps *) malloc(world_n * sizeof(struct _gps));
   mpiworld = (struct _gps *) malloc(world_n * sizeof(struct _gps));
@@ -568,7 +579,6 @@ main(int argc, char **argv)
                                   checkpoint_world_n)) {
       /* The init function will have already showed the error.  So we
          can just kexit here */
-      sfh_argv_free(argv);
       sfh_argv_free(main_argv);
       ao_free(ad);
       lam_ssi_base_close();
