@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN/GDB/JRV/RBD
+ * $HEADER$
  *
- *	$Id: mpitask.c,v 6.9.2.1 2002/10/09 19:48:39 brbarret Exp $
+ * $Id: mpitask.c,v 6.16 2003/02/27 03:01:12 jsquyres Exp $
  * 
  *	Function:	- prints MPI task status information
  */
@@ -23,6 +21,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
+#include <sys/param.h>
+#include <netdb.h>
 #include <unistd.h>
 
 #include <all_opt.h>			/* argument parsing */
@@ -39,6 +39,7 @@
 #include <terror.h>			/* error codes */
 #include <typical.h>			/* commonly used constants */
 #include <t_types.h>			/* data conversion */
+#include <etc_misc.h>
 
 /*
  * local constants and macros
@@ -49,18 +50,25 @@
 /*
  * local functions
  */
-static void		state_node();
-static void		run_state_out();
-static void		br_state_out();
-static void		bs_state_out();
-static void		mpiblk_state_out();
-static void		unpack_fyi();
-static void		format_task();
-static void		cid_vout();
-static void		dtype_vout();
-static char		*mpiblktype();
-static void		parse_command_line();
-static void		help();
+static void		state_node(int4 nodeid);
+static void		run_state_out(int4 nodeid, struct pstate *pstat);
+static void		br_state_out(int4 nodeid, struct pstate *pstat);
+static void		bs_state_out(int4 nodeid, struct pstate *pstat);
+static void		mpiblk_state_out(int4 nodeid, struct pstate *pstat);
+static void             unpack_fyi(struct _fyiproc *fyi, int4 *psglobal, 
+				   int4 *pslocal, int4 *peernode, 
+				   int4 *peeridx, int4 *peerglobal, 
+				   int4 *peerlocal, int4 *rootnode, 
+				   int4 *rootidx, int4 *rootglobal, 
+				   int4 *rootlocal, int4 *cid, int4 *tag);
+static void		format_task(int4 nodeid, struct pstate *pstat, 
+				    int4 idx, int4 global, int4 local, 
+				    char *buf);
+static void		cid_vout(int4 nodeid, int4 pid, int4 cid);
+static void		dtype_vout(int4 nodeid, int4 pid, int4 dtype);
+static char		*mpiblktype(int4 type);
+static void		parse_command_line(int *pargc, char *argv[]);
+static void		help(void);
 
 /*
  * local variables
@@ -88,11 +96,7 @@ static char		*usage =
  *	main
  */
 int
-main(argc, argv)
-
-int			argc;
-char			*argv[];
-
+main(int argc, char *argv[])
 {
 	int4		n_index;		/* index of node entry */
 	int4		nodeid;			/* value of node entry */
@@ -102,17 +106,22 @@ char			*argv[];
 
 	/* Ensure that we are not root */
 
+#ifndef LAM_ALLOW_RUN_AS_ROOT
 	if (getuid() == 0 || geteuid() == 0) {
 	  show_help(NULL, "deny-root", NULL);
 	  exit(EACCES);
 	}
+#endif
 
 	parse_command_line(&argc, argv);
 /*
  * Attach to kernel.
  */
 	if (kinit(PRCMD)) {
-	  show_help(NULL, "no-lamd", "mpitask", NULL);
+	  char hostname[MAXHOSTNAMELEN];
+	  gethostname(hostname, MAXHOSTNAMELEN);
+
+	  show_help(NULL, "no-lamd", "mpitask", hostname, NULL);
 	  exit(LAM_EEXIT);
 	}
 
@@ -169,10 +178,7 @@ char			*argv[];
  *	Accepts:	- node identifier
  */
 static void
-state_node(nodeid)
-
-int4			nodeid;
-
+state_node(int4 nodeid)
 {
 	struct pstate	*pstat;			/* ptr process state */
 	int4		nprocs;			/* # processes returned */
@@ -223,11 +229,7 @@ int4			nodeid;
  *			- process state
  */
 static void
-run_state_out(nodeid, pstat)
-
-int4			nodeid;
-struct pstate		*pstat;
-
+run_state_out(int4 nodeid, struct pstate *pstat)
 {
 	struct _fyiproc	*fyi;		/* ptr to process FYI */
 /*
@@ -253,11 +255,7 @@ struct pstate		*pstat;
  *			- process state
  */
 static void
-br_state_out(nodeid, pstat)
-
-int4			nodeid;
-struct pstate		*pstat;
-
+br_state_out(int4 nodeid, struct pstate *pstat)
 {
 	struct _fyiproc	*fyi;		/* ptr process FYI */
 	
@@ -303,11 +301,7 @@ struct pstate		*pstat;
  *			- process state
  */
 static void
-bs_state_out(nodeid, pstat)
-
-int4			nodeid;
-struct pstate		*pstat;
-
+bs_state_out(int4 nodeid, struct pstate* pstat)
 {
 	struct _fyiproc	*fyi;		/* ptr to process FYI */
 	int4		event;		/* kernel state event */
@@ -362,11 +356,7 @@ struct pstate		*pstat;
  *			- process state
  */
 static void
-mpiblk_state_out(nodeid, pstat)
-
-int4			nodeid;
-struct pstate		*pstat;
-
+mpiblk_state_out(int4 nodeid, struct pstate *pstat)
 {
 	struct _fyiproc	*fyi;		/* ptr process FYI */
 	int4		psglobal;	/* process global rank */
@@ -602,23 +592,10 @@ struct pstate		*pstat;
  *			- ptrs to locations to unpack fyi into
  */
 static void
-unpack_fyi(fyi, psglobal, pslocal, peernode, peeridx, peerglobal, peerlocal,
-		rootnode, rootidx, rootglobal, rootlocal, cid, tag)
-
-struct _fyiproc		*fyi;
-int4			*psglobal;
-int4			*pslocal;
-int4			*peernode;	
-int4			*peeridx;	
-int4			*peerglobal;	
-int4			*peerlocal;	
-int4			*rootnode;	
-int4			*rootidx;	
-int4			*rootglobal;	
-int4			*rootlocal;	
-int4			*tag;		
-int4			*cid;		
-
+unpack_fyi(struct _fyiproc *fyi, int4 *psglobal, int4 *pslocal, 
+	   int4 *peernode, int4 *peeridx, int4 *peerglobal, int4 *peerlocal,
+	   int4 *rootnode, int4 *rootidx, int4 *rootglobal, int4 *rootlocal, 
+	   int4 *cid, int4 *tag)
 {
 	*psglobal = fyi->fyp_me >> 16;
 	*pslocal = fyi->fyp_me & 0xFFFF;
@@ -657,15 +634,8 @@ int4			*cid;
  *			- buffer to format into (returned value)
  */
 static void
-format_task(nodeid, pstat, idx, global, local, buf)
-
-int4			nodeid;
-struct pstate		*pstat;
-int4			idx;
-int4			global;
-int4			local;
-char			*buf;
-
+format_task(int4 nodeid, struct pstate *pstat, int4 idx, int4 global, 
+	    int4 local, char *buf)
 {
 	char		*p;		/* favourite pointer */
 
@@ -690,12 +660,7 @@ char			*buf;
  *			- context ID
  */
 static void
-cid_vout(nodeid, pid, cid)
-
-int4			nodeid;
-int4			pid;
-int4			cid;
-
+cid_vout(int4 nodeid, int4 pid, int4 cid)
 {
 	char		*fmt;
 	
@@ -717,12 +682,7 @@ int4			cid;
  *			- datatype label
  */
 static void
-dtype_vout(nodeid, pid, dtype)
-
-int4			nodeid;
-int4			pid;
-int4			dtype;
-
+dtype_vout(int4 nodeid, int4 pid, int4 dtype)
 {
 	char		*fmt;		/* formatting */
 	
@@ -747,10 +707,7 @@ int4			dtype;
  *	Returns:	- description string or NULL
  */
 static char *
-mpiblktype(type)
-
-int4			type;
-
+mpiblktype(int4 type)
 {
 	char		*desc;		/* full description */
 	char		*under;		/* position of first underscore */
@@ -771,11 +728,7 @@ int4			type;
  *			- argument vector
  */
 static void
-parse_command_line(pargc, argv)
-
-int			*pargc;
-char			*argv[];
-
+parse_command_line(int *pargc, char *argv[])
 {
         ad = ao_init();
         if (ad == 0) {
@@ -810,8 +763,7 @@ char			*argv[];
  *	Function:	- prints helpful information on the mpitask command
  */
 static void
-help()
-
+help(void)
 {
 	printf("\nSynopsis:	mpitask [options] [nodes] [processes]\n");
 	printf("\nDescription:	Print information on LAM MPI tasks.\n");
