@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	GDB
+ * $HEADER$
  *
- *	$Id: state.c,v 6.8.2.1 2002/10/09 19:48:40 brbarret Exp $
+ * $Id: state.c,v 6.12 2003/02/16 06:59:32 brbarret Exp $
  * 
  *	Function:	- prints Trollius process status information
  *			- processes can be selected by index or identifier
@@ -35,6 +33,7 @@
 
 #include <args.h>
 #include <blktype.h>
+#include <etc_misc.h>
 #include <events.h>			/* for EVSTOP and EVPAUSE */
 #include <ksignal.h>			/* signal constants */
 #include <net.h>			/* network constants */
