@@ -29,6 +29,7 @@
 #include <unistd.h>
 #include <sys/param.h>
 #include <sys/socket.h>
+#include <fcntl.h>
 
 #include <all_opt.h>
 #include <dl_inet.h>
@@ -89,6 +90,10 @@ di_bootcmd(struct dilink **pdilinks, struct diinfo **pdiinfo, int4 *pndil,
 		lampanic("dli_inet (sfh_sock_open_srv_inet_dgm)");
 	}
 
+        /* set socket to be close-on-exec */
+        if (fcntl(dli_sd, F_SETFD, 1) != 0)
+            lampanic("dli_inet: setting close-on-exec");
+
 	if (sfh_sock_set_buf_size(dli_sd, SFH_INET, SO_RCVBUF, 
 	    		sizeof(struct dlframe) * DOMAXPENDING)) {
 		lampanic("dli_inet (sfh_sock_set_buf_size)");
