@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2003 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2004 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -62,7 +62,7 @@ static int		initdlo(void);
 static void		di_ack(int4);
 static void		diqsetlink(struct nmsg *);
 static void		diqremlink(struct nmsg *);
-static void             initrouter(struct diinfo *pdiinfo);
+static void             initrouter(struct diinfo *pdiinfo, int4 mynode);
 static void		getmessage(void);
 
 
@@ -101,20 +101,24 @@ extern OPT* lam_daemon_optd;
 void (*(
 di_init(int argc, char *argv[])))()
 {
+        int4 mynode;
+
 	--argc;
 	++argv;
 /*
  * Boot from agent.  Get agent address and port from command line.
  */
 	if (ao_taken(lam_daemon_optd, "H")) {
-		dli_sd = di_bootagent(&dilinks, &diinfo, &ndil, argc, argv);
+		dli_sd = di_bootagent(&dilinks, &diinfo, &ndil, &mynode, 
+                                      argc, argv);
 	} else {
-		dli_sd = di_bootcmd(&dilinks, &diinfo, &ndil, argc, argv);
+		dli_sd = di_bootcmd(&dilinks, &diinfo, &ndil, &mynode,
+                                    argc, argv);
 	}
 /*
  * Build and send route information to router.
  */
-	initrouter(diinfo);
+	initrouter(diinfo, mynode);
 /*
  * Send the link info to dlo.
  */
@@ -383,7 +387,7 @@ initdlo(void)
  *                      - on each node
  */
 static void
-initrouter(struct diinfo *pdiinfo)
+initrouter(struct diinfo *pdiinfo, int4 mynodeid)
 {
 	int4		i;		/* favourite index */
 	int4		nnodes;		/* # nodes */
@@ -391,17 +395,10 @@ initrouter(struct diinfo *pdiinfo)
 	struct route	*p;		/* favourite pointer */
 	struct dilink	*pdil;		/* link ptr */
 	struct diinfo	*pdii;		/* link ptr */
-	int4		mynodeid;	/* my node ID */
 	int4		origin;		/* origin node ID */
 /*
- * Determine local and origin node IDs.
+ * Determine and origin node ID
  */
-	if (ao_taken(lam_daemon_optd, "n")) {
-		ao_intparam(lam_daemon_optd, "n", 0, 0, &mynodeid);
-	} else {
-		mynodeid = 0;
-	}
-
 	if (ao_taken(lam_daemon_optd, "o")) {
 		ao_intparam(lam_daemon_optd, "o", 0, 0, &origin);
 	} else {
