@@ -26,6 +26,7 @@
 #include <sys/types.h>
 #include <sys/time.h>
 #include <sys/socket.h>
+#include <fcntl.h>
 
 #include <lamdebug.h>
 #include <dl_inet.h>
@@ -107,6 +108,10 @@ do_init()))()
 	if ((do_sd = sfh_sock_open_clt_inet_dgm()) < 0)
 			lampanic("dlo_inet (sfh_sock_open_clt_inet_dgm)");
 
+        /* set socket to be close-on-exec */
+        if (fcntl(do_sd, F_SETFD, 1) != 0)
+            lampanic("dlo_inet: setting close-on-exec");
+
 	nvclose = 0;
 	dos_nfull = 0;
 	getnodeid();
