@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- *	$Id: filed.c,v 6.6 2003/03/10 03:22:05 jsquyres Exp $
+ *	$Id: filed.c,v 6.7 2003/06/30 05:19:30 brbarret Exp $
  * 
  *	Function:	- filed mainline 
  *			- remote daemon
@@ -89,6 +89,7 @@ extern void		fqftrunc();
 extern void		fqdup();
 extern void		fqmkdir();
 extern void		fqsystem();
+extern void		fqrename(struct freq* fq);
 extern void		fqrmdir();
 extern void		fqunlink();
 extern void		fqincr();
@@ -128,6 +129,7 @@ static void		(*(fqfunc[FQMAX]))() = {
 			fqftrunc,
 			fqopenfd,
 			fqpathfind,
+			fqrename,
 			fqf77read,
 			fqf77back,
 			};
