@@ -210,12 +210,19 @@ diediedie(int client_pid)
  * Setup tkill to kill us
  */
   sfh_argv_add(&pathc, &pathv, "");
-  sfh_argv_add(&pathc, &pathv, "$PATH");
   sfh_argv_add(&pathc, &pathv, "$LAMHOME/bin");
   sfh_argv_add(&pathc, &pathv, LAM_BINDIR);
 
-  tkillpath = sfh_path_findv(fname, pathv, R_OK, environ);
+  tkillpath = sfh_path_findv(fname, pathv, X_OK, environ);
   sfh_argv_free(pathv);
+
+  if (NULL == tkillpath) {
+      tkillpath = sfh_path_env_find(fname, X_OK);
+
+      if (NULL == tkillpath) {
+          exit(1);
+      }
+  }
   sfh_argv_add(&argc, &argv, tkillpath);
 
   if (ao_taken(lam_daemon_optd, "d")) {
