@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -10,8 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *
- * $Id: client.c,v 1.25.2.2 2002/10/09 19:48:44 brbarret Exp $
+ * $Id: client.c,v 1.31 2003/04/27 14:03:33 jsquyres Exp $
  */
 
 #include <lam_config.h>
@@ -34,13 +35,12 @@
 #include <portable.h>
 #include <typical.h>
 #include <mpisys.h>
-#include <rpi_c2c.h>
-#include <rpi_tcp.h>
-#include <debug.h>
+#include <lamdebug.h>
 #include <impi-defs.h>
 #include <impi.h>
 #include <impid.h>
 #include <sfh.h>
+#include <etc_misc.h>
 
 #ifdef DEBUG
 #undef DEBUG
@@ -298,9 +298,9 @@ do_cmd_auth_key(IMPI_Server_auth *sauth)
     DBUG("Got IMPI_AUTH_KEY\n");
   DBUG("I got the auth key of: %s\n", key);
 
-#if HAVE_ATOLL
+#if LAM_HAVE_ATOLL
   auth.key = atoll(key);
-#elif HAVE_STRTOLL
+#elif LAM_HAVE_STRTOLL
   auth.key = strtoll(key, (char**) 0, 10);
 #else
 
@@ -442,7 +442,7 @@ do_cmd_coll(IMPI_Uint4 my_ipaddress, int my_dance_port)
 
   /* IMPI_C_TAGUB label */
 
-  data = LAM_MAXTAG;
+  data = lam_mpi_max_tag;
   LAM_SWAP_ENDIAN(&data, sizeof(data));
   DBUG("IMPI_C_TAGUB\n");
   if (do_coll_label(IMPI_C_TAGUB, &data, 4, 1, nclients, 0) == LAMERROR)
