@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2003 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2004 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: dance.c,v 1.26.2.1 2003/10/11 19:04:00 brbarret Exp $
+ * $Id: dance.c,v 1.27 2003/10/11 19:15:34 brbarret Exp $
  *
  *	Function:	- network functions for connecting up all
  *                        the IMPI clients
@@ -113,9 +113,15 @@ impi_get_my_ipaddress()
   int loopback;
   struct in_addr* server_node;
   struct hostent* server_struct;
+  const char *hostname;
 
-  if (gethostname(my_hostname, LAM_MAXHOSTNAMELEN) != 0)
-    lamfail("LAM IMPI client: gethostname failed");
+  hostname = getenv("IMPI_HOST_NAME");
+  if (hostname != NULL && strlen(hostname) > 0) {
+    strncpy (my_hostname, hostname, LAM_MAXHOSTNAMELEN);
+  } else {
+    if (gethostname(my_hostname, LAM_MAXHOSTNAMELEN) != 0)
+      lamfail("LAM IMPI client: gethostname failed");
+  }
   if ((server_struct = gethostbyname(my_hostname)) == NULL)
     lamfail("LAM IMPI client: gethostbyname failed");
 
