@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -10,8 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *
- * $Id: host.cc,v 1.31.2.1 2002/10/09 19:48:44 brbarret Exp $
+ * $Id: host.cc,v 1.34 2003/02/04 17:51:30 jsquyres Exp $
  *
  *	Function:	- all actions triggered by messages coming in from 
  *                        IMPI hosts
@@ -26,32 +27,35 @@
 #include <new>
 #endif
 
-#include <iostream.h>
 #include <stdio.h>
 #include <unistd.h>
 
+#include <iostream>
 #include <set>
 
 #include <impi-defs.h>
 #include <impi.h>
 #include <impid-cc.h>
 #include <hostack_mgmt.h>
-#include <debug-cc.h>
+#include <lamdebug-cc.h>
 #include <mpisys.h>
 #include <packet_mgmt.h>
 
 #include <laminternal.h>
 
 using std::set;
+using std::cerr;
+using std::endl;
 typedef set<int>  host_pkfini_rcvd_set;
 
+
 /*
  * private variables
  */
-
 static host_pkfini_rcvd_set pkfini_set;
 static Debug debug(false);
 
+
 /*
  * local functions
  */
@@ -68,6 +72,7 @@ static void process_fini(IMPI_host *h, struct pollfd *poll_fd);
 static char* read_packet_data(IMPI_Uint4 len, IMPI_Uint8 msglen, int fd, 
 			      IMPI_Uint4* bytes_read);
 
+
 /*
  *	impi_host_init
  *
