@@ -82,13 +82,15 @@ int
 main(int argc, char *argv[])
 {
   MPI_Comm       parent_inter;
+  extern char *lam_ssi_coll_base_override;
 
   /* Parse the command line arguments */
 
   parse_args(argc, argv);
   DBUG("LAM IMPI client starting: client rank %d, server %s, port %d\n",
        my_client_rank, server_name, server_port);
-  
+
+  lam_ssi_coll_base_override = "lam_basic";
   MPI_Init(&argc, &argv);
   DBUG("Finished MPI_Init in impid\n");
 
