@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: pqdetach.c,v 6.17.2.2 2004/01/02 00:19:34 jsquyres Exp $
+ * $Id: pqdetach.c,v 6.20 2004/01/02 00:19:27 jsquyres Exp $
  * 
  *	Function:	- OTB kenyad
  *			- attaches and detaches kenya processes
@@ -36,6 +36,7 @@
 #include <terror.h>
 #include <typical.h>
 #include <lamdebug.h>
+#include <sfh.h>
 
 /*
  * external variables
@@ -259,7 +260,7 @@ pqattach()
 
 		if (pq.pq_name[0] != '\0') {
 			pattach->p_argc = 1;
-			pattach->p_argv = argvbreak(pq.pq_name, 0xa);
+			pattach->p_argv = sfh_argv_break(pq.pq_name, 0xa);
 			if (pattach->p_argv == 0)
 					lampanic("kenyad (pack_argv)");
 		}
