@@ -247,6 +247,11 @@ kio_init()
         chdir(orig_dir);
         free(orig_dir);
         free(addr_dir);
+
+        /* set socket to be close-on-exec */
+	if (fcntl(sd_kernel, F_SETFD, 1) != 0)
+            lampanic("lamd kernel: setting close-on-exec");
+
 /*
  * Open the kill record file.
  */
