@@ -36,6 +36,7 @@
 #include <laminternal.h>
 #include <lamdebug.h>
 #include <etc_misc.h>
+#include <priority.h>
 
 /*
  * external functions
@@ -247,7 +248,11 @@ kqattach(struct kproc *pclient, struct kreq *pkq)
 		pclient->kp_state = KSREADY;
 		kpinsert(&pready, pclient);
 
-		kkillwrite(pkq->kq_pid);
+                /* see note in kkill.c about the lamhalt special
+                   priority */
+                if (pclient->kp_priority != PRLAMHALT) {
+                    kkillwrite(pkq->kq_pid);
+                }
 	}
 
 	reply.kr_reply = 0;
