@@ -10,14 +10,16 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *	Ohio Trollius
  *	Copyright 1995 The Ohio State University
  *	GDB
  *
  *	$Log: di_wait.int.c,v $
- *	Revision 6.5.2.1  2002/10/09 19:48:46  brbarret
- *	* Updated license header to match current requirements
- *	
+ *	Revision 6.6  2002/10/09 20:56:47  brbarret
+ *	* Update tree to match the latest, greatest, license for LAM/MPI.  And this
+ *	  one is even done properly :)
+ *
  *	Revision 6.5  2000/02/08 10:29:33  jsquyres
  *	Duh.  Remove the mail headers before trying to compile...
  *	
