@@ -10,14 +10,16 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *	Ohio Trollius
  *	Copyright 1994 The Ohio State University
  *	GDB
  *
  *	$Log: kexit.c,v $
- *	Revision 6.2.2.1  2002/10/09 19:48:46  brbarret
- *	* Updated license header to match current requirements
- *	
+ *	Revision 6.3  2002/10/09 20:56:47  brbarret
+ *	* Update tree to match the latest, greatest, license for LAM/MPI.  And this
+ *	  one is even done properly :)
+ *
  *	Revision 6.2  1999/06/12 17:11:36  kmeyer1
  *	added copyright
  *	
