@@ -1,38 +1,21 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
- * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *	Ohio Trollius
  *	Copyright 1995 The Ohio State University
  *	GDB
  *
- *	$Id: loadd.c,v 6.4 2000/11/02 07:20:52 jsquyres Exp $
+ *	$Id: loadd.c,v 6.7 2002/10/09 20:56:50 brbarret Exp $
  *
  *	Function	- load daemon
  *			- loads local file onto remote node
@@ -46,7 +29,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 
-#include <debug.h>
+#include <lamdebug.h>
 #include <events.h>
 #include <flatreq.h>
 #include <ksignal.h>
@@ -131,8 +114,8 @@ loadd()))()
 	int		fdesc;		/* local file descriptor */
 	char		*fullname;	/* full path filename */
 
-	db(("loadd: dest_node: %X src_node: %X file: %s\n",
-			lq->lq_dest_node, lq->lq_src_node, fname));
+	lamlog("loadd: dest_node: %X src_node: %X file: %s\n",
+	       lq->lq_dest_node, lq->lq_src_node, fname);
 /*
  * Locate the file.
  */
