@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2006 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -11,11 +11,6 @@
  * LAM/MPI source distribution.
  * 
  * $HEADER$
- *      Ohio Trollius
- *      Copyright 1997 The Ohio State University
- *      GDB/NJN
- *
- *      $Id: trbuf.c,v 1.4 2002/10/09 20:56:52 brbarret Exp $
  * 
  *	Function:	- functions that manipulate the trace buffer
  *			  data structure
@@ -210,7 +205,7 @@ struct trreq		*ptrq;
 		}
 
 		ptrl = (ptrq->trq_lnum == TRANYLIST) ?
-				ah_next(trbhd, ptrl) : 0;
+				ah_next(trbhd, ptrl) : NULL;
 	}
 
 	trsendr(ptrq, &reply, (char *) 0, 0);
@@ -242,7 +237,7 @@ struct trreq		*ptrq;
 		}
 
 		ptrl = (ptrq->trq_lnum == TRANYLIST) ?
-				ah_next(trbhd, ptrl) : 0;
+				ah_next(trbhd, ptrl) : NULL;
 	}
 }
 
@@ -282,7 +277,7 @@ struct trreq		*ptrq;
 		}
 
 		ptrl = (ptrq->trq_lnum == TRANYLIST) ?
-				ah_next(trbhd, ptrl) : 0;
+				ah_next(trbhd, ptrl) : NULL;
 	}
 }
 
