@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: tping.c,v 6.21 2003/02/27 03:01:15 jsquyres Exp $
+ * $Id: tping.c,v 6.22 2004/03/06 20:37:21 jsquyres Exp $
  *
  *	Function:	- bounces a message off the echo daemon
  */
@@ -79,7 +79,6 @@ main(int argc, char *argv[])
 	double		ttotal;			/* total timing */
 	double		ttrip;			/* message trip timing */
 	int		*indices;		/* array of indices */
-	int		*nodes;			/* array of nodes */
 	int4		nlinks;                 /* total number of links */
 	struct dolink	*links;                 /* from ldogetlinks */
 
@@ -182,27 +181,31 @@ main(int argc, char *argv[])
 /*
  * Use that as an upper bound to malloc the nodes array
  */
-	nodes = (int*) malloc(sizeof(int) * nlinks);
-	if (nodes == 0)
-	  kexit(errno);
 	indices = (int*) malloc(sizeof(int) * nlinks);
 	if (indices == 0) {
-	  free(nodes);
 	  kexit(errno);
 	}
 	for (i = 0; i < nlinks; i++)
-	  nodes[i] = indices[i] = -1;
+	  indices[i] = -1;
 /*
  * Now fill the indices array with the indices of unique nodes
  */
 	localnodes = 0;
 	do {
-	  if (nodes[nodeid] == -1)
-	    indices[n_index] = 1;
-	  nodes[nodeid] = 1;
+          if ((nodeid >= nlinks) || ((nodeid < 0) && (nodeid != LOCAL))) {
+            fprintf(stderr, "tping: invalid node %s\n", nid_fmt(nodeid));
+            kexit(EUSAGE);
+          }
 
-	  if (nodeid == getnodeid())
-	    localnodes = 1;
+          if ((nodeid == getnodeid()) || (nodeid == LOCAL)) {
+            localnodes = 1;
+            i = getnodeid();
+          } else {
+            i = nodeid;
+          }
+
+          if (indices[i] == -1)
+            indices[i] = n_index;
 
 	  nid_get(&n_index, &nodeid, &n_flags);
 	} while (n_index != first_index);
@@ -217,9 +220,10 @@ main(int argc, char *argv[])
  */
 		nnodes = 0;
 		do {
-		  if (indices[n_index] == 1) {
+                  i = (nodeid != LOCAL) ? nodeid : getnodeid();
+                  if (indices[i] == n_index) {
 			prevnode = nodeid;
-			if (nodeid != getnodeid())
+			if (i != getnodeid())
 			  ++nnodes;
 /*
  * Ping the node.
@@ -283,7 +287,6 @@ main(int argc, char *argv[])
   	if (inbuf) {
   		free(inbuf);
   	}
-  	free(nodes);
   	free(indices);
 /*
  * Print out the final statistics.
