@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_hfs_done.c,v 1.1.1.1 1999/03/17 18:52:53 jsquyres Exp $    
+ *   $Id: ad_hfs_done.c,v 1.3 2003/03/25 22:39:55 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -10,6 +11,9 @@
 int ADIOI_HFS_ReadDone(ADIO_Request *request, ADIO_Status *status, int *error_code)  
 {
     if (*request != ADIO_REQUEST_NULL) {
+#ifdef HAVE_STATUS_SET_BYTES
+	MPIR_Status_set_bytes(status, (*request)->datatype, (*request)->nbytes);
+#endif
 	(*request)->fd->async_count--;
 	ADIOI_Free_request((ADIOI_Req_node *) (*request));
 	*request = ADIO_REQUEST_NULL;
@@ -17,9 +21,6 @@ int ADIOI_HFS_ReadDone(ADIO_Request *request, ADIO_Status *status, int *error_co
 
     *error_code = MPI_SUCCESS;
     return 1;
-
-/* status to be filled */
-
 }
 
 
