@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_nfs.h,v 1.1.1.1 2000/09/06 20:01:56 jsquyres Exp $    
+ *   $Id: ad_nfs.h,v 1.3 2003/03/25 22:39:58 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -18,6 +19,9 @@
 #include <sys/asynch.h>
 #else
 #include <aio.h>
+#ifdef NEEDS_ADIOCB_T
+typedef struct adiocb adiocb_t;
+#endif
 #endif
 #endif
 
