@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_nfs_read.c,v 1.1.1.1 2000/09/06 20:01:56 jsquyres Exp $    
+ *   $Id: ad_nfs_read.c,v 1.3 2003/03/25 22:39:59 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -110,7 +111,7 @@ void ADIOI_NFS_ReadStrided(ADIO_File fd, void *buf, int count,
     MPI_Aint filetype_extent, buftype_extent; 
     int buf_count, buftype_is_contig, filetype_is_contig;
     ADIO_Offset userbuf_off;
-    ADIO_Offset off, req_off, disp, end_offset, readbuf_off, start_off;
+    ADIO_Offset off, req_off, disp, end_offset=0, readbuf_off, start_off;
     char *readbuf, *tmp_buf, *value;
     int flag, st_frd_size, st_n_filetypes, readbuf_len;
     int new_brd_size, new_frd_size, err_flag=0, info_flag, max_bufsize;
