@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_nfs_setsh.c,v 1.1.1.1 2000/09/06 20:01:56 jsquyres Exp $    
+ *   $Id: ad_nfs_setsh.c,v 1.3 2003/03/25 22:40:00 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -20,7 +21,7 @@ void ADIOI_NFS_Set_shared_fp(ADIO_File fd, ADIO_Offset offset, int *error_code)
 
     if (fd->shared_fp_fd == ADIO_FILE_NULL) {
 	MPI_Comm_dup(MPI_COMM_SELF, &dupcommself);
-	fd->shared_fp_fd = ADIO_Open(dupcommself, fd->shared_fp_fname, 
+	fd->shared_fp_fd = ADIO_Open(MPI_COMM_SELF, dupcommself, fd->shared_fp_fname, 
              fd->file_system, ADIO_CREATE | ADIO_RDWR | ADIO_DELETE_ON_CLOSE, 
              0, MPI_BYTE, MPI_BYTE, M_ASYNC, MPI_INFO_NULL, 
              ADIO_PERM_NULL, error_code);
