@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_pfs.h,v 1.1.1.1 2000/09/06 20:01:56 jsquyres Exp $    
+ *   $Id: ad_pfs.h,v 1.3 2003/03/25 22:40:05 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -20,6 +21,7 @@
 
 #ifdef tflops
 #define lseek eseek
+#define _gopen(n,m,i,p) open(n,m,p)
 #endif
 
 #endif
