@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_pfs_flush.c,v 1.1.1.1 2000/09/06 20:01:56 jsquyres Exp $    
+ *   $Id: ad_pfs_flush.c,v 1.3 2003/03/25 22:40:06 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -10,6 +11,9 @@
 void ADIOI_PFS_Flush(ADIO_File fd, int *error_code)
 {
     int err, np_total, np_comm;
+#ifndef PRINT_ERR_MSG
+    static char myname[] = "ADIOI_PFS_FLUSH";
+#endif
 
 /* fsync is not actually needed in PFS, because it uses something
    called fast-path I/O. However, it doesn't do any harm either. */
