@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_pfs_iwrite.c,v 1.1.1.1 2000/09/06 20:01:56 jsquyres Exp $    
+ *   $Id: ad_pfs_iwrite.c,v 1.3 2003/03/25 22:40:06 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -7,7 +8,8 @@
 
 #include "ad_pfs.h"
 
-void ADIOI_PFS_IwriteContig(ADIO_File fd, void *buf, int len, int file_ptr_type,
+void ADIOI_PFS_IwriteContig(ADIO_File fd, void *buf, int count, 
+                MPI_Datatype datatype, int file_ptr_type,
                 ADIO_Offset offset, ADIO_Request *request, int *error_code)  
 {
     long *id_sys;
