@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_piofs.h,v 1.1.1.1 1999/03/17 18:52:44 jsquyres Exp $    
+ *   $Id: ad_piofs.h,v 1.3 2003/03/25 22:40:09 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -8,8 +9,8 @@
 /* contains definitions, declarations, and macros specific to the
    implementation of ADIO on PIOFS */
 
-#ifndef __AD_PIOFS_INCLUDE
-#define __AD_PIOFS_INCLUDE
+#ifndef AD_PIOFS_INCLUDE
+#define AD_PIOFS_INCLUDE
 
 #include <unistd.h>
 #include <sys/uio.h>
