@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_pvfs_flush.c,v 1.1.1.1 2000/09/06 20:01:55 jsquyres Exp $    
+ *   $Id: ad_pvfs_flush.c,v 1.3 2003/03/25 22:40:13 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -10,6 +11,9 @@
 void ADIOI_PVFS_Flush(ADIO_File fd, int *error_code)
 {
     int err;
+#ifndef PRINT_ERR_MSG
+    static char myname[] = "ADIOI_PVFS_FLUSH";
+#endif
 
     err = pvfs_fsync(fd->fd_sys);
 
