@@ -1,12 +1,13 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_sfs.h,v 1.1.1.1 1999/03/17 18:52:52 jsquyres Exp $    
+ *   $Id: ad_sfs.h,v 1.3 2003/03/25 22:40:16 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
  */
 
-#ifndef __AD_SFS_INCLUDE
-#define __AD_SFS_INCLUDE
+#ifndef AD_SFS_INCLUDE
+#define AD_SFS_INCLUDE
 
 #include <unistd.h>
 #include <sys/types.h>
