@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_ufs_open.c,v 1.1.1.1 1999/03/17 18:52:50 jsquyres Exp $    
+ *   $Id: ad_ufs_open.c,v 1.3 2003/03/25 22:40:31 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -10,6 +11,9 @@
 void ADIOI_UFS_Open(ADIO_File fd, int *error_code)
 {
     int perm, old_mask, amode;
+#ifndef PRINT_ERR_MSG
+    static char myname[] = "ADIOI_UFS_OPEN";
+#endif
 
     if (fd->perm == ADIO_PERM_NULL) {
 	old_mask = umask(022);
@@ -32,12 +36,17 @@ void ADIOI_UFS_Open(ADIO_File fd, int *error_code)
 
     fd->fd_sys = open(fd->filename, amode, perm);
 
-    if ((fd->fd_sys != -1) && (fd->access_mode & ADIO_APPEND)) {
+    if ((fd->fd_sys != -1) && (fd->access_mode & ADIO_APPEND))
 	fd->fp_ind = fd->fp_sys_posn = lseek(fd->fd_sys, 0, SEEK_END);
-	MPI_Barrier(fd->comm);
-	/* the barrier ensures that no process races ahead and modifies
-           the file size before all processes have opened the file. */
-    }
 
+#ifdef PRINT_ERR_MSG
     *error_code = (fd->fd_sys == -1) ? MPI_ERR_UNKNOWN : MPI_SUCCESS;
+#else
+    if (fd->fd_sys == -1) {
+	*error_code = MPIR_Err_setmsg(MPI_ERR_IO, MPIR_ADIO_ERROR,
+			      myname, "I/O Error", "%s", strerror(errno));
+	ADIOI_Error(ADIO_FILE_NULL, *error_code, myname);	    
+    }
+    else *error_code = MPI_SUCCESS;
+#endif
 }
