@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_ufs_write.c,v 1.1.1.1 2000/09/06 20:01:55 jsquyres Exp $    
+ *   $Id: ad_ufs_write.c,v 1.3 2003/03/25 22:40:32 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -35,7 +36,7 @@ void ADIOI_UFS_WriteContig(ADIO_File fd, void *buf, int count,
     }
 
 #ifdef HAVE_STATUS_SET_BYTES
-    if (err != -1) MPIR_Status_set_bytes(status, datatype, err);
+    if (err != -1 && status) MPIR_Status_set_bytes(status, datatype, err);
 #endif
 
 #ifdef PRINT_ERR_MSG
