@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_delete.c,v 1.1.1.1 2000/09/06 20:01:55 jsquyres Exp $    
+ *   $Id: ad_delete.c,v 1.3 2003/03/25 22:40:37 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -7,13 +8,16 @@
 
 #include "adio.h"
 
-void ADIO_Delete(char *filename, int *error_code)
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
+void ADIOI_GEN_Delete(char *filename, int *error_code)
 {
     int err;
 #ifndef PRINT_ERR_MSG
-    static char myname[] = "ADIO_DELETE";
+    static char myname[] = "ADIOI_GEN_DELETE";
 #endif
-
     err = unlink(filename);
 #ifdef PRINT_ERR_MSG
     *error_code = (err == 0) ? MPI_SUCCESS : MPI_ERR_UNKNOWN;
