@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_flush.c,v 1.1.1.1 2000/09/06 20:01:55 jsquyres Exp $    
+ *   $Id: ad_flush.c,v 1.3 2003/03/25 22:40:37 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -7,15 +8,17 @@
 
 #include "adio.h"
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
 void ADIOI_GEN_Flush(ADIO_File fd, int *error_code)
 {
     int err;
 #ifndef PRINT_ERR_MSG
     static char myname[] = "ADIOI_GEN_FLUSH";
 #endif
-
     err = fsync(fd->fd_sys);
-
 #ifdef PRINT_ERR_MSG
     *error_code = (err == 0) ? MPI_SUCCESS : MPI_ERR_UNKNOWN;
 #else
