@@ -12,7 +12,7 @@
 
 #include "adio.h"
 
-#if (defined(HPUX) || defined(SPPUX) || defined(IRIX) || defined(SOLARIS) || defined(AIX) || defined(DEC) || defined(CRAY))
+#if (defined(HPUX) || defined(SPPUX) || defined(IRIX) || defined(SOLARIS) || defined(AIX) || defined(DEC) || defined(CRAY) || __NetBSD_Version__ >= 300000000)
 #include <sys/statvfs.h>
 #endif
 #ifdef LINUX
@@ -45,6 +45,11 @@
 #include <unistd.h>
 #endif
 
+#if __NetBSD_Version__ >= 300000000
+#define statfs statvfs
+#define ROMIO_HAVE_STATFS_F_FSTYPENAME 1
+#endif
+
 #ifndef ROMIO_NTFS
 static void ADIO_FileSysType_parentdir(char *filename, char **dirnamep);
 #endif
