@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_seek.c,v 1.3 2001/01/23 13:56:56 jsquyres Exp $    
+ *   $Id: ad_seek.c,v 1.5 2003/03/25 22:40:39 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -19,6 +20,10 @@
 #define lseek eseek
 #endif
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
 ADIO_Offset ADIOI_GEN_SeekIndividual(ADIO_File fd, ADIO_Offset offset, 
 		      int whence, int *error_code)
 {
