@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: ad_write_coll.c,v 1.3 2001/01/23 13:54:11 jsquyres Exp $    
+ *   $Id: ad_write_coll.c,v 1.5 2003/03/25 22:40:39 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -13,8 +14,7 @@
 
 /* prototypes of functions used for collective writes only. */
 static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
-                         datatype, int nprocs, int
-                         nprocs_for_coll, int myrank, ADIOI_Access
+                         datatype, int nprocs, int myrank, ADIOI_Access
                          *others_req, ADIO_Offset *offset_list,
                          int *len_list, int contig_access_count, ADIO_Offset
                          min_st_offset, ADIO_Offset fd_size,
@@ -26,7 +26,7 @@ static void ADIOI_W_Exchange_data(ADIO_File fd, void *buf, char *write_buf,
                          int *recv_size, ADIO_Offset off, int size,
                          int *count, int *start_pos, int *partial_recv, 
                          int *sent_to_proc, int nprocs, 
-                         int nprocs_for_coll, int myrank, int
+                         int myrank, int
                          buftype_is_contig, int contig_access_count,
                          ADIO_Offset min_st_offset, ADIO_Offset fd_size,
                          ADIO_Offset *fd_start, ADIO_Offset *fd_end, 
@@ -37,7 +37,7 @@ static void ADIOI_W_Exchange_data(ADIO_File fd, void *buf, char *write_buf,
 static void ADIOI_Fill_send_buffer(ADIO_File fd, void *buf, ADIOI_Flatlist_node                           *flat_buf, char **send_buf, ADIO_Offset 
                            *offset_list, int *len_list, int *send_size, 
                            MPI_Request *requests, int *sent_to_proc, 
-                           int nprocs_for_coll, int myrank, 
+                           int nprocs, int myrank, 
                            int contig_access_count, ADIO_Offset
                            min_st_offset, ADIO_Offset fd_size,
                            ADIO_Offset *fd_start, ADIO_Offset *fd_end, 
@@ -69,16 +69,12 @@ void ADIOI_GEN_WriteStridedColl(ADIO_File fd, void *buf, int count,
        whose request lies in this process's file domain. */
 
     int i, filetype_is_contig, nprocs, nprocs_for_coll, myrank;
-    int *len_list, contig_access_count, interleave_count, info_flag;
+    int *len_list, contig_access_count, interleave_count;
     int buftype_is_contig, *buf_idx;
     int *count_my_req_per_proc, count_my_req_procs, count_others_req_procs;
     ADIO_Offset *offset_list, start_offset, end_offset, *st_offsets, orig_fp;
     ADIO_Offset *fd_start, *fd_end, fd_size, min_st_offset, *end_offsets;
     ADIO_Offset off;
-    char *value;
-#ifdef HAVE_STATUS_SET_BYTES
-    int bufsize, size;
-#endif
 
 #ifdef PROFILE
 	MPE_Log_event(13, 0, "start computation");
@@ -88,13 +84,9 @@ void ADIOI_GEN_WriteStridedColl(ADIO_File fd, void *buf, int count,
     MPI_Comm_rank(fd->comm, &myrank);
 
 /* the number of processes that actually perform I/O, nprocs_for_coll,
-   is stored in the info object. it is either = nprocs or a smaller number
-   set by the user. get it from info. */
-
-    value = (char *) ADIOI_Malloc((MPI_MAX_INFO_VAL+1)*sizeof(char));
-    MPI_Info_get(fd->info, "cb_nodes", MPI_MAX_INFO_VAL, value, &info_flag);
-    nprocs_for_coll = atoi(value);
-    ADIOI_Free(value);
+ * is stored in the hints off the ADIO_File structure
+ */
+    nprocs_for_coll = fd->hints->cb_nodes;
 
 
 /* For this process's request, calculate the list of offsets and
@@ -129,8 +121,10 @@ void ADIOI_GEN_WriteStridedColl(ADIO_File fd, void *buf, int count,
 
     ADIOI_Datatype_iscontig(datatype, &buftype_is_contig);
 
-    if (!interleave_count) {
-/* no interleaving of requests. noncollective is good enough */
+    if (fd->hints->cb_write == ADIOI_HINT_DISABLE ||
+	(!interleave_count && (fd->hints->cb_write == ADIOI_HINT_AUTO)))
+    {
+	/* use independent accesses */
 	ADIOI_Free(offset_list);
 	ADIOI_Free(len_list);
 	ADIOI_Free(st_offsets);
@@ -164,11 +158,11 @@ void ADIOI_GEN_WriteStridedColl(ADIO_File fd, void *buf, int count,
 
 
 /* calculate what portions of the access requests of this process are
-   located in the file domains of other processes */
+   located in what file domains */
 
-    ADIOI_Calc_my_req(offset_list, len_list, contig_access_count,
+    ADIOI_Calc_my_req(fd, offset_list, len_list, contig_access_count,
 			   min_st_offset, fd_start, fd_end, fd_size,
-			   nprocs, nprocs_for_coll, &count_my_req_procs, 
+			   nprocs, &count_my_req_procs, 
 			   &count_my_req_per_proc, &my_req,
                            &buf_idx); 
 
@@ -181,11 +175,11 @@ void ADIOI_GEN_WriteStridedColl(ADIO_File fd, void *buf, int count,
 
     ADIOI_Calc_others_req(fd, count_my_req_procs, 
 			       count_my_req_per_proc, my_req, 
-			       nprocs, myrank, nprocs_for_coll,
+			       nprocs, myrank,
 			       &count_others_req_procs, &others_req); 
 
     ADIOI_Free(count_my_req_per_proc);
-    for (i=0; i<nprocs_for_coll; i++) {
+    for (i=0; i < nprocs; i++) {
 	if (my_req[i].count) {
 	    ADIOI_Free(my_req[i].offsets);
 	    ADIOI_Free(my_req[i].lens);
@@ -194,7 +188,7 @@ void ADIOI_GEN_WriteStridedColl(ADIO_File fd, void *buf, int count,
     ADIOI_Free(my_req);
 
 /* exchange data and write in sizes of no more than coll_bufsize. */
-    ADIOI_Exch_and_write(fd, buf, datatype, nprocs, nprocs_for_coll, myrank,
+    ADIOI_Exch_and_write(fd, buf, datatype, nprocs, myrank,
                         others_req, offset_list,
 			len_list, contig_access_count, min_st_offset,
 			fd_size, fd_start, fd_end, buf_idx, error_code);
@@ -221,9 +215,13 @@ void ADIOI_GEN_WriteStridedColl(ADIO_File fd, void *buf, int count,
     ADIOI_Free(fd_end);
 
 #ifdef HAVE_STATUS_SET_BYTES
-    MPI_Type_size(datatype, &size);
-    bufsize = size * count;
-    MPIR_Status_set_bytes(status, datatype, bufsize);
+    if (status) {
+      int bufsize, size;
+      /* Don't set status if it isn't needed */
+      MPI_Type_size(datatype, &size);
+      bufsize = size * count;
+      MPIR_Status_set_bytes(status, datatype, bufsize);
+    }
 /* This is a temporary way of filling in status. The right way is to 
    keep track of how much data was actually written during collective I/O. */
 #endif
@@ -234,8 +232,7 @@ void ADIOI_GEN_WriteStridedColl(ADIO_File fd, void *buf, int count,
 
 
 static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
-			 datatype, int nprocs, int
-			 nprocs_for_coll, int myrank, ADIOI_Access
+			 datatype, int nprocs, int myrank, ADIOI_Access
 			 *others_req, ADIO_Offset *offset_list,
 			 int *len_list, int contig_access_count, ADIO_Offset
                          min_st_offset, ADIO_Offset fd_size,
@@ -251,9 +248,9 @@ static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
    array to a file, where each local array is 8Mbytes, requiring
    at least another 8Mbytes of temp space is unacceptable. */
 
-    int hole, i, j, m, size, ntimes, max_ntimes, buftype_is_contig;
+    int hole, i, j, m, size=0, ntimes, max_ntimes, buftype_is_contig;
     ADIO_Offset st_loc=-1, end_loc=-1, off, done, req_off;
-    char *write_buf;
+    char *write_buf=NULL;
     int *curr_offlen_ptr, *count, *send_size, req_len, *recv_size;
     int *partial_recv, *sent_to_proc, *start_pos, flag;
     int *send_buf_idx, *curr_to_proc, *done_to_proc;
@@ -277,7 +274,7 @@ static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
     ADIOI_Free(value);
 
 
-    for (i=0; i<nprocs; i++) {
+    for (i=0; i < nprocs; i++) {
 	if (others_req[i].count) {
 	    st_loc = others_req[i].offsets[0];
 	    end_loc = others_req[i].offsets[0];
@@ -285,8 +282,8 @@ static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
 	}
     }
 
-    for (i=0; i<nprocs; i++)
-	for (j=0; j<others_req[i].count; j++) {
+    for (i=0; i < nprocs; i++)
+	for (j=0; j < others_req[i].count; j++) {
 	    st_loc = ADIOI_MIN(st_loc, others_req[i].offsets[j]);
 	    end_loc = ADIOI_MAX(end_loc, (others_req[i].offsets[j]
 				       + others_req[i].lens[j] - 1));
@@ -322,13 +319,13 @@ static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
     recv_size = (int *) ADIOI_Malloc(nprocs*sizeof(int));
     /* total size of data to be recd. from each proc. in an iteration.*/
 
-    sent_to_proc = (int *) ADIOI_Calloc(nprocs_for_coll, sizeof(int));
+    sent_to_proc = (int *) ADIOI_Calloc(nprocs, sizeof(int));
     /* amount of data sent to each proc so far. Used in
        ADIOI_Fill_send_buffer. initialized to 0 here. */
 
-    send_buf_idx = (int *) ADIOI_Malloc(nprocs_for_coll*sizeof(int));
-    curr_to_proc = (int *) ADIOI_Malloc(nprocs_for_coll*sizeof(int));
-    done_to_proc = (int *) ADIOI_Malloc(nprocs_for_coll*sizeof(int));
+    send_buf_idx = (int *) ADIOI_Malloc(nprocs*sizeof(int));
+    curr_to_proc = (int *) ADIOI_Malloc(nprocs*sizeof(int));
+    done_to_proc = (int *) ADIOI_Malloc(nprocs*sizeof(int));
     /* Above three are used in ADIOI_Fill_send_buffer*/
 
     start_pos = (int *) ADIOI_Malloc(nprocs*sizeof(int));
@@ -361,7 +358,7 @@ static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
 	MPE_Log_event(14, 0, "end computation");
 #endif
 
-    for (m=0; m<ntimes; m++) {
+    for (m=0; m < ntimes; m++) {
        /* go through all others_req and check which will be satisfied
           by the current write */
 
@@ -382,15 +379,14 @@ static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
 #ifdef PROFILE
 	MPE_Log_event(13, 0, "start computation");
 #endif
-	for (i=0; i<nprocs; i++) count[i] = recv_size[i] = 0;
+	for (i=0; i < nprocs; i++) count[i] = recv_size[i] = 0;
 
 	size = (int) (ADIOI_MIN(coll_bufsize, end_loc-st_loc+1-done)); 
 
-	for (i=0; i<nprocs; i++) {
+	for (i=0; i < nprocs; i++) {
 	    if (others_req[i].count) {
 		start_pos[i] = curr_offlen_ptr[i];
-		for (j=curr_offlen_ptr[i]; j<others_req[i].count;
-		     j++) {
+		for (j=curr_offlen_ptr[i]; j<others_req[i].count; j++) {
 		    if (partial_recv[i]) {
 			/* this request may have been partially
 			   satisfied in the previous iteration. */
@@ -411,8 +407,8 @@ static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
 			count[i]++;
 			MPI_Address(write_buf+req_off-off, 
                                &(others_req[i].mem_ptrs[j]));
-			recv_size[i] += ADIOI_MIN(off + size - 
-						  req_off, req_len);
+			recv_size[i] += (int)(ADIOI_MIN(off + (ADIO_Offset)size - 
+						  req_off, req_len));
 
 			if (off+size-req_off < req_len) {
 			    partial_recv[i] = (int) (off + size - req_off);
@@ -438,7 +434,7 @@ static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
 	ADIOI_W_Exchange_data(fd, buf, write_buf, flat_buf, offset_list, 
                             len_list, send_size, recv_size, off, size, count, 
                             start_pos, partial_recv, 
-                            sent_to_proc, nprocs, nprocs_for_coll, myrank, 
+                            sent_to_proc, nprocs, myrank, 
 			    buftype_is_contig, contig_access_count,
 			    min_st_offset, fd_size, fd_start, fd_end,
 			    others_req, send_buf_idx, curr_to_proc,
@@ -472,7 +468,7 @@ static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
 	ADIOI_W_Exchange_data(fd, buf, write_buf, flat_buf, offset_list, 
                             len_list, send_size, recv_size, off, size, count, 
                             start_pos, partial_recv, 
-                            sent_to_proc, nprocs, nprocs_for_coll, myrank, 
+                            sent_to_proc, nprocs, myrank, 
 			    buftype_is_contig, contig_access_count,
 			    min_st_offset, fd_size, fd_start, fd_end,
 			    others_req, send_buf_idx, 
@@ -504,7 +500,7 @@ static void ADIOI_W_Exchange_data(ADIO_File fd, void *buf, char *write_buf,
                          int *recv_size, ADIO_Offset off, int size,
 			 int *count, int *start_pos, int *partial_recv,
 			 int *sent_to_proc, int nprocs, 
-			 int nprocs_for_coll, int myrank, int
+			 int myrank, int
 			 buftype_is_contig, int contig_access_count,
 			 ADIO_Offset min_st_offset, ADIO_Offset fd_size,
 			 ADIO_Offset *fd_start, ADIO_Offset *fd_end, 
@@ -515,7 +511,7 @@ static void ADIOI_W_Exchange_data(ADIO_File fd, void *buf, char *write_buf,
                          int *error_code)
 {
     int i, j, k, *tmp_len, nprocs_recv, nprocs_send, err;
-    char **send_buf; 
+    char **send_buf = NULL; 
     MPI_Request *requests;
     MPI_Datatype *recv_types;
     MPI_Status *statuses, status;
@@ -599,7 +595,7 @@ static void ADIOI_W_Exchange_data(ADIO_File fd, void *buf, char *write_buf,
 #ifdef PRINT_ERR_MSG
 		FPRINTF(stderr, "ADIOI_GEN_WriteStridedColl: ROMIO tries to optimize this access by doing a read-modify-write, but is unable to read the file. Please give the file read permission and open it with MPI_MODE_RDWR.\n");
 		*error_code = err;
-		MPI_Abort(MPI_COMM_WORLD, 1);
+                MPI_Abort(MPI_COMM_WORLD, 1);
 #else
 		*error_code = MPIR_Err_setmsg(MPI_ERR_IO, MPIR_READ_PERM,
 			      myname, (char *) 0, (char *) 0);
@@ -611,7 +607,7 @@ static void ADIOI_W_Exchange_data(ADIO_File fd, void *buf, char *write_buf,
     }
 
     nprocs_send = 0;
-    for (i=0; i<nprocs_for_coll; i++) if (send_size[i]) nprocs_send++;
+    for (i=0; i < nprocs; i++) if (send_size[i]) nprocs_send++;
 
     requests = (MPI_Request *) 	
 	ADIOI_Malloc((nprocs_send+nprocs_recv+1)*sizeof(MPI_Request)); 
@@ -632,7 +628,7 @@ static void ADIOI_W_Exchange_data(ADIO_File fd, void *buf, char *write_buf,
 
     if (buftype_is_contig) {
 	j = 0;
-	for (i=0; i<nprocs_for_coll; i++) 
+	for (i=0; i < nprocs; i++) 
 	    if (send_size[i]) {
 		MPI_Isend(((char *) buf) + buf_idx[i], send_size[i], 
   		            MPI_BYTE, i,  myrank+i+100*iter, fd->comm, 
@@ -643,15 +639,15 @@ static void ADIOI_W_Exchange_data(ADIO_File fd, void *buf, char *write_buf,
     }
     else if (nprocs_send) {
 	/* buftype is not contig */
-	send_buf = (char **) ADIOI_Malloc(nprocs_for_coll*sizeof(char*));
-	for (i=0; i<nprocs_for_coll; i++) 
+	send_buf = (char **) ADIOI_Malloc(nprocs*sizeof(char*));
+	for (i=0; i < nprocs; i++) 
 	    if (send_size[i]) 
 		send_buf[i] = (char *) ADIOI_Malloc(send_size[i]);
 
 	ADIOI_Fill_send_buffer(fd, buf, flat_buf, send_buf,
                            offset_list, len_list, send_size, 
 			   requests+nprocs_recv,
-                           sent_to_proc, nprocs_for_coll, myrank, 
+                           sent_to_proc, nprocs, myrank, 
                            contig_access_count,
                            min_st_offset, fd_size, fd_start, fd_end, 
                            send_buf_idx, curr_to_proc, done_to_proc, iter,
@@ -676,7 +672,7 @@ static void ADIOI_W_Exchange_data(ADIO_File fd, void *buf, char *write_buf,
     ADIOI_Free(statuses);
     ADIOI_Free(requests);
     if (!buftype_is_contig && nprocs_send) {
-	for (i=0; i<nprocs_for_coll; i++) 
+	for (i=0; i < nprocs; i++) 
 	    if (send_size[i]) ADIOI_Free(send_buf[i]);
 	ADIOI_Free(send_buf);
     }
@@ -735,7 +731,7 @@ static void ADIOI_Fill_send_buffer(ADIO_File fd, void *buf, ADIOI_Flatlist_node
                            *flat_buf, char **send_buf, ADIO_Offset 
                            *offset_list, int *len_list, int *send_size, 
                            MPI_Request *requests, int *sent_to_proc, 
-                           int nprocs_for_coll, int myrank, 
+                           int nprocs, int myrank, 
                            int contig_access_count, 
                            ADIO_Offset min_st_offset, ADIO_Offset fd_size,
                            ADIO_Offset *fd_start, ADIO_Offset *fd_end, 
@@ -745,9 +741,9 @@ static void ADIOI_Fill_send_buffer(ADIO_File fd, void *buf, ADIOI_Flatlist_node
 {
 /* this function is only called if buftype is not contig */
 
-    int i, p, flat_buf_idx, rem_len, size;
-    int flat_buf_sz, len, buf_incr, size_in_buf, jj, n_buftypes;
-    ADIO_Offset off, user_buf_idx;
+    int i, p, flat_buf_idx, size;
+    int flat_buf_sz, buf_incr, size_in_buf, jj, n_buftypes;
+    ADIO_Offset off, len, rem_len, user_buf_idx;
 
 /*  curr_to_proc[p] = amount of data sent to proc. p that has already
     been accounted for so far
@@ -756,7 +752,7 @@ static void ADIOI_Fill_send_buffer(ADIO_File fd, void *buf, ADIOI_Flatlist_node
     user_buf_idx = current location in user buffer 
     send_buf_idx[p] = current location in send_buf of proc. p  */
 
-    for (i=0; i<nprocs_for_coll; i++) {
+    for (i=0; i < nprocs; i++) {
 	send_buf_idx[i] = curr_to_proc[i] = 0;
 	done_to_proc[i] = sent_to_proc[i];
     }
@@ -772,66 +768,38 @@ static void ADIOI_Fill_send_buffer(ADIO_File fd, void *buf, ADIOI_Flatlist_node
 	                 flattened buf */
 
     for (i=0; i<contig_access_count; i++) { 
-	p = (int) ((offset_list[i]-min_st_offset+fd_size)/fd_size - 1);
-	off = offset_list[i];
-	len = (int) (((off+len_list[i]-1) <= fd_end[p]) ? 
-		len_list[i] : (fd_end[p] - off + 1));
+	off     = offset_list[i];
+	rem_len = (ADIO_Offset) len_list[i];
 
-	if (send_buf_idx[p] < send_size[p]) {
-	    if (curr_to_proc[p]+len > done_to_proc[p]) {
-		if (done_to_proc[p] > curr_to_proc[p]) {
-		    size = ADIOI_MIN(curr_to_proc[p]+len-done_to_proc[p], 
-                                         send_size[p]-send_buf_idx[p]);
-		    buf_incr = done_to_proc[p] - curr_to_proc[p];
-		    ADIOI_BUF_INCR
-		    buf_incr = curr_to_proc[p] + len - done_to_proc[p];
-		    curr_to_proc[p] = done_to_proc[p] + size;
-		    ADIOI_BUF_COPY
-		}
-		else {
-		    size = ADIOI_MIN(len, send_size[p]-send_buf_idx[p]); 
-		    buf_incr = len;
-		    curr_to_proc[p] += size;
-		    ADIOI_BUF_COPY
-		}
-		if (send_buf_idx[p] == send_size[p]) {
-		    MPI_Isend(send_buf[p], send_size[p], MPI_BYTE, p, 
-                                myrank+p+100*iter, fd->comm, requests+jj);
-		    jj++;
-		}
-	    }
-	    else {
-		curr_to_proc[p] += len;
-		buf_incr = len;
-		ADIOI_BUF_INCR
-	    }
-	}
-	else {
-	    buf_incr = len;
-	    ADIOI_BUF_INCR
-	}
-            
 	/*this request may span the file domains of more than one process*/
-	rem_len = len_list[i] - len;
 	while (rem_len != 0) {
-	    p++;
-	    off = fd_start[p];
-	    len = (int) (((off+rem_len-1) <= fd_end[p]) ? rem_len : 
-		    (fd_end[p] - off + 1));
+	    len = rem_len;
+	    /* NOTE: len value is modified by ADIOI_Calc_aggregator() to be no
+	     * longer than the single region that processor "p" is responsible
+	     * for.
+	     */
+	    p = ADIOI_Calc_aggregator(fd,
+				      off,
+				      min_st_offset,
+				      &len,
+				      fd_size,
+				      fd_start,
+				      fd_end);
+
 	    if (send_buf_idx[p] < send_size[p]) {
 		if (curr_to_proc[p]+len > done_to_proc[p]) {
 		    if (done_to_proc[p] > curr_to_proc[p]) {
-			size = ADIOI_MIN(curr_to_proc[p] + len - 
+			size = (int)ADIOI_MIN(curr_to_proc[p] + len - 
                                 done_to_proc[p], send_size[p]-send_buf_idx[p]);
 			buf_incr = done_to_proc[p] - curr_to_proc[p];
 			ADIOI_BUF_INCR
-		        buf_incr = curr_to_proc[p] + len - done_to_proc[p];
+		        buf_incr = (int)(curr_to_proc[p] + len - done_to_proc[p]);
 			curr_to_proc[p] = done_to_proc[p] + size;
 		        ADIOI_BUF_COPY
 		    }
 		    else {
-			size = ADIOI_MIN(len,send_size[p]-send_buf_idx[p]);
-			buf_incr = len;
+			size = (int)ADIOI_MIN(len,send_size[p]-send_buf_idx[p]);
+			buf_incr = (int)len;
 			curr_to_proc[p] += size;
 			ADIOI_BUF_COPY
 		    }
@@ -842,19 +810,20 @@ static void ADIOI_Fill_send_buffer(ADIO_File fd, void *buf, ADIOI_Flatlist_node
 		    }
 		}
 		else {
-		    curr_to_proc[p] += len;
-		    buf_incr = len;
+		    curr_to_proc[p] += (int)len;
+		    buf_incr = (int)len;
 		    ADIOI_BUF_INCR
 		}
 	    }
 	    else {
-		buf_incr = len;
+		buf_incr = (int)len;
 		ADIOI_BUF_INCR
             }
+	    off     += len;
 	    rem_len -= len;
 	}
     }
-    for (i=0; i<nprocs_for_coll; i++) 
+    for (i=0; i < nprocs; i++) 
 	if (send_size[i]) sent_to_proc[i] = curr_to_proc[i];
 }
 
@@ -895,7 +864,7 @@ static void ADIOI_Heap_merge(ADIOI_Access *others_req, int *count,
            removed the recursion so that there are no function calls.
            Function calls are too expensive. */
 	k = i;
-	done = 0;
+  	done = 0;
 	while (!done) {
 	    l = 2*(k+1) - 1;
 	    r = 2*(k+1);
@@ -977,8 +946,8 @@ static void ADIOI_Heap_merge(ADIOI_Access *others_req, int *count,
 	    
 		k = smallest;
 	    }
-	    else
-	      done = 1;
+	    else 
+              done = 1;
 	}
     }
     ADIOI_Free(a);
