@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: flatten.c,v 1.1.1.1 2000/09/06 20:01:55 jsquyres Exp $    
+ *   $Id: flatten.c,v 1.3 2003/03/25 22:40:40 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -11,6 +12,7 @@
 #include "mpisgi2.h"
 #endif
 
+void ADIOI_Optimize_flattened(ADIOI_Flatlist_node *flat_type);
 
 /* flatten datatype and add it to Flatlist */
 void ADIOI_Flatten_datatype(MPI_Datatype datatype)
@@ -57,6 +59,7 @@ void ADIOI_Flatten_datatype(MPI_Datatype datatype)
 
     ADIOI_Flatten(datatype, flat, 0, &curr_index);
 
+    ADIOI_Optimize_flattened(flat);
 /* debug */
     /*FPRINTF(stderr, "blens: ");
     for (i=0; i<flat->count; i++) 
@@ -73,7 +76,7 @@ void ADIOI_Flatten_datatype(MPI_Datatype datatype)
 void ADIOI_Flatten(MPI_Datatype datatype, ADIOI_Flatlist_node *flat, 
 		  ADIO_Offset st_offset, int *curr_index)  
 {
-    int i, j, m, n, num, basic_num, prev_index;
+    int i, j, k, m, n, num, basic_num, prev_index;
     int top_count, combiner, old_combiner, old_is_contig;
     int old_size, nints, nadds, ntypes, old_nints, old_nadds, old_ntypes;
     MPI_Aint old_extent;
@@ -88,6 +91,15 @@ void ADIOI_Flatten(MPI_Datatype datatype, ADIOI_Flatlist_node *flat,
     MPI_Type_get_contents(datatype, nints, nadds, ntypes, ints, adds, types);
 
     switch (combiner) {
+#ifdef MPICH2
+    case MPI_COMBINER_DUP:
+        MPI_Type_get_envelope(types[0], &old_nints, &old_nadds,
+			      &old_ntypes, &old_combiner); 
+        ADIOI_Datatype_iscontig(types[0], &old_is_contig);
+	if ((old_combiner != MPI_COMBINER_NAMED) && (!old_is_contig))
+            ADIOI_Flatten(types[0], flat, st_offset, curr_index);
+        break;
+#endif
     case MPI_COMBINER_CONTIGUOUS:
 	top_count = ints[0];
         MPI_Type_get_envelope(types[0], &old_nints, &old_nadds,
@@ -276,16 +288,18 @@ void ADIOI_Flatten(MPI_Datatype datatype, ADIOI_Flatlist_node *flat,
 		prev_index = *curr_index;
 		for (m=0; m<basic_num; m++) {
 		    flat->indices[j] = flat->indices[j-num] + 
-                              ints[top_count+1+i]*old_extent;
+                        (ints[top_count+1+i]-ints[top_count+i])*old_extent;
 		    flat->blocklens[j] = flat->blocklens[j-num];
 		    j++;
 		}
 		*curr_index = j;
 		for (m=1; m<ints[1+i]; m++) {
-		    flat->indices[j] = flat->indices[j-basic_num] + old_extent;
-		    flat->blocklens[j] = flat->blocklens[j-basic_num];
-		    j++;
-		}
+                    for (k=0; k<basic_num; k++) {
+                        flat->indices[j] = flat->indices[j-basic_num] + old_extent;
+                        flat->blocklens[j] = flat->blocklens[j-basic_num];
+                        j++;
+                    }
+                }
 		*curr_index = j;
 	    }
 	}
@@ -335,15 +349,17 @@ void ADIOI_Flatten(MPI_Datatype datatype, ADIOI_Flatlist_node *flat,
 		num = *curr_index - prev_index;
 		prev_index = *curr_index;
 		for (m=0; m<basic_num; m++) {
-		    flat->indices[j] = flat->indices[j-num] + adds[i];
+		    flat->indices[j] = flat->indices[j-num] + adds[i] - adds[i-1];
 		    flat->blocklens[j] = flat->blocklens[j-num];
 		    j++;
 		}
 		*curr_index = j;
 		for (m=1; m<ints[1+i]; m++) {
-		    flat->indices[j] = flat->indices[j-basic_num] + old_extent;
-		    flat->blocklens[j] = flat->blocklens[j-basic_num];
+                    for (k=0; k<basic_num; k++) {
+                        flat->indices[j] = flat->indices[j-basic_num] + old_extent;
+                        flat->blocklens[j] = flat->blocklens[j-basic_num];
 		    j++;
+                    }
 		}
 		*curr_index = j;
 	    }
@@ -430,6 +446,16 @@ int ADIOI_Count_contiguous_blocks(MPI_Datatype datatype, int *curr_index)
     MPI_Type_get_contents(datatype, nints, nadds, ntypes, ints, adds, types);
 
     switch (combiner) {
+#ifdef MPICH2
+    case MPI_COMBINER_DUP:
+        MPI_Type_get_envelope(types[0], &old_nints, &old_nadds,
+                              &old_ntypes, &old_combiner); 
+	ADIOI_Datatype_iscontig(types[0], &old_is_contig);
+	if ((old_combiner != MPI_COMBINER_NAMED) && (!old_is_contig))
+	    count = ADIOI_Count_contiguous_blocks(types[0], curr_index);
+	else count = 1;
+        break;
+#endif
     case MPI_COMBINER_CONTIGUOUS:
         top_count = ints[0];
         MPI_Type_get_envelope(types[0], &old_nints, &old_nadds,
@@ -569,6 +595,57 @@ int ADIOI_Count_contiguous_blocks(MPI_Datatype datatype, int *curr_index)
 }
 
 
+/****************************************************************/
+
+/* ADIOI_Optimize_flattened()
+ *
+ * Scans the blocks of a flattened type and merges adjacent blocks 
+ * together, resulting in a shorter blocklist (and thus fewer
+ * contiguous operations).
+ */
+void ADIOI_Optimize_flattened(ADIOI_Flatlist_node *flat_type)
+{
+    int i, j, opt_blocks;
+    int *opt_blocklens;
+    ADIO_Offset *opt_indices;
+    
+    opt_blocks = 1;
+    
+    /* save number of noncontiguous blocks in opt_blocks */
+    for (i=0; i < (flat_type->count - 1); i++) {
+        if ((flat_type->indices[i] + flat_type->blocklens[i] !=
+	     flat_type->indices[i + 1]))
+	    opt_blocks++;
+    }
+
+    /* if we can't reduce the number of blocks, quit now */
+    if (opt_blocks == flat_type->count) return;
+
+    opt_blocklens = (int *) ADIOI_Malloc(opt_blocks * sizeof(int));
+    opt_indices = (ADIO_Offset *)ADIOI_Malloc(opt_blocks*sizeof(ADIO_Offset));
+
+    /* fill in new blocklists */
+    opt_blocklens[0] = flat_type->blocklens[0];
+    opt_indices[0] = flat_type->indices[0];
+    j = 0;
+    for (i=0; i < (flat_type->count - 1); i++) {
+	if ((flat_type->indices[i] + flat_type->blocklens[i] ==
+	     flat_type->indices[i + 1]))
+	    opt_blocklens[j] += flat_type->blocklens[i + 1];
+	else {
+	    j++;
+	    opt_indices[j] = flat_type->indices[i + 1];
+	    opt_blocklens[j] = flat_type->blocklens[i + 1];
+	} 
+    }
+    flat_type->count = opt_blocks;
+    ADIOI_Free(flat_type->blocklens);
+    ADIOI_Free(flat_type->indices);
+    flat_type->blocklens = opt_blocklens;
+    flat_type->indices = opt_indices;
+    return;
+}
+
 /****************************************************************/
 
 void ADIOI_Delete_flattened(MPI_Datatype datatype)
