@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: adioi.h,v 1.1.1.1 2000/09/06 20:01:54 jsquyres Exp $    
+ *   $Id: adioi.h,v 1.3 2003/03/25 22:40:44 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -49,6 +50,43 @@ typedef struct ADIOI_Malloc_req_ptr {
     struct ADIOI_Malloc_req_ptr *next;
 } ADIOI_Malloc_req;
 
+/* used to keep track of hint/info values.
+ * Note that there are a lot of int-sized values in here...they are
+ * used as int-sized entities other places as well.  This would be a 
+ * problem on 32-bit systems using > 2GB files in some cases...
+ */
+struct ADIOI_Hints_struct {
+    int initialized;
+    int cb_read;
+    int cb_write;
+    int cb_nodes;
+    int cb_buffer_size;
+    int ds_read;
+    int ds_write;
+    int no_indep_rw;
+    int ind_rd_buffer_size;
+    int ind_wr_buffer_size;
+    char *cb_config_list;
+    int *ranklist;
+    union {
+	    struct {
+		    int listio_read;
+		    int listio_write;
+	    } pvfs;
+    } fs_hints;
+
+};
+
+/* Values for use with cb_read, cb_write, ds_read, and ds_write 
+ * and some fs-specific hints
+   (IBM xlc, Compaq Tru64 compilers object to a comma after the last item)
+   (that's just wrong)
+ */
+enum {
+    ADIOI_HINT_AUTO    = 0,
+    ADIOI_HINT_ENABLE  = 1,
+    ADIOI_HINT_DISABLE = 2
+};
 
 /* flattened datatypes. Each datatype is stored as a node of a
    globally accessible linked list. Once attribute caching on a
@@ -113,6 +151,7 @@ struct ADIOI_Fns_struct {
 	       ADIO_Offset offset, ADIO_Request *request, int *error_code);
     void (*ADIOI_xxx_Flush) (ADIO_File fd, int *error_code); 
     void (*ADIOI_xxx_Resize) (ADIO_File fd, ADIO_Offset size, int *error_code);
+    void (*ADIOI_xxx_Delete) (char *filename, int *error_code);
 };
 
 /* optypes for ADIO_RequestD */
@@ -136,6 +175,8 @@ struct ADIOI_Fns_struct {
        with file locking. If buffer size is large there is more contention 
        for locks. */
 #define ADIOI_IND_WR_BUFFER_SIZE_DFLT     "524288"
+    /* use one process per processor name by default */
+#define ADIOI_CB_CONFIG_LIST_DFLT "*:1"
 
 
 /* some of the ADIO functions are macro-replaced */
@@ -200,6 +241,9 @@ struct ADIOI_Fns_struct {
 #define ADIO_Resize(fd,size,error_code) \
         (*(fd->fns->ADIOI_xxx_Resize))(fd,size,error_code)
 
+#define ADIO_Delete(filename,error_code) \
+        (*(fd->fns->ADIOI_xxx_Delete))(filename,error_code)
+
 #define ADIO_SetInfo(fd, users_info, error_code) \
         (*(fd->fns->ADIOI_xxx_SetInfo))(fd, users_info, error_code)
 
@@ -232,21 +276,26 @@ void ADIOI_Complete_async(int *error_code);
 void ADIOI_Del_req_from_list(ADIO_Request *request);
 struct ADIOI_RequestD *ADIOI_Malloc_request(void);
 void ADIOI_Free_request(ADIOI_Req_node *node);
-void *ADIOI_Malloc(size_t size, int lineno, char *fname);
-void *ADIOI_Calloc(size_t nelem, size_t elsize, int lineno, char *fname);
-void *ADIOI_Realloc(void *ptr, size_t size, int lineno, char *fname);
-void ADIOI_Free(void *ptr, int lineno, char *fname);
+void *ADIOI_Malloc_fn(size_t size, int lineno, char *fname);
+void *ADIOI_Calloc_fn(size_t nelem, size_t elsize, int lineno, char *fname);
+void *ADIOI_Realloc_fn(void *ptr, size_t size, int lineno, char *fname);
+void ADIOI_Free_fn(void *ptr, int lineno, char *fname);
 void ADIOI_Datatype_iscontig(MPI_Datatype datatype, int *flag);
 void ADIOI_Get_position(ADIO_File fd, ADIO_Offset *offset);
 void ADIOI_Get_eof_offset(ADIO_File fd, ADIO_Offset *eof_offset);
 void ADIOI_Get_byte_offset(ADIO_File fd, ADIO_Offset offset, ADIO_Offset *disp);
 
 void ADIOI_GEN_Flush(ADIO_File fd, int *error_code);
+void ADIOI_GEN_Delete(char *filename, int *error_code);
 
 void ADIOI_GEN_ReadStrided(ADIO_File fd, void *buf, int count,
                        MPI_Datatype datatype, int file_ptr_type,
                        ADIO_Offset offset, ADIO_Status *status, int
                        *error_code);
+void ADIOI_GEN_ReadStrided_naive(ADIO_File fd, void *buf, int count,
+                       MPI_Datatype buftype, int file_ptr_type,
+                       ADIO_Offset offset, ADIO_Status *status, int
+                       *error_code);
 void ADIOI_GEN_WriteStrided(ADIO_File fd, void *buf, int count,
                        MPI_Datatype datatype, int file_ptr_type,
                        ADIO_Offset offset, ADIO_Status *status, int
@@ -270,11 +319,19 @@ void ADIOI_Calc_file_domains(ADIO_Offset *st_offsets, ADIO_Offset
 			     ADIO_Offset *min_st_offset_ptr,
 			     ADIO_Offset **fd_start_ptr, ADIO_Offset 
 			     **fd_end_ptr, ADIO_Offset *fd_size_ptr);
-void ADIOI_Calc_my_req(ADIO_Offset *offset_list, int *len_list, int
+int ADIOI_Calc_aggregator(ADIO_File fd,
+                                 ADIO_Offset off,
+                                 ADIO_Offset min_off,
+                                 ADIO_Offset *len,
+                                 ADIO_Offset fd_size,
+                                 ADIO_Offset *fd_start,
+                                 ADIO_Offset *fd_end);
+void ADIOI_Calc_my_req(ADIO_File fd, ADIO_Offset *offset_list, 
+			    int *len_list, int
 			    contig_access_count, ADIO_Offset 
 			    min_st_offset, ADIO_Offset *fd_start,
 			    ADIO_Offset *fd_end, ADIO_Offset fd_size,
-                            int nprocs, int nprocs_for_coll, 
+                            int nprocs,
                             int *count_my_req_procs_ptr,
 			    int **count_my_req_per_proc_ptr,
 			    ADIOI_Access **my_req_ptr,
@@ -282,7 +339,7 @@ void ADIOI_Calc_my_req(ADIO_Offset *offset_list, int *len_list, int
 void ADIOI_Calc_others_req(ADIO_File fd, int count_my_req_procs, 
 				int *count_my_req_per_proc,
 				ADIOI_Access *my_req, 
-				int nprocs, int myrank, int nprocs_for_coll, 
+				int nprocs, int myrank,
 				int *count_others_req_procs_ptr,
 				ADIOI_Access **others_req_ptr);  
 ADIO_Offset ADIOI_GEN_SeekIndividual(ADIO_File fd, ADIO_Offset offset, 
@@ -293,6 +350,8 @@ int ADIOI_Error(ADIO_File fd, int error_code, char *string);
 int MPIR_Err_setmsg( int, int, const char *, const char *, const char *, ... );
 int ADIOI_End_call(MPI_Comm comm, int keyval, void *attribute_val, void *extra_state);
 int MPIR_Status_set_bytes(MPI_Status *status, MPI_Datatype datatype, int nbytes);
+int ADIOI_Uses_generic_read(ADIO_File fd);
+int ADIOI_Uses_generic_write(ADIO_File fd);
 
 
 /* Unix-style file locking */
@@ -314,6 +373,18 @@ int MPIR_Status_set_bytes(MPI_Status *status, MPI_Datatype datatype, int nbytes)
      ADIOI_Set_lock64((fd)->fd_sys, F_SETLK64, F_UNLCK, offset, whence, len); \
    else ADIOI_Set_lock((fd)->fd_sys, F_SETLK, F_UNLCK, offset, whence, len)
 
+#elif (defined(ROMIO_NTFS))
+
+#define ADIOI_LOCK_CMD		0
+#define ADIOI_UNLOCK_CMD	1
+
+#   define ADIOI_WRITE_LOCK(fd, offset, whence, len) \
+          ADIOI_Set_lock((fd)->fd_sys, ADIOI_LOCK_CMD, LOCKFILE_EXCLUSIVE_LOCK, offset, whence, len)
+#   define ADIOI_READ_LOCK(fd, offset, whence, len) \
+          ADIOI_Set_lock((fd)->fd_sys, ADIOLOCK, 0, offset, whence, len)
+#   define ADIOI_UNLOCK(fd, offset, whence, len) \
+          ADIOI_Set_lock((fd)->fd_sys, ADIOI_UNLOCK_CMD, LOCKFILE_FAIL_IMMEDIATELY, offset, whence, len)
+
 #else
 
 #   define ADIOI_WRITE_LOCK(fd, offset, whence, len) \
@@ -325,13 +396,13 @@ int MPIR_Status_set_bytes(MPI_Status *status, MPI_Datatype datatype, int nbytes)
 
 #endif
 
-int ADIOI_Set_lock(int fd_sys, int cmd, int type, ADIO_Offset offset, int whence, ADIO_Offset len);
-int ADIOI_Set_lock64(int fd_sys, int cmd, int type, ADIO_Offset offset, int whence, ADIO_Offset len);
+int ADIOI_Set_lock(FDTYPE fd_sys, int cmd, int type, ADIO_Offset offset, int whence, ADIO_Offset len);
+int ADIOI_Set_lock64(FDTYPE fd_sys, int cmd, int type, ADIO_Offset offset, int whence, ADIO_Offset len);
 
-#define ADIOI_Malloc(a) ADIOI_Malloc(a,__LINE__,__FILE__)
-#define ADIOI_Calloc(a,b) ADIOI_Calloc(a,b,__LINE__,__FILE__)
-#define ADIOI_Realloc(a,b) ADIOI_Realloc(a,b,__LINE__,__FILE__)
-#define ADIOI_Free(a) ADIOI_Free(a,__LINE__,__FILE__)
+#define ADIOI_Malloc(a) ADIOI_Malloc_fn(a,__LINE__,__FILE__)
+#define ADIOI_Calloc(a,b) ADIOI_Calloc_fn(a,b,__LINE__,__FILE__)
+#define ADIOI_Realloc(a,b) ADIOI_Realloc_fn(a,b,__LINE__,__FILE__)
+#define ADIOI_Free(a) ADIOI_Free_fn(a,__LINE__,__FILE__)
 
 #define FPRINTF fprintf
 
