@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: delete.c,v 1.3 2001/01/23 13:56:57 jsquyres Exp $    
+ *   $Id: delete.c,v 1.5 2003/03/25 22:40:59 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -36,8 +37,12 @@ Input Parameters:
 @*/
 int MPI_File_delete(char *filename, MPI_Info info)
 {
-    int flag, error_code;
+    int flag, error_code, file_system;
     char *tmp;
+    ADIOI_Fns *fsops;
+#ifndef PRINT_ERR_MSG
+    static char myname[] = "MPI_FILE_DELETE";
+#endif
 #ifdef MPI_hpux
     int fl_xmpi;
   
@@ -48,7 +53,7 @@ int MPI_File_delete(char *filename, MPI_Info info)
     /* Bogusness to silence compiler warnings */
 
     if (info == MPI_INFO_NULL);
-
+	
     /* first check if ADIO has been initialized. If not, initialize it */
     if (ADIO_Init_keyval == MPI_KEYVAL_INVALID) {
 
@@ -75,10 +80,33 @@ int MPI_File_delete(char *filename, MPI_Info info)
         ADIO_Init( (int *)0, (char ***)0, &error_code);
     }
 
-    tmp = strchr(filename, ':');
-    if (tmp) filename = tmp + 1;
 
-    ADIO_Delete(filename, &error_code);
+    /* resolve file system type from file name; this is a collective call */
+    ADIO_ResolveFileType(MPI_COMM_SELF, filename, &file_system, &fsops, 
+			 &error_code);
+    if (error_code != MPI_SUCCESS) {
+	/* ADIO_ResolveFileType() will print as informative a message as it
+	 * possibly can or call MPIR_Err_setmsg.  We just need to propagate 
+	 * the error up.  In the PRINT_ERR_MSG case MPI_Abort has already
+	 * been called as well, so we probably didn't even make it this far.
+	 */
+#ifdef PRINT_ERR_MSG
+	MPI_Abort(MPI_COMM_WORLD, 1); /* this is mostly here for clarity */
+#else
+	return ADIOI_Error(MPI_FILE_NULL, error_code, myname);
+#endif
+    }
+
+    /* skip prefix on filename if there is one */
+    tmp = strchr(filename, ':');
+    /* Only skip prefixes greater than length one to allow for windows drive specification (c:\...)*/
+    /*if (tmp) filename = tmp + 1;*/
+    if (tmp > filename + 1)
+	filename = tmp + 1;
+
+    /* call the fs-specific delete function */
+    (fsops->ADIOI_xxx_Delete)(filename, &error_code);
+	
 #ifdef MPI_hpux
     HPMP_IO_END(fl_xmpi, MPI_FILE_NULL, MPI_DATATYPE_NULL, -1);
 #endif /* MPI_hpux */
