@@ -1,5 +1,6 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: iotest.c,v 1.1.1.1 1999/03/17 18:52:54 jsquyres Exp $    
+ *   $Id: iotest.c,v 1.3 2003/03/25 22:41:01 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -7,6 +8,22 @@
 
 #include "mpioimpl.h"
 
+#ifdef HAVE_WEAK_SYMBOLS
+
+#if defined(HAVE_PRAGMA_WEAK)
+#pragma weak MPIO_Test = PMPIO_Test
+#elif defined(HAVE_PRAGMA_HP_SEC_DEF)
+#pragma _HP_SECONDARY_DEF PMPIO_Test MPIO_Test
+#elif defined(HAVE_PRAGMA_CRI_DUP)
+#pragma _CRI duplicate MPIO_Test as PMPIO_Test
+/* end of weak pragmas */
+#endif
+
+/* Include mapping from MPI->PMPI */
+#define MPIO_BUILD_PROFILING
+#include "mpioprof.h"
+#endif
+
 /* status object not filled currently */
 
 /*@
@@ -24,6 +41,9 @@ Output Parameters:
 int MPIO_Test(MPIO_Request *request, int *flag, MPI_Status *status)
 {
     int error_code;
+#ifndef PRINT_ERR_MSG
+    static char myname[] = "MPIO_TEST";
+#endif
 #ifdef MPI_hpux
     int fl_xmpi;
 
@@ -36,8 +56,14 @@ int MPIO_Test(MPIO_Request *request, int *flag, MPI_Status *status)
 
     if ((*request < (MPIO_Request) 0) || 
 	     ((*request)->cookie != ADIOI_REQ_COOKIE)) {
-	printf("MPIO_Test: Invalid request object\n");
+#ifdef PRINT_ERR_MSG
+	FPRINTF(stderr, "MPIO_Test: Invalid request object\n");
 	MPI_Abort(MPI_COMM_WORLD, 1);
+#else
+	error_code = MPIR_Err_setmsg(MPI_ERR_REQUEST, MPIR_ERR_REQUEST_NULL,
+				     myname, (char *) 0, (char *) 0);
+	return ADIOI_Error(MPI_FILE_NULL, error_code, myname);
+#endif
     }
 
     switch ((*request)->optype) {
