@@ -1,11 +1,28 @@
+/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /* 
- *   $Id: info_f2c.c,v 1.1.1.1 1999/03/17 18:53:04 jsquyres Exp $    
+ *   $Id: info_f2c.c,v 1.3 2003/03/25 22:41:23 nsanghvi Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
  */
 
 #include "mpioimpl.h"
+
+#ifdef HAVE_WEAK_SYMBOLS
+
+#if defined(HAVE_PRAGMA_WEAK)
+#pragma weak MPI_Info_f2c = PMPI_Info_f2c
+#elif defined(HAVE_PRAGMA_HP_SEC_DEF)
+#pragma _HP_SECONDARY_DEF PMPI_Info_f2c MPI_Info_f2c
+#elif defined(HAVE_PRAGMA_CRI_DUP)
+#pragma _CRI duplicate MPI_Info_f2c as PMPI_Info_f2c
+/* end of weak pragmas */
+#endif
+
+/* Include mapping from MPI->PMPI */
+#define MPIO_BUILD_PROFILING
+#include "mpioprof.h"
+#endif
 #include "adio_extern.h"
 
 /*@
@@ -20,12 +37,12 @@ Return Value:
 MPI_Info MPI_Info_f2c(MPI_Fint info)
 {
 
-#ifndef __INT_LT_POINTER
+#ifndef INT_LT_POINTER
     return (MPI_Info) info;
 #else
     if (!info) return MPI_INFO_NULL;
     if ((info < 0) || (info > MPIR_Infotable_ptr)) {
-	printf("MPI_Info_f2c: Invalid info handle\n");
+	FPRINTF(stderr, "MPI_Info_f2c: Invalid info handle\n");
 	MPI_Abort(MPI_COMM_WORLD, 1);
     }
     return MPIR_Infotable[info];
