@@ -11,14 +11,8 @@
  * LAM/MPI source distribution.
  * 
  * $HEADER$
- *	Software for Humanity
- *	GDB/RBD
  *
- *	This program is freely distributed in the hope that it will be useful,
- *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- *
- *	$Id: all_argv.c,v 6.9 2003/05/31 22:28:49 jsquyres Exp $
+ * $Id: all_argv.c,v 6.10 2003/07/05 21:43:46 jsquyres Exp $
  *
  *	Function:	- argument vector library
  */
@@ -28,6 +22,7 @@
 
 #include <lam.h>
 #include <etc_misc.h>
+#include <sfh.h>
 
 #define ARGSIZE		128
 
@@ -106,7 +101,7 @@ sfh_argv_break(char *args, int delim)
 {
 	char		arg[ARGSIZE];	/* single argument */
 	char		**argv = 0;	/* argument structure ptr */
-	char	*p;		/* walk through args */
+	char            *p;		/* walk through args */
 	char		*argtemp;	/* temporary single argument */
 	int		argc = 0;	/* # arguments */
 	unint		arglen;		/* single argument length */
@@ -495,31 +490,3 @@ sfh_argv_quote(char *s, char quotes[])
 
 	return(qs);
 }
-
-
-/*
- * backwards compatibility
- */
-int addarg(int *argc, char ***argv, char *arg)
-{ return(sfh_argv_add(argc, argv, arg)); }
-
-int argvadd(int *argc, char ***argv, char *arg)
-{ return(sfh_argv_add(argc, argv, arg)); }
-
-void argvfree(char **argv)
-{ sfh_argv_free(argv); }
-
-char **argvbreak(char *args, int delim)
-{ return(sfh_argv_break(args, delim)); }
-
-int argvcount(char **argv)
-{ return(sfh_argv_count(argv)); }
-
-char *argvglue(char **argv, int delim, unint maxlen)
-{ return(sfh_argv_glue(argv, delim, maxlen)); }
-
-unint argvlen(char **argv)
-{ return(sfh_argv_len(argv)); }
-
-char **argvdup(char **argv)
-{ return(sfh_argv_dup(argv)); }
