@@ -33,7 +33,7 @@
 static int addinst(struct ao_opt *opt, int nparam, char **params);
 static int countparam(OPT *aod, struct ao_opt *opt, char **argv);
 static int mutexchk(struct ao_opt *opt);
-static int strtonum(const char *str, int *pnum);
+static int lam_strtonum(const char *str, int *pnum);
 static struct ao_opt *findopt(OPT *desc, const char *optstr);
 
 
@@ -652,7 +652,7 @@ ao_parse(OPT *aod, int *pcmdc, char **cmdv)
 /*
  * If a number, assume '#' option.
  */
-		else if (strtonum(++str, &num) == 0) {
+		else if (lam_strtonum(++str, &num) == 0) {
 
 			popt = findopt(aod, "#");
 			if ((popt == 0) || (mutexchk(popt))) {
@@ -884,7 +884,7 @@ findopt(OPT *desc, const char *optstr)
 
 
 /*
- *	strtonum
+ *	lam_strtonum
  *
  *	Function:	- convert string to number if possible
  *			- handles decimal/octal/hexadecimal
@@ -894,7 +894,7 @@ findopt(OPT *desc, const char *optstr)
  *	Returns:	- 0 or LAMERROR
  */
 static int
-strtonum(const char *str, int *pnum)
+lam_strtonum(const char *str, int *pnum)
 {
 	char		*endstr;		/* end of parsed string */
 
@@ -956,7 +956,7 @@ countparam(OPT *aod, struct ao_opt *opt, char **argv)
 
 		if (strcmp(string, "--") == 0) break;
 
-		if ((strtonum(string + 1, &num) == 0) &&
+		if ((lam_strtonum(string + 1, &num) == 0) &&
 				(findopt(aod, "#") != 0)) break;
 
 		if (findopt(aod, string + 1)) break;
@@ -1036,7 +1036,7 @@ addinst(struct ao_opt *opt, int nparam, char **params)
 	for (; nparam > 0; --nparam, ++params, parmbuf += size) {
 
 		if (fl_int) {
-			if (strtonum(*params, &num)) {
+			if (lam_strtonum(*params, &num)) {
 				errno = EUSAGE;
 				return(LAMERROR);
 			}
