@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: ndi_parse.c,v 6.10 2003/03/19 19:15:35 jsquyres Exp $
+ * $Id: ndi_parse.c,v 6.11 2003/07/05 21:44:33 jsquyres Exp $
  *
  *	Function:	- node identifier parsing package
  *			- id_range() based in part on Trollius 2.0,
@@ -32,6 +32,7 @@
 #include <ndi.h>
 #include <rreq.h>
 #include <lam.h>
+#include <sfh.h>
 
 #define NEW		1
 #define ONE		2
@@ -73,7 +74,7 @@ ndi_parse(int argc, char **argv, char ***othersv)
 		othersc = 0;
 		*othersv = 0;
 
-		if (argvadd(&othersc, othersv, argv[0])) {
+		if (sfh_argv_add(&othersc, othersv, argv[0])) {
 			al_free(nodelist);
 			return(0);
 		}
@@ -91,7 +92,7 @@ ndi_parse(int argc, char **argv, char ***othersv)
 		if ((**argv == 'n') && isdigit((int) *((*argv + 1)))) {
 			if (id_range(*argv + 1, 0, &index, 1, nodelist)) {
 				al_free(nodelist);
-				if (othersv) argvfree(*othersv);
+				if (othersv) sfh_argv_free(*othersv);
 				return(0);
 			}
 		}
@@ -101,7 +102,7 @@ ndi_parse(int argc, char **argv, char ***othersv)
 		else if ((**argv == 'c') && isdigit((int) *((*argv + 1)))) {
 			if (id_range(*argv + 1, 0, &index, 0, nodelist)) {
 				al_free(nodelist);
-				if (othersv) argvfree(*othersv);
+				if (othersv) sfh_argv_free(*othersv);
 				return(0);
 			}
 		}
@@ -116,7 +117,7 @@ ndi_parse(int argc, char **argv, char ***othersv)
 
 			if (al_append(nodelist, &newndi) == 0) {
 				al_free(nodelist);
-				if (othersv) argvfree(*othersv);
+				if (othersv) sfh_argv_free(*othersv);
 				return(0);
 			}
 		}
@@ -135,7 +136,7 @@ ndi_parse(int argc, char **argv, char ***othersv)
 
 			if (al_append(nodelist, &newndi) == 0) {
 				al_free(nodelist);
-				if (othersv) argvfree(*othersv);
+				if (othersv) sfh_argv_free(*othersv);
 				return(0);
 			}
 		}
@@ -148,7 +149,7 @@ ndi_parse(int argc, char **argv, char ***othersv)
 
 			if (al_append(nodelist, &newndi) == 0) {
 				al_free(nodelist);
-				if (othersv) argvfree(*othersv);
+				if (othersv) sfh_argv_free(*othersv);
 				return(0);
 			}
 		}
@@ -157,9 +158,9 @@ ndi_parse(int argc, char **argv, char ***othersv)
  */
 		else if (othersv) {
 
-			if (argvadd(&othersc, othersv, argv[0])) {
+			if (sfh_argv_add(&othersc, othersv, argv[0])) {
 				al_free(nodelist);
-				argvfree(*othersv);
+				sfh_argv_free(*othersv);
 				return(0);
 			}
 		}
