@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -11,11 +11,8 @@
  * LAM/MPI source distribution.
  * 
  * $HEADER$
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	GDB
  *
- *	$Id: pdi_parse.c,v 6.8 2002/10/09 20:56:56 brbarret Exp $
+ * $Id: pdi_parse.c,v 6.9 2003/07/05 21:44:46 jsquyres Exp $
  *
  *	Function:	- node identifier parsing package
  *			- id_range() based in part on Trollius 2.0,
@@ -36,6 +33,7 @@
 #include <preq.h>
 #include <terror.h>
 #include <typical.h>
+#include <sfh.h>
 
 #define NEW		1
 #define ONE		2
@@ -73,7 +71,7 @@ pdi_parse(int argc, char **argv, char ***othersv)
 		othersc = 0;
 		*othersv = 0;
 
-		if (argvadd(&othersc, othersv, argv[0])) {
+		if (sfh_argv_add(&othersc, othersv, argv[0])) {
 			al_free(proclist);
 			return(0);
 		}
@@ -92,7 +90,7 @@ pdi_parse(int argc, char **argv, char ***othersv)
 
 			if (id_range(*argv + 1, SELECT_PID, &index, proclist)) {
 				al_free(proclist);
-				argvfree(*othersv);
+				sfh_argv_free(*othersv);
 				return(0);
 			}
 		}
@@ -105,7 +103,7 @@ pdi_parse(int argc, char **argv, char ***othersv)
 			if (id_range(*argv + 1,
 					SELECT_INDEX, &index, proclist)) {
 				al_free(proclist);
-				argvfree(*othersv);
+				sfh_argv_free(*othersv);
 				return(0);
 			}
 		}
@@ -114,9 +112,9 @@ pdi_parse(int argc, char **argv, char ***othersv)
  */
 		else if (othersv) {
 
-			if (argvadd(&othersc, othersv, argv[0])) {
+			if (sfh_argv_add(&othersc, othersv, argv[0])) {
 				al_free(proclist);
-				argvfree(*othersv);
+				sfh_argv_free(*othersv);
 				return(0);
 			}
 		}
