@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD/GDB
+ * $HEADER$
  *
- *	$Id: app_mgmt.c,v 6.6.2.1 2002/10/09 19:48:50 brbarret Exp $
+ * $Id: app_mgmt.c,v 6.8 2003/04/10 17:47:01 jsquyres Exp $
  *
  *	Function:	- application execution and management
  */
@@ -25,11 +23,6 @@
 #include <preq.h>
 #include <typical.h>
 
-/*
- * public functions
- */
-int			app_doom();
-int			app_sendprocs();
 
 /*
  *	app_sendprocs
@@ -40,11 +33,7 @@ int			app_sendprocs();
  *	Returns:	- 0 or LAMERROR
  */
 int
-app_sendprocs(nprocs, pgps)
-
-int			nprocs;
-struct _gps		*pgps;
-
+app_sendprocs(int nprocs, struct _gps *pgps)
 {
 	struct nmsg	nhead;			/* network msg header */
 	struct _gps	*p;			/* ptr GPS entry */
@@ -52,6 +41,7 @@ struct _gps		*pgps;
 /*
  * Set up the message.
  */
+        LAM_ZERO_ME(nhead);
 	nhead.nh_type = 0;
 	nhead.nh_flags = DINT4MSG;
 	nhead.nh_msg = (char *) pgps;
@@ -69,6 +59,7 @@ struct _gps		*pgps;
 	return(0);
 }
 
+
 /*
  *	app_doom
  *
