@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- *	$Id: asc_parse.c,v 6.32.2.2 2004/01/12 04:38:46 jsquyres Exp $
+ * Id: asc_parse.c,v 6.33 2004/01/09 18:03:34 jsquyres Exp $
  *
  *	Function:	- application schema parsing
  */
@@ -663,7 +663,7 @@ asc_environment(int exportme, char *varlist, char ***env)
 	if (exportme)
 /*
  * Export all environment variables of form LAM_MPI_* or LAM_IMPI_* or 
- * IMPI_*.  Special case: do *no* export LAM_MPI_SESSION_PREFIX.
+ * IMPI_*.  Special case: do *not* export LAM_MPI_SESSION_PREFIX.
  */
 		for (p = environ; p && *p; p++) {
 		  if (strncmp(*p, "LAM_MPI_", 8) == 0 &&
