@@ -11,11 +11,8 @@
  * LAM/MPI source distribution.
  * 
  * $HEADER$
- *	Ohio Trollius
- *	Copyright 1995 The Ohio State University
- *	GDB
  *
- *      $Id: proc_schema.c,v 6.7 2003/04/14 01:24:20 vsahay Exp $
+ * $Id: proc_schema.c,v 6.8 2003/07/05 21:45:40 jsquyres Exp $
  * 
  *	Function:	- process schema operations
  */
@@ -31,6 +28,7 @@
 #include <typical.h>
 #include <etc_misc.h>
 #include <sfh.h>
+#include <boot.h>
 
 /*
  * private functions
@@ -89,7 +87,7 @@ psc_parse(FILE *fp, LIST **list_psc, char **argv_var)
 			} else if (*token == '$') {
 				var_substitute(&psc_new, token, argv_var);
 			} else {
-				argvadd(&psc_new.psc_argc, &psc_new.psc_argv,
+                          sfh_argv_add(&psc_new.psc_argc, &psc_new.psc_argv,
 						token);
 			}
 
