@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: T.c,v 6.7 2003/01/13 19:17:43 jsquyres Exp $
+ * $Id: T.c,v 6.8 2003/07/05 21:46:23 jsquyres Exp $
  * 
  *	Function:	- f2c F77 interface for libt functions
  */
@@ -94,50 +94,116 @@ extern char		*f2cstring();
 #define lamf_rfopen_	lamf_rfopen__
 #endif
 
+/*
+ * These are (unsupported) functions, so it's not too important to
+ * protoype them.  But for the sake of eliminating compiler
+ * warnings...
+ */
+double fttime_(void);
+int4 igntp_(int4 *tp, int4 *msk);
+int4 ignall_(void);
+int4 igncmp_(void);
+int4 igndid_(void);
+int4 igndtp_(void);
+int4 ignjon_(void);
+int4 ignotb_(void);
+int4 igorgn_(void);
+int4 igrtp_(int4 *nd);
+void i2ltot_(int2 *l, int2 *t);
+void i2mltt_(int2 *a, int *n);
+void i2mttl_(int2 *a, int *n);
+void i2ttol_(int2 *t, int2 *l);
+void i4ltot_(int4 *l, int4 *t);
+void i4mltt_(int4 *a, int *n);
+void i4mttl_(int4 *a, int *n);
+void i4ttol_(int4 *t, int4 *l);
+void f4ltot_(float4 *l, float4 *t);
+void f4mltt_(float4 *a, int *n);
+void f4mttl_(float4 *a, int *n);
+void f4ttol_(float4 *t, float4 *l);
+void f8ltot_(float8 *l, float8 *t);
+void f8mltt_(float8 *a, int *n);
+void f8mttl_(float8 *a, int *n);
+void f8ttol_(float8 *t, float8 *l);
+void gall_(int4 *n, int4 *nn, int4 *ie);
+void gcomps_(int4 *n, int4 *nn, int4 *ie);
+void gjones_(int4 *n, int4 *nn, int4 *ie);
+void gnodes_(int4 *n, int4 *nn, int4 *tp, int4 *msk, int4 *ie);
+void gotbs_(int4 *n, int4 *nn, int4 *ie);
+void kxit_(int *er);
+void lamf_rfclose_(int *ud, int *ie);
+void lamf_rfread_(int *ud, char *b, int *i, int *o, int *ie);
+void lamf_rfwrite_(int *ud, char *b, int *i, int *o, int *ie);
+
+
+void trror_(char *pstr, unsigned int lstr);
+void lamf_rfopen_(int *udesc, char *file_name, int *flags, int *modes, 
+                  int *ierror, unsigned int lstr);
+void kentr_(char *name, int *priority, int *ierror, unsigned int lstr);
+void nsnd_(int *nnode, int *nevent, int *ntype, int *nlength, int *nflags, 
+           int *ndata, int *ndsize, char *nmsg, int *ierror);
+void nrcv_(int *nevent, int *ntype, int *nlength, int *nflags, int *ndata, 
+           int *ndsize, char *nmsg, int *ierror);
+void nprob_(int *nevent, int *ntype, int *nlength, int *nflags, int *nready, 
+            int *ierror);
+void tsnd_(int *nnode, int *nevent, int *ntype, int *nlength, int *nflags, 
+           int *ndata, int *ndsize, char *nmsg, int *ierror);
+void trcv_(int *nevent, int *ntype, int *nlength, int *nflags, int *ndata, 
+           int *ndsize, char *nmsg, int *ierror);
+void psndo_(int4 *pnode, int4* pevent, int4* ptype, int4* ierror);
+void psndc_(int4 *pnode, int4 *pevent, int4 *ptype, int4 *ierror);
+void psnd_(int4 *pnode, int4 *pevent, int4 *ptype, int4 *plength, 
+           int4 *pflags, int4 *pdata, int4 *pdsize, char *pmsg, int4 *ierror);
+void prcvo_(int *pevent, int *ptype, int *ierror);
+void prcvc_(int4* pevent, int4* ptype, int4* ierror);
+void prcv_(int4 *pevent, int4 *ptype, int4 *plength, int4 *pflags, 
+           int4 *pdata, int4 *pdsize, char *pmsg, int4 *ierror);
+
+
 /*
  * simple wrappers
  */
-double fttime_() { return(ttime()); }
-int4 igntp_(tp, msk) int4 *tp, *msk; { return(getntype(*tp, *msk)); }
-int4 ignall_() { return(getnall()); }
-int4 igncmp_() { return(getncomp()); }
-int4 igndid_() { return(getnodeid()); }
-int4 igndtp_() { return(getnodetype()); }
-int4 ignjon_() { return(getnjones()); }
-int4 ignotb_() { return(getnotb()); }
-int4 igorgn_() { return(getorigin()); }
-int4 igrtp_(nd) int4 *nd; { return(getrtype(*nd)); }
-void i2ltot_(l, t) int2 *l, *t; { ltoti2(l, t); }
-void i2mltt_(a, n) int2 *a; int *n; { mltoti2(a, *n); }
-void i2mttl_(a, n) int2 *a; int *n; { mttoli2(a, *n); }
-void i2ttol_(t, l) int2 *t, *l; { ttoli2(t, l); }
-void i4ltot_(l, t) int4 *l, *t; { ltoti4(l, t); }
-void i4mltt_(a, n) int4 *a; int *n; { mltoti4(a, *n); }
-void i4mttl_(a, n) int4 *a; int *n; { mttoli4(a, *n); }
-void i4ttol_(t, l) int4 *t, *l; { ttoli4(t, l); }
-void f4ltot_(l, t) float4 *l, *t; { ltotf4(l, t); }
-void f4mltt_(a, n) float4 *a; int *n; { mltotf4(a, *n); }
-void f4mttl_(a, n) float4 *a; int *n; { mttolf4(a, *n); }
-void f4ttol_(t, l) float4 *t, *l; { ttolf4(t, l); }
-void f8ltot_(l, t) float8 *l, *t; { ltotf8(l, t); }
-void f8mltt_(a, n) float8 *a; int *n; { mltotf8(a, *n); }
-void f8mttl_(a, n) float8 *a; int *n; { mttolf8(a, *n); }
-void f8ttol_(t, l) float8 *t, *l; { ttolf8(t, l); }
-void gall_(n, nn, ie) int4 *n, *nn, *ie;
+double fttime_(void) { return(ttime()); }
+int4 igntp_(int4 *tp, int4 *msk) { return(getntype(*tp, *msk)); }
+int4 ignall_(void) { return(getnall()); }
+int4 igncmp_(void) { return(getncomp()); }
+int4 igndid_(void) { return(getnodeid()); }
+int4 igndtp_(void) { return(getnodetype()); }
+int4 ignjon_(void) { return(getnjones()); }
+int4 ignotb_(void) { return(getnotb()); }
+int4 igorgn_(void) { return(getorigin()); }
+int4 igrtp_(int4 *nd) { return(getrtype(*nd)); }
+void i2ltot_(int2 *l, int2 *t) { ltoti2(l, t); }
+void i2mltt_(int2 *a, int *n) { mltoti2(a, *n); }
+void i2mttl_(int2 *a, int *n) { mttoli2(a, *n); }
+void i2ttol_(int2 *t, int2 *l) { ttoli2(t, l); }
+void i4ltot_(int4 *l, int4 *t) { ltoti4(l, t); }
+void i4mltt_(int4 *a, int *n) { mltoti4(a, *n); }
+void i4mttl_(int4 *a, int *n) { mttoli4(a, *n); }
+void i4ttol_(int4 *t, int4 *l){ ttoli4(t, l); }
+void f4ltot_(float4 *l, float4 *t) { ltotf4(l, t); }
+void f4mltt_(float4 *a, int *n) { mltotf4(a, *n); }
+void f4mttl_(float4 *a, int *n) { mttolf4(a, *n); }
+void f4ttol_(float4 *t, float4 *l) { ttolf4(t, l); }
+void f8ltot_(float8 *l, float8 *t) { ltotf8(l, t); }
+void f8mltt_(float8 *a, int *n) { mltotf8(a, *n); }
+void f8mttl_(float8 *a, int *n) { mttolf8(a, *n); }
+void f8ttol_(float8 *t, float8 *l) { ttolf8(t, l); }
+void gall_(int4 *n, int4 *nn, int4 *ie) 
 		{ *ie = getall(n, *nn) ? errno : 0; }
-void gcomps_(n, nn, ie) int4 *n, *nn, *ie;
+void gcomps_(int4 *n, int4 *nn, int4 *ie) 
 		{ *ie = getcomps(n, *nn) ? errno : 0; }
-void gjones_(n, nn, ie) int4 *n, *nn, *ie;
+void gjones_(int4 *n, int4 *nn, int4 *ie)
 		{ *ie = getjones(n, *nn) ? errno : 0; }
-void gnodes_(n, nn, tp, msk, ie) int4 *n, *nn, *tp, *msk, *ie;
+void gnodes_(int4 *n, int4 *nn, int4 *tp, int4 *msk, int4 *ie)
 		{ *ie = getnodes(n, *nn, *tp, *msk) ? errno : 0; }
-void gotbs_(n, nn, ie) int4 *n, *nn, *ie;
+void gotbs_(int4 *n, int4 *nn, int4 *ie)
 		{ *ie = getotbs(n, *nn) ? errno : 0; }
-void kxit_(er) int *er; { kexit(*er); }
-void lamf_rfclose_(ud, ie) int *ud, *ie; { *ie = lam_rfclose(*ud) ? errno : 0; }
-void lamf_rfread_(ud, b, i, o, ie) int *ud; char *b; int *i, *o, *ie;
+void kxit_(int *er) { kexit(*er); }
+void lamf_rfclose_(int *ud, int *ie) { *ie = lam_rfclose(*ud) ? errno : 0; }
+void lamf_rfread_(int *ud, char *b, int *i, int *o, int *ie)
 		{ *ie = (*o = lam_rfread(*ud, b, *i)) < 0 ? errno : 0; }
-void lamf_rfwrite_(ud, b, i, o, ie) int *ud; char *b; int *i, *o, *ie;
+void lamf_rfwrite_(int *ud, char *b, int *i, int *o, int *ie)
 		{ *ie = (*o = lam_rfwrite(*ud, b, *i)) < 0 ? errno : 0; }
 
 /*
