@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -11,14 +11,8 @@
  * LAM/MPI source distribution.
  * 
  * $HEADER$
- *	Software for Humanity
- *	RBD
  *
- *	This program is freely distributed in the hope that it will be useful,
- *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- *
- *	$Id: all_hash.c,v 6.4 2002/10/09 20:57:00 brbarret Exp $
+ * $Id: all_hash.c,v 6.5 2003/07/05 21:47:01 jsquyres Exp $
  *
  *	Function:	- generic hash table management code
  *			- fully dynamic version
@@ -264,7 +258,7 @@ ah_find(HASH *ahd, int4 key)
  *	Returns:	- ptr to element or NULL
  */
 void *
-ah_find_elem(HASH *ahd, void *celem)
+ah_find_elm(HASH *ahd, void *celem)
 {
 	void		*pfirst;	/* ptr first element found */
 	void		*p;		/* favourite pointer */
