@@ -1,38 +1,21 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
- * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/NJN
  *
- *	$Id: blktype.c,v 6.8 2000/10/16 01:21:28 jsquyres Exp $
+ *	$Id: blktype.c,v 6.12 2002/10/09 20:57:01 brbarret Exp $
  *
  *	Function:	- get description of blocking request type code
  *	Accepts:	- request type code
@@ -208,7 +191,7 @@ static CONST char	*blkdesc[] = {
 
 		"MPI_Accumulate",		/* BLKMPIACCUMULATE */
 		"",				/* BLKMPIADDERRCLASS */
-		"",				/* BLKMPIALLOCMEM */
+		"MPI_Alloc_mem",		/* BLKMPIALLOCMEM */
 		"",				/* BLKMPIFILEREADALL */
 		"",				/* BLKMPIALLTOALLW */
 		"MPI_Close_port",		/* BLKMPICLOSEPORT */
@@ -218,18 +201,19 @@ static CONST char	*blkdesc[] = {
 		"MPI_Comm_create_errhandler",	/* BLKMPICOMMCREATEERRHDL */
 		"MPI_Comm_create_keyval",	/* BLKMPICOMMCREATEKEYVAL */
 		"MPI_Comm_disconnect",		/* BLKMPICOMMDISCONNECT */
-		"",				/* BLKMPICOMMDUPFN */
+		"MPI_COMM_DUP_FN",		/* BLKMPICOMMDUPFN */
 		"MPI_Comm_free_keyval",		/* BLKMPICOMMFREEKEYVAL */
 		"MPI_Comm_get_errhandler",	/* BLKMPICOMMGETERRHDL */
 		"MPI_Comm_get_name",		/* BLKMPICOMMGETNAME */
 		"MPI_Comm_get_parent",		/* BLKMPICOMMGETPARENT */
 		"MPI_Comm_join",		/* BLKMPICOMMJOIN */
-		"",				/* BLKMPICOMMNULLCOPYFN */
+		"MPI_COMM_NULL_COPY_FN",	/* BLKMPICOMMNULLCOPYFN */
 		"MPI_Comm_set_errhandler",	/* BLKMPICOMMSETERRHDL */
 		"MPI_Comm_set_name",		/* BLKMPICOMMSETNAME */
 		"MPI_Comm_spawn",		/* BLKMPICOMMSPAWN */
 		"MPI_Comm_spawn_multiple",	/* BLKMPICOMMSPAWNMULT */
 		"",				/* BLKMPIEXSCAN */
+
 		"",				/* BLKMPIFILEC2F */
 		"",				/* BLKMPIFILECALLERRHDL */
 		"",				/* BLKMPIFILECLOSE */
@@ -277,7 +261,8 @@ static CONST char	*blkdesc[] = {
 		"",				/* BLKMPIFILEWRITEORD */
 		"",				/* BLKMPIFILEWRITEORDBEG */
 		"",				/* BLKMPIFILEWRITESHARED */
-		"",				/* BLKMPIFREEMEM */
+
+		"MPI_Free_mem",			/* BLKMPIFREEMEM */
 		"MPI_Get",			/* BLKMPIGET */
 		"MPI_Get_address",		/* BLKMPIGETADDRESS */
 		"",				/* BLKMPIGREQCOMPLETE */
@@ -306,17 +291,17 @@ static CONST char	*blkdesc[] = {
 		"MPI_Type_create_subarray",	/* BLKMPITCREATESUBARRAY */
 		"MPI_Type_delete_attr",		/* BLKMPITDELETEATTR */
 		"MPI_Type_dup",			/* BLKMPITDUP */
-		"",				/* BLKMPITDUPFN */
+		"MPI_DUP_FN",			/* BLKMPITDUPFN */
 		"MPI_Type_free_keyval",		/* BLKMPITFREEKEYVAL */
 		"MPI_Type_get_extent",		/* BLKMPITGETEXTENT */
 		"MPI_Type_get_name",		/* BLKMPITGETNAME */
 		"",				/* BLKMPITMATCHSIZE */
-		"",				/* BLKMPITNULLCOPYFN */
+		"MPI_TYPE_NULL_COPY_FN",	/* BLKMPITNULLCOPYFN */
 		"MPI_Type_set_name",		/* BLKMPITSETNAME */
 		"",				/* BLKMPIUNPACKEXTERNAL */
 		"MPI_Unpublish_name",		/* BLKMPIUNPUBLISHNAME */
 		"MPI_Win_c2f",			/* BLKMPIWINC2F */
-		"",				/* BLKMPIWINCALLERRHDL */
+		"MPI_Win_call_errhandler",	/* BLKMPIWINCALLERRHDL */
 		"MPI_Win_complete",		/* BLKMPIWINCOMPLETE */
 		"MPI_Win_create",		/* BLKMPIWINCREATE */
 		"MPI_Win_create_errhandler",	/* BLKMPIWINCREATEERRHDL */
@@ -328,14 +313,15 @@ static CONST char	*blkdesc[] = {
 		"MPI_Win_get_errhandler",	/* BLKMPIWINGETERRHDL */
 		"MPI_Win_get_group",		/* BLKMPIWINGETGROUP */
 		"MPI_Win_get_name",		/* BLKMPIWINGETNAME */
-		"",				/* BLKMPIWINLOCK */
-		"",				/* BLKMPIWINNULLCOPYFN */
+		"MPI_Win_lock",			/* BLKMPIWINLOCK */
+		"MPI_WIN_NULL_COPY_FN",		/* BLKMPIWINNULLCOPYFN */
 		"MPI_Win_post",			/* BLKMPIWINPOST */
 		"MPI_Win_set_attr",		/* BLKMPIWINSETATTR */
 		"MPI_Win_set_errhandler",	/* BLKMPIWINSETERRHDL */
 		"MPI_Win_set_name",		/* BLKMPIWINSETNAME */
 		"MPI_Win_start",		/* BLKMPIWINSTART */
-		"",				/* BLKMPIWINUNLOCK */
+		"MPI_Win_test",			/* BLKMPIWINTEST */
+		"MPI_Win_unlock",		/* BLKMPIWINUNLOCK */
 		"MPI_Win_wait",			/* BLKMPIWINWAIT */
 		"",				/* BLKMPIFILEWRITEALL */
 		"",				/* BLKMPIOTEST */
@@ -363,6 +349,9 @@ static CONST char	*blkdesc[] = {
 
 		"mpirun",                       /* BLKMPIRUN */
 
+		"MPIL_Request_get_name",        /* BLKMPILREQUESTGETNAME */
+		"MPIL_Request_set_name",        /* BLKMPILREQUESTSETNAME */
+
 		"XMPI_Buoy",                    /* BLKXMPIBUOY */
 		"XMPI_Coloron",                 /* BLKXMPICOLORON */
 		"XMPI_Coloroff",                /* BLKXMPICOLOROFF */
