@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,11 +12,7 @@
  * 
  * $HEADER$
  *
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD
- *
- *	$Id: combine.c,v 6.5 2002/10/09 20:57:01 brbarret Exp $
+ * $Id: combine.c,v 6.6 2003/07/05 21:50:25 jsquyres Exp $
  *
  *	Function:	- functions to combine arrays of data
  */
@@ -26,6 +22,7 @@
 #include <net.h>
 #include <portable.h>
 #include <typical.h>
+#include <etc_misc.h>
 
 /*
  *	cbn_add
@@ -37,13 +34,7 @@
  *			- second message
  */	
 void
-cbn_add(flags, length, msg1, msg2)
-
-int4			flags;
-int4			length;
-char			*msg1;
-char			*msg2;
-
+cbn_add(int4 flags, int4 length, char *msg1, char *msg2)
 {
 	float4		*pf1, *pf2;
 	float8		*pd1, *pd2;
@@ -106,13 +97,7 @@ char			*msg2;
  *			- second message
  */	
 void
-cbn_and(flags, length, msg1, msg2)
-
-int4			flags;
-int4			length;
-char			*msg1;
-char			*msg2;
-
+cbn_and(int4 flags, int4 length, char *msg1, char *msg2)
 {
 	int4		*pi1, *pi2;
 
@@ -159,13 +144,7 @@ char			*msg2;
  *			- second message
  */	
 void
-cbn_err(flags, length, msg1, msg2)
-
-int4			flags;
-int4			length;
-char			*msg1;
-char			*msg2;
-
+cbn_err(int4 flags, int4 length, char *msg1, char *msg2)
 {
 	float4		*pf1, *pf2;
 	float8		*pd1, *pd2;
@@ -225,13 +204,7 @@ char			*msg2;
  *			- second message
  */	
 void
-cbn_max(flags, length, msg1, msg2)
-
-int4			flags;
-int4			length;
-char			*msg1;
-char			*msg2;
-
+cbn_max(int4 flags, int4 length, char *msg1, char *msg2)
 {
 	float4		*pf1, *pf2;
 	float8		*pd1, *pd2;
@@ -293,13 +266,7 @@ char			*msg2;
  *			- second message
  */	
 void
-cbn_min(flags, length, msg1, msg2)
-
-int4			flags;
-int4			length;
-char			*msg1;
-char			*msg2;
-
+cbn_min(int4 flags, int4 length, char *msg1, char *msg2)
 {
 	float4		*pf1, *pf2;
 	float8		*pd1, *pd2;
@@ -361,13 +328,7 @@ char			*msg2;
  *			- second message
  */	
 void
-cbn_mul(flags, length, msg1, msg2)
-
-int4			flags;
-int4			length;
-char			*msg1;
-char			*msg2;
-
+cbn_mul(int4 flags, int4 length, char *msg1, char *msg2)
 {
 	float4		*pf1, *pf2;
 	float8		*pd1, *pd2;
@@ -430,13 +391,7 @@ char			*msg2;
  *			- second message
  */	
 void
-cbn_or(flags, length, msg1, msg2)
-
-int4			flags;
-int4			length;
-char			*msg1;
-char			*msg2;
-
+cbn_or(int4 flags, int4 length, char *msg1, char *msg2)
 {
 	int4		*pi1, *pi2;
 
@@ -484,13 +439,7 @@ char			*msg2;
  *			- second message
  */	
 void
-cbn_xor(flags, length, msg1, msg2)
-
-int4			flags;
-int4			length;
-char			*msg1;
-char			*msg2;
-
+cbn_xor(int4 flags, int4 length, char *msg1, char *msg2)
 {
 	int4		*pi1, *pi2;
 
@@ -539,14 +488,7 @@ char			*msg2;
  *	Returns:	- # bytes full in first buffer
  */	
 int4
-cbn_cat(buf1, len1, nfull, buf2, len2)
-
-char			*buf1;
-int4			len1;
-int4			nfull;
-char			*buf2;
-int4			len2;
-
+cbn_cat(char *buf1, int4 len1, int4 nfull, char *buf2, int4 len2)
 {
 	int4		nbytes;
 
