@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  * 
- * $Id: f2cstring.c,v 6.4 2003/05/31 22:28:49 jsquyres Exp $
+ * $Id: f2cstring.c,v 6.5 2003/07/05 21:50:25 jsquyres Exp $
  *
  *	Function:	- create a C string from a F77 string
  *	Accepts:	- F77 string
@@ -27,11 +27,7 @@
 
 
 char *
-f2cstring(str, len)
-
-char			*str;
-unsigned int		len;
-
+f2cstring(char *str, int len)
 {
 	char		*cstr;
 	int		i;
