@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: few.c,v 6.6 2003/03/18 16:52:24 jsquyres Exp $
+ * $Id: few.c,v 6.7 2003/07/05 21:52:08 jsquyres Exp $
  * 
  *	Function:	- forks, execs and waits for a subordinate program
  *	Accepts:	- argument vector, argv[0] is program
@@ -28,6 +28,7 @@
 #include <lam_config.h>
 #include <laminternal.h>
 #include <sfh.h>
+#include <etc_misc.h>
 
 #if LAM_HAVE_BPROC
 
@@ -43,6 +44,7 @@ _lam_few(char *argv[])
 {
 	int		status;		/* exit status */
 	int		pid;		/* whoami? */
+        int             ret;
 
 	if ((pid = fork()) < 0) {
 		return(pid);
@@ -54,12 +56,24 @@ _lam_few(char *argv[])
     	}
 
 	else {				/* parent */
-
-		while ((waitpid(pid, &status, 0) != 0) &&
-				(! WIFEXITED(status)));
+          /* spin in waitpid until we get a valid entry.  If we get an
+             error that isn't going to go away, quit. */
+          while ((ret = waitpid(pid, &status, 0)) <= 0) {
+            if (ret < 0 && (errno == EFAULT || errno == EINVAL)) {
+              return -1;
+            }
+          }
 	}
 
-	return(WEXITSTATUS(status));
+        if (WIFEXITED(status)) {
+          ret = WEXITSTATUS(status);
+        } else if (WIFSIGNALED(status)) {
+          ret =  WTERMSIG(status);
+        } else {
+          ret = -1;
+        }
+
+        return ret;
 }
 
 
