@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -11,31 +11,25 @@
  * LAM/MPI source distribution.
  * 
  * $HEADER$
- *	Software for Humanity
- *	K&R
  *
- *	This program is freely distributed in the hope that it will be useful,
- *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- *
- *	$Id: itoa.c,v 6.3 2002/10/09 20:57:02 brbarret Exp $
+ * $Id: itoa.c,v 6.4 2003/07/05 21:50:25 jsquyres Exp $
  * 
  *	Function:	- K&R itoa()
  */
 
+#include <lam_config.h>
+
 #include <string.h>
 
+#include <sfh.h>
+
 /*
  * local functions
  */
-static void		reverse();
+static void reverse(char s[]);
 
 void
-sfh_itoa(n, s)
-
-char			*s;
-int			n;
-
+sfh_itoa(int n, char *s)
 {
 	int		i;
 	int		sign;
@@ -61,10 +55,7 @@ int			n;
  *	Accepts:	- string
  */
 static void
-reverse(s)
-
-char			s[];
-
+reverse(char s[])
 {
 	int		c;
 	int		i;
@@ -77,8 +68,11 @@ char			s[];
 	}
 }
 
+
+#if 0
 /*
  * backwards compatibility
  */
-void itoa(n, s) char *s; int n;
+void itoa(int n, char *s)
 { sfh_itoa(n, s); }
+#endif
