@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -11,20 +11,21 @@
  * LAM/MPI source distribution.
  * 
  * $HEADER$
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD
  *
- *	$Id: lamunix.c,v 6.8 2002/10/21 04:48:07 brbarret Exp $
+ * $Id: lamunix.c,v 6.9 2003/07/05 21:52:08 jsquyres Exp $
  * 
  *	Function:	- We make UNIX portable in here!
  *			- #ifdef'ing the universe is cool!
  */
 
 #include <lam_config.h>
+
 #include <signal.h>
 #include <stdlib.h>
 
+#include <laminternal.h>
+#include <etc_misc.h>
+
 /*
  *	_lam_signal
  *
