@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -11,11 +11,8 @@
  * LAM/MPI source distribution.
  * 
  * $HEADER$
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD
  *
- *	$Id: mpitr_com.c,v 6.4 2002/10/09 20:57:02 brbarret Exp $
+ * $Id: mpitr_com.c,v 6.5 2003/07/05 21:50:25 jsquyres Exp $
  * 
  *	Function:	- MPI communicator trace access functions
  */
@@ -31,11 +28,6 @@
 #include <typical.h>
 #include <t_types.h>
 
-/*
- * global functions
- */
-int			mpitr_comget();
-void			mpitr_comprint();
 
 /*
  * external functions
@@ -55,13 +47,7 @@ extern int		lam_rtrget();
  *	Returns:	- 0 or ERROR
  */
 int
-mpitr_comget(nodeid, pid, contextid, ptrcom)
-
-int4			nodeid;
-int4			pid;
-int4			contextid;
-char			**ptrcom;
-
+mpitr_comget(int4 nodeid, int4 pid, int4 contextid, char **ptrcom)
 {
 	struct trcid	*ptrc;		/* ptr cid trace */
 	int		trlen;		/* trace buffer length */
@@ -127,12 +113,7 @@ char			**ptrcom;
  *			- flag, on means show in GPS form
  */
 void
-mpitr_comprint(cid, trcom, showgps)
-
-int			cid;
-char			*trcom;
-int			showgps;
-
+mpitr_comprint(int cid, char *trcom, int showgps)
 {
 	int		collective;	/* is it a collective comm? */
 	int4		lsize;		/* size of 1st group */
