@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -11,26 +11,8 @@
  * LAM/MPI source distribution.
  * 
  * $HEADER$
- *	Ohio Trollius
- *	Copyright 1995 The Ohio State University
- *	RBD
  *
- *      $Id: nmsgconv.c,v 6.5 2002/10/09 20:57:03 brbarret Exp $
- *	
- * Revision 6.0  96/02/29  13:48:21  gdburns
- * Ohio Release
- * 
- * Revision 5.2.1.1  95/12/20  12:09:03  gdburns
- * Add DINT2MSG conversion.
- * 
- * Revision 5.2  94/08/22  13:57:06  gdburns
- * Ohio Release
- * 
- * Revision 5.1  94/05/18  10:56:59  gdburns
- * Ohio Release
- * 
- * Revision 2.3  94/04/22  12:35:04  gdburns
- * Ohio Release
+ * $Id: nmsgconv.c,v 6.6 2003/07/05 21:52:08 jsquyres Exp $
  * 
  *	Function:	- Trollius message byte order conversion routines
  *
@@ -43,6 +25,7 @@
 #include <portable.h>
 #include <net.h>
 #include <t_types.h>
+#include <etc_misc.h>
 
 /*
  *	_ltot_sysnmsg
