@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -11,10 +11,8 @@
  * LAM/MPI source distribution.
  * 
  * $HEADER$
- *	Ohio Trollius
  *
- *	Copyright 1995 The Ohio State University
- *	$Id: nodespin.c,v 6.5 2002/10/09 20:57:03 brbarret Exp $
+ * $Id: nodespin.c,v 6.6 2003/07/05 21:52:08 jsquyres Exp $
  *
  *	Function:	- pretty prints successive node ID messages
  */
@@ -23,6 +21,7 @@
 
 #include <args.h>
 #include <portable.h>
+#include <etc_misc.h>
 
 /*
  *	nodespin_init
