@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,11 +12,7 @@
  * 
  * $HEADER$
  *
- *	Ohio Trollius
- *	Copyright 1994 The Ohio State University
- *	RBD
- *
- *	$Id: prime.c,v 6.3 2002/10/09 20:57:03 brbarret Exp $
+ * $Id: prime.c,v 6.4 2003/07/05 21:50:25 jsquyres Exp $
  *
  *	Function:	- test and generate prime numbers
  *				- is_prime(): test is number is prime
@@ -25,6 +21,7 @@
 
 #include <portable.h>
 #include <typical.h>
+#include <etc_misc.h>
 
 /*
  *	is_prime
@@ -34,10 +31,7 @@
  *	Returns:	- TRUE or FALSE
  */
 int
-is_prime(n)
-
-int4			n;
-
+is_prime(int4 n)
 {
 	int4		i;		/* favourite counter */
 	int4		i_2;		/* i squared */
@@ -74,10 +68,7 @@ int4			n;
  *	Returns:	- a prime number or ERROR
  */
 int4
-next_prime(n)
-
-int4			n;
-
+next_prime(int4 n)
 {
 	if (n < 0) {
 		return((int4) ERROR);
