@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -11,11 +11,8 @@
  * LAM/MPI source distribution.
  * 
  * $HEADER$
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD
  *
- *	$Id: rev.c,v 6.4 2002/10/09 20:57:03 brbarret Exp $
+ * $Id: rev.c,v 6.5 2003/07/05 21:50:25 jsquyres Exp $
  * 
  *	Function:	- reverse byte ordering of data types
  *			- handles 4 and 8-byte types in fast manner
@@ -23,6 +20,7 @@
  */
 
 #include <portable.h>
+#include <t_types.h>
 
 /*
  *	rev4
@@ -33,11 +31,7 @@
  *			- ptr destination array
  */
 void
-rev4(src, dest)
-
-void			*src;
-void			*dest;
-
+rev4(void *src, void *dest)
 {
 	uint4		old;
 	uint4		*d;
@@ -62,11 +56,7 @@ void			*dest;
  *			- ptr destination array
  */
 void
-rev8(src, dest)
-
-void			*src;
-void			*dest;
-
+rev8(void *src, void *dest)
 {
 	uint4		old;
 	char		*d;
@@ -87,12 +77,7 @@ void			*dest;
  *			- # of bytes
  */
 void
-revn(src, dest, nbytes)
-
-void			*src;
-void			*dest;
-int			nbytes;
-
+revn(void *src, void *dest, int nbytes)
 {
 	char		temp;
 	char		*s, *d;
@@ -127,11 +112,7 @@ int			nbytes;
  *			- # elements in array
  */
 void
-mrev4(array, num)
-
-void			*array;
-int			num;
-
+mrev4(void *array, int num)
 {
 	uint4		old;
 	uint4		*d;
@@ -157,11 +138,7 @@ int			num;
  *			- # elements in array
  */
 void
-mrev8(array, num)
-
-void			*array;
-int			num;
-
+mrev8(void *array, int num)
 {
 	uint4		old;
 	uint4		tmp;
@@ -198,12 +175,7 @@ int			num;
  *			- # elements in array
  */
 void
-mrevn(array, size, num)
-
-void			*array;
-int			size;
-int			num;
-
+mrevn(void *array, int size, int num)
 {
 	char		*p, *s, *d;
 	char		temp;
@@ -230,10 +202,7 @@ int			num;
  *	Returns:	- word with reversed byte order
  */
 uint4
-rw(oword)
-
-uint4			oword;
-
+rw(uint4 oword)
 {
 	uint4		rword;
 
