@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: socket.c,v 1.10.2.4 2003/10/11 19:04:01 brbarret Exp $
+ * $Id: socket.c,v 1.15 2003/11/12 23:22:17 jsquyres Exp $
  *
  *	Function:	- socket utilities
  */
@@ -127,6 +127,7 @@ sfh_sock_open_clt_inet_stm(unsigned char *hostaddr, int portnum)
 {
 	int		sockd;		/* socket descriptor */
 	int		ret;		/* connect() return value */
+	int		errno_save;
 	struct sockaddr_in
 			srvaddr;	/* server address info */
 /*
@@ -156,8 +157,10 @@ sfh_sock_open_clt_inet_stm(unsigned char *hostaddr, int portnum)
 		if (ret == 0) {
 			return(sockd);
 		} else if (errno != EINTR) {
-			close(sockd);
-			return(-1);
+                  errno_save = errno;
+                  close(sockd);
+                  errno = errno_save;
+                  return(-1);
 		} else {
 			close(sockd);
 		}
@@ -286,13 +289,11 @@ sfh_sock_open_clt_unix_stm(char *addr)
         char *orig_dir;
         char *addr_dir;
         char *addr_file;
-
 /*
  * Set up address.
  */
 	memset(&server_un, 0, sizeof(server_un));
 	server_un.sun_family = AF_UNIX;
-
         /* In some cases, we may be trying to open a *really* long
            socket name.  And that may be longer that the size allowed
            by sockaddr_un.  So instead of trying to open the socket
@@ -319,8 +320,8 @@ sfh_sock_open_clt_unix_stm(char *addr)
 	strcpy(server_un.sun_path, addr_file);
 
 #if LAM_HAVE_SA_LEN
-	len = sizeof(server_un.sun_len) + sizeof(server_un.sun_family) +
-	  strlen(server_un.sun_path) + 1;
+	len = sizeof(server_un.sun_len) + sizeof(server_un.sun_family) + 
+          strlen(server_un.sun_path) + 1;
 	server_un.sun_len = len;
 #else
 	len = strlen(server_un.sun_path) + sizeof(server_un.sun_family);
@@ -581,10 +582,10 @@ sfh_sock_fill_inet_addr(unsigned char *hostaddr, int port,
  *			- size to set (bytes)
  */
 int
-sfh_sock_set_buf_size(int sd, int domain, int buf, int size)
+sfh_sock_set_buf_size(int sd, int domain, int buf, unsigned int size)
 {
     LAM_SOCK_OPTLEN_T 	optlen;
-    int			defsize = 0;
+    unsigned int defsize = 0;
 
     if (domain == SFH_UNIX) {
 #if LAM_BROKEN_SET_UNIX_SO_BUFSIZES
