@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -11,22 +11,20 @@
  * LAM/MPI source distribution.
  * 
  * $HEADER$
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	GDB
  *
- *	$Id: stoi.c,v 6.4 2002/10/09 20:57:04 brbarret Exp $
+ * $Id: stoi.c,v 6.5 2003/07/05 21:50:25 jsquyres Exp $
  *
  *	Function:	- convert decimal or hexadecimal string to integer
  */
 
-#include "lam.h"
+#include <lam_config.h>
+
+#include <lam.h>
+#include <laminternal.h>
+
 
 int4
-stoi(s)
-
-unsigned char		*s;
-
+stoi(unsigned char *s) 
 {
 	int4  		base;			/* base of digits */
 	int4  		i;			/* result */
