@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -11,11 +11,8 @@
  * LAM/MPI source distribution.
  * 
  * $HEADER$
- *	Ohio Trollius
- *	Copyright 1993 The Ohio State University
- *	RBD
  *
- *	$Id: ttime.c,v 1.4 2002/10/09 20:57:04 brbarret Exp $
+ * $Id: ttime.c,v 1.5 2003/07/05 21:50:25 jsquyres Exp $
  *
  *	Function:	- returns the contents of a system timer
  *			  expressed in seconds.
@@ -33,9 +30,13 @@
  *			  Research Foundation
  */
 
+#include <lam_config.h>
+
 #include <errno.h>
 #include <sys/time.h>
 
+#include <net.h>
+
 /*
  * ttime() returns the contents of the system timer (a measure
  * of time since an arbitrary but fixed point in time) expressed
@@ -43,7 +44,7 @@
  */
 
 double
-ttime()
+ttime(void)
 {
   struct timeval now;
   double sec;
