@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -11,11 +11,8 @@
  * LAM/MPI source distribution.
  * 
  * $HEADER$
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD
  *
- *	$Id: vctable.c,v 6.5 2002/10/09 20:57:04 brbarret Exp $
+ * $Id: vctable.c,v 6.6 2003/07/05 21:50:25 jsquyres Exp $
  *
  *	Function:	- manipulate the table of virtual circuits
  *
@@ -53,13 +50,7 @@ static struct vcdesc	vctable[VCMAX];		/* VC hash table */
  *	Returns:	- 0 or ERROR
  */
 int
-_vcinsert(node, event, type, path)
-
-int4			node;
-int4			event;
-int4			type;
-int4			path;
-
+_vcinsert(int4 node, int4 event, int4 type, int4 path)
 {
 	int4		i, j;		/* favourite indices */
 	struct vcdesc	*p;		/* favourite pointer */
@@ -135,12 +126,7 @@ int4			path;
  *	Returns:	- ptr to VC entry or NULL
  */
 struct vcdesc *
-_vcfind(node, event, type)
-
-int4			node;
-int4			event;
-int4			type;
-
+_vcfind(int4 node, int4 event, int4 type)
 {
 	int4		i, j;		/* favourite indices */
 	struct vcdesc	*p;		/* favourite pointer */
@@ -188,12 +174,7 @@ int4			type;
  *	Returns:	- 0 or ERROR
  */
 int
-_vcdelete(node, event, type)
-
-int4			node;
-int4			event;
-int4			type;
-
+_vcdelete(int4 node, int4 event, int4 type)
 {
 	struct vcdesc	*p;		/* favourite pointer */
 /*
@@ -217,8 +198,7 @@ int4			type;
  *	Function:	- free all virtual circuits
  */
 void
-_vcfree()
-
+_vcfree(void)
 {
 	int4		i;		/* favourite index */
 	struct vcdesc	*p;		/* favourite pointer */
