@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -15,7 +15,7 @@
  *	Copyright 1994 The Ohio State University
  *	GDB
  *
- *	$Id: rf77.c,v 6.6 2002/10/09 20:57:13 brbarret Exp $
+ *	$Id: rf77.c,v 6.7 2003/11/02 19:30:51 brbarret Exp $
  *
  *	Function:	- functions to support F77 I/O
  */
@@ -38,7 +38,7 @@ extern struct fclient	_ufd[FUMAX];	/* client file descriptor table */
 /*
  * external functions
  */
-extern int		_fdvalid();	/* check validity of file desc */
+extern int		_fdvalid(int);	/* check validity of file desc */
 
 /*
  *	rf77back
@@ -50,11 +50,7 @@ extern int		_fdvalid();	/* check validity of file desc */
  *	Returns:	- 0 or ERROR
  */
 int
-rf77back(fd, fmt)
-
-int			fd;
-char			fmt;
-
+lam_rf77back(int fd, char fmt)
 {
 	struct nmsg	nhead;		/* network message desc. */
 	struct freq	*request;	/* filed request */
@@ -120,13 +116,7 @@ char			fmt;
  *	Returns:	- actual length of record in file
  */
 int4
-rf77read(fd, buf, len, fmt)
-
-int			fd;
-char			*buf;
-int4			len;
-char			fmt;
-
+lam_rf77read(int fd, char *buf, int4 len, char fmt)
 {
 	struct nmsg	nhead;		/* network message desc. */
 	struct freq	*request;	/* filed request */
