@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -15,7 +15,7 @@
  *	Copyright 1996 The Ohio State University
  *	GDB/NJN
  *
- *	$Id: rfatexit.c,v 6.4 2002/10/09 20:57:13 brbarret Exp $
+ *	$Id: rfatexit.c,v 6.5 2003/11/02 19:30:51 brbarret Exp $
  *
  *	Function:	- close file descriptors
  *			- don't bother with standard I/O
@@ -30,13 +30,8 @@
 extern struct fclient	_ufd[];			/* client file descs */
 extern struct kio_t	_kio;			/* kernel IO block */
 
-/*
- * external functions
- */
-extern int		rfclose();
-
 void
-rfatexit()
+lam_rfatexit()
 {
     int			i;
     int			tfd;
@@ -59,3 +54,12 @@ rfatexit()
 	}
     }
 }
+
+
+/*
+ * backwards compatibility
+ */
+void rfatexit()
+{ 
+  lam_rfatexit();
+}
