@@ -10,8 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *
- *	$Id: rfclose.c,v 6.3.2.2 2003/01/17 20:39:31 brbarret Exp $
+ * $Id: rfclose.c,v 6.7 2003/04/10 17:50:47 jsquyres Exp $
  *
  *	Function:	- closes a file using remote filed
  *	Accepts:	- runtime file descriptor
@@ -23,25 +24,26 @@
 #include <ksignal.h>
 #include <net.h>
 #include <typical.h>
+#include <etc_misc.h>
 
 #include <errno.h>
 #include <unistd.h>
 
+
 /*
  * external variables
  */
 extern struct fclient	_ufd[FUMAX];	/* client file descriptor table */
 
+
 /*
  * external functions
  */
-extern int		_fdvalid();	/* check validity of file desc */
+extern int		_fdvalid(int fd); /* check validity of file desc */
+
 
 int
-lam_rfclose(fd)
-
-int			fd;
-
+lam_rfclose(int fd)
 {
 	struct nmsg	nhead;		/* network message desc. */
 	struct freq	*request;	/* filed request */
@@ -50,13 +52,15 @@ int			fd;
 /*
  * Do simple error checking.
  */
-	if (_fdvalid(fd)) return(LAMERROR);
+	if (_fdvalid(fd)) 
+          return(LAMERROR);
 
+        LAM_ZERO_ME(nhead);
 	request = (struct freq *) nhead.nh_data;
 	reply = (struct freply *) nhead.nh_data;
 
 	request->fq_src_node = getnodeid();
-	request->fq_src_event = -getpid();
+	request->fq_src_event = -lam_getpid();
 	request->fq_req = FQCLOSE;
 	request->fq_tfd = _ufd[fd].fu_tfd;
 
@@ -77,7 +81,7 @@ int			fd;
 		return(LAMERROR);
 	}
 
-	nhead.nh_event = -getpid();
+	nhead.nh_event = -lam_getpid();
 
 	if (nrecv(&nhead)) {
 		ksigsetmask(mask);
@@ -95,7 +99,11 @@ int			fd;
 	}
 }
 
+
 /*
  * backwards compatibility
  */
-int rfclose(fd) int fd; { return(lam_rfclose(fd)); }
+int rfclose(int fd)
+{ 
+  return(lam_rfclose(fd)); 
+}
