@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2003 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -10,8 +10,12 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
+ *	Ohio Trollius
+ *	Copyright 1997 The Ohio State University
+ *	GDB
  *
- *	$Id: rflseek.c,v 6.3.2.2 2003/01/17 20:39:31 brbarret Exp $
+ *	$Id: rflseek.c,v 6.6 2002/10/09 20:57:14 brbarret Exp $
  *
  *	Function:	- seeks on a file using remote filed
  *	Accepts:	- runtime file descriptor
@@ -25,6 +29,7 @@
 #include <ksignal.h>
 #include <net.h>
 #include <typical.h>
+#include <etc_misc.h>
 
 #include <errno.h>
 #include <unistd.h>
@@ -60,7 +65,7 @@ int			whence;
 	reply = (struct freply *) nhead.nh_data;
 
 	request->fq_src_node = getnodeid();
-	request->fq_src_event = -getpid();
+	request->fq_src_event = -lam_getpid();
 	request->fq_req = FQLSEEK;
 	request->fq_tfd = _ufd[fd].fu_tfd;
 	request->fq_offset = offset;
@@ -84,7 +89,7 @@ int			whence;
 		return(LAMERROR);
 	}
 
-	nhead.nh_event = -getpid();
+	nhead.nh_event = -lam_getpid();
 
 	if (nrecv(&nhead)) {
 		ksigsetmask(mask);
