@@ -10,11 +10,12 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB
  *
- *	$Id: rfopen.c,v 6.3.2.1 2002/10/09 19:48:55 brbarret Exp $
+ *	$Id: rfopen.c,v 6.5 2002/10/09 20:57:14 brbarret Exp $
  *
  *	Function:	- opens a file using remote filed
  *			- server nodeid may be specified by prefixing
@@ -35,6 +36,7 @@
 #include <net.h>
 #include <portable.h>
 #include <typical.h>
+#include <etc_misc.h>
 
 /*
  * external variables
@@ -77,7 +79,7 @@ int4			mode;
 	reply = (struct freply *) nhead.nh_data;
 
 	request->fq_src_node = getnodeid();
-	request->fq_src_event = -getpid();
+	request->fq_src_event = -lam_getpid();
 	request->fq_req = FQOPEN;
 	request->fq_mode = mode;
 	request->fq_flags = flags;
@@ -100,7 +102,7 @@ int4			mode;
 		return(LAMERROR);
 	}
 
-	nhead.nh_event = -getpid();
+	nhead.nh_event = -lam_getpid();
 	nhead.nh_length = 0;
 	nhead.nh_msg = 0;
 
