@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -15,7 +15,7 @@
  *	Copyright 1997 The Ohio State University
  *	GDB
  *
- *	$Id: rfread.c,v 6.6 2002/10/09 20:57:14 brbarret Exp $
+ *	$Id: rfread.c,v 6.7 2003/11/02 19:30:51 brbarret Exp $
  *
  *	Function:	- reads from a file using remote filed
  *	Accepts:	- runtime file descriptor
@@ -42,7 +42,7 @@ extern struct fclient	_ufd[FUMAX];	/* client file descriptor table */
 /*
  * external functions
  */
-extern int		_fdvalid();	/* check validity of file desc */
+extern int		_fdvalid(int);	/* check validity of file desc */
 
 int4
 lam_rfread(fd, buf, len)
@@ -130,5 +130,8 @@ int4			len;
 /*
  * backwards compatibility
  */
-int4 rfread(fd, buf, len) int fd; char *buf; int4 len;
-	{ return(lam_rfread(fd, buf, len)); }
+int4
+rfread(int fd, char *buf, int4 len)
+{
+  return(lam_rfread(fd, buf, len));
+}
