@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -15,7 +15,7 @@
  *	Copyright 1995 The Ohio State University
  *	GDB
  *
- *	$Id: rfsimplex.c,v 6.5 2002/10/09 20:57:14 brbarret Exp $
+ *	$Id: rfsimplex.c,v 6.6 2003/11/02 19:30:51 brbarret Exp $
  *
  *	Function:	- simple, basic, filed requests
  */
@@ -43,7 +43,7 @@ extern struct fclient	_ufd[FUMAX];	/* client file descriptor table */
 /*
  * external functions
  */
-extern int		_fdvalid();	/* check validity of file desc */
+extern int		_fdvalid(int);	/* check validity of file desc */
 extern int4		_makefreq();	/* make simple file request */
 extern char		*_fnparse();	/* parse nodeid from file name */
 
@@ -408,29 +408,80 @@ int			nfd;
 /*
  * backwards compatibility
  */
-int rfmkdir(fname, mode) CONST char *fname; int4 mode;
-	{ return(lam_rfmkdir(fname, mode)); }
-int rfaccess(fname, mode) CONST char *fname; int4 mode;
-	{ return(lam_rfaccess(fname, mode)); }
-int rfchdir(node, newdir) int4 node; CONST char *newdir;
-	{ return(lam_rfchdir(node, newdir)); }
-char *rfgetwd(node, currdir) int4 node; char *currdir;
-	{ return(lam_rfgetwd(node, currdir)); }
-int rfrmfd(node, tfd) int4 node, tfd;
-	{ return(lam_rfrmfd(node, tfd)); }
-int rfsystem(node, cmd) int4 node; CONST char *cmd;
-	{ return(lam_rfsystem(node, cmd)); }
-int rfunlink(fname) CONST char *fname;
-	{ return(lam_rfunlink(fname)); }
-int rfrmdir(fname) CONST char *fname;
-	{ return(lam_rfrmdir(fname)); }
-int rfftruncate(fd, len) int fd; int4 len;
-	{ return(lam_rfftruncate(fd, len)); }
-int rftruncate(fname, len) CONST char *fname; int4 len;
-	{ return(lam_rftruncate(fname, len)); }
-int rfincr(fd, amount) int fd; int4 amount;
-	{ return(lam_rfincr(fd, amount)); }
-int rfdup(ofd) int ofd;
-	{ return(lam_rfdup(ofd)); }
-int rfdup2(ofd, nfd) int ofd; int nfd;
-	{ return(lam_rfdup2(ofd, nfd)); }
+int
+rfmkdir(CONST char *fname, int4 mode)
+{
+  return(lam_rfmkdir(fname, mode)); 
+}
+
+int
+rfaccess(CONST char *fname, int4 mode)
+{
+  return(lam_rfaccess(fname, mode)); 
+}
+
+int
+rfchdir(int4 node, CONST char *newdir)
+{
+  return(lam_rfchdir(node, newdir)); 
+}
+
+char *
+rfgetwd(int4 node, char *currdir)
+{
+  return(lam_rfgetwd(node, currdir)); 
+}
+
+int
+rfrmfd(int4 node, int4 tfd)
+{
+  return(lam_rfrmfd(node, tfd)); 
+}
+
+int
+rfsystem(int4 node, CONST char *cmd)
+{
+  return(lam_rfsystem(node, cmd)); 
+}
+
+int
+rfunlink(CONST char *fname)
+{
+  return(lam_rfunlink(fname)); 
+}
+
+int
+rfrmdir(CONST char *fname)
+{ 
+  return(lam_rfrmdir(fname)); 
+}
+
+int
+rfftruncate(int fd, int4 len)
+{ 
+  return(lam_rfftruncate(fd, len)); 
+}
+
+int
+rftruncate(CONST char *fname, int4 len)
+{ 
+  return(lam_rftruncate(fname, len)); 
+}
+
+int
+rfincr(int fd, int4 amount)
+{
+  return(lam_rfincr(fd, amount)); 
+}
+
+int
+rfdup(int ofd)
+{ 
+  return(lam_rfdup(ofd)); 
+}
+
+int
+rfdup2(int ofd, int nfd)
+{
+  return(lam_rfdup2(ofd, nfd));
+}
