@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -15,7 +15,7 @@
  *	Copyright 1997 The Ohio State University
  *	NJN
  *
- *	$Id: rfstat.c,v 6.9 2002/10/09 20:57:14 brbarret Exp $
+ *	$Id: rfstat.c,v 6.10 2003/11/02 19:30:52 brbarret Exp $
  *
  *	Function:	- rffstat() and rfstat()
  *			- get file status
@@ -39,14 +39,15 @@ extern struct fclient	_ufd[FUMAX];	/* client file descriptor table */
 /*
  * external functions
  */
-extern int		_fdvalid();	/* check validity of file desc */
+extern int		_fdvalid(int);	/* check validity of file desc */
 extern int4		_makefreq();	/* make simple file request */
 extern char		*_fnparse();	/* parse nodeid from file name */
 
 /*
  * local functions
  */
-static void		conv_stat();	/* convert to status structure */
+/* convert to status structure */
+static void		conv_stat(struct stat *status, uint4 *buf);
 
 /*
  *	lam_rfstat
@@ -57,11 +58,7 @@ static void		conv_stat();	/* convert to status structure */
  *	Returns:	- 0 or ERROR
  */
 int
-lam_rfstat(fname, status)
-
-CONST char		*fname;
-char			*status;
-
+lam_rfstat(CONST char *fname, char *status)
 {
 	int4		node;			/* server node ID */
 	int4		len;
@@ -91,11 +88,7 @@ char			*status;
  *	Returns:	- 0 or ERROR
  */
 int
-lam_rffstat(fd, status)
-
-int			fd;
-char			*status;
-
+lam_rffstat(int fd, char *status)
 {
 	uint4		buf[17];
 	int		ret;
@@ -146,11 +139,7 @@ stuff_buff(char *src, int src_size, char *dest, int dest_size)
  *			- ptr to int4 array
  */
 static void
-conv_stat(status, buf)
-
-struct stat		*status;
-uint4			*buf;
-
+conv_stat(struct stat *status, uint4 *buf)
 {
 #if LAM_STAT_MEMBERS_INT4
 	status->st_dev = buf[0];
@@ -190,7 +179,14 @@ uint4			*buf;
 /*
  * backwards compatibility
  */
-int rfstat(fname, status) CONST char *fname; char *status;
-	{ return(lam_rfstat(fname, status)); }
-int rffstat(fd, status) int fd; char *status;
-	{ return(lam_rffstat(fd, status)); }
+int
+rfstat(CONST char *fname, char *status)
+{
+  return(lam_rfstat(fname, status));
+}
+
+int
+rffstat(int fd, char *status)
+{
+  return(lam_rffstat(fd, status)); 
+}
