@@ -55,8 +55,7 @@ lam_impi_datasync_handler(MPI_Request req)
   IMPI_Uint8 *buf;
   MPI_Request ack = MPI_REQUEST_NULL;
 
-  DBUG("LAM rank in lam_impi_ping_ack_handler: req 0x%x\n", 
-       (unsigned int) req);
+  DBUG("LAM rank in lam_impi_ping_ack_handler: req %p\n", req);
 
   if ((req->rq_flags & LAM_RQFACKDONE) != 0 ||
       (req->rq_flags & LAM_RQFCANCEL) != 0)
@@ -81,7 +80,7 @@ lam_impi_datasync_handler(MPI_Request req)
     return(err);
 
   DBUG("LAM rank queued up an ACK to go back to the IMPID: %lld\n", *buf);
-  DBUG("LAM ACK req: 0x%x\n", (unsigned int) ack);
+  DBUG("LAM ACK req: %p\n", ack);
   
   if (lam_rq_flblock == 1) {
     DBUG("LAM rank queued ACK to be blocking\n");
@@ -112,8 +111,7 @@ lam_impi_datasync_handler(MPI_Request req)
 static int
 lam_impi_datasync_done_handler(MPI_Request req)
 {
-  DBUG("LAM rank In lam_impi_ping_ack_done_handler: 0x%x\n", 
-       (unsigned int) req);
+  DBUG("LAM rank In lam_impi_ping_ack_done_handler: %p\n", req);
   if (req->rq_extra != 0) 
     ((MPI_Request) req->rq_extra)->rq_extra = 0;
 
