@@ -10,8 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *
- *	$Id: ifinalize.c,v 1.10.2.1 2002/10/09 19:48:56 brbarret Exp $
+ *	$Id: ifinalize.c,v 1.12 2002/10/09 20:57:17 brbarret Exp $
  *
  *	Function:	- finalize an IMPI job
  */
@@ -34,7 +35,7 @@
 #include <rpisys.h>
 #include <impi-defs.h> /* This file supplied by IMPI server package */
 #include <impi.h>
-#include <debug.h>
+#include <lamdebug.h>
 #include <mpisys.h>
 #include <all_hash.h>
 
