@@ -10,8 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *
- *	$Id: ihelpers.c,v 1.4.2.1 2002/10/09 19:48:56 brbarret Exp $
+ *	$Id: ihelpers.c,v 1.6 2002/10/09 20:57:17 brbarret Exp $
  *
  *	Function:	- utility functions for the IMPI collectives
  *                      - NOTE: some of these functions lack
@@ -38,7 +39,7 @@
 #include <mpisys.h>
 #include <impi-defs.h> /* This file supplied by IMPI server package */
 #include <impi.h>
-#include <debug.h>
+#include <lamdebug.h>
 #include <mpi.h>
 
 
