@@ -126,30 +126,10 @@ IMPI_Init(int *world_n, int *cid, struct _gps **worlds)
     DBUG("Got impid args: %s %s\n", server_string, rank_string);
     free((char *) msg.nh_msg);
 
-/*
- * These first two options will likely only work for Llamas.  :-)
- */
-    if (getenv("LAM_IMPI_DEBUG_IMPID") != NULL) {
-      cmd = "workshop";
-      spawn_argv[spawn_count++] = NULL;
-      free(rank_string);
-      free(server_string);
-    } else if (getenv("LAM_IMPI_BCHECK_IMPID") != NULL) {
-      cmd = "/opt/SUNWspro.forte6/bin/bcheck";
-      spawn_argv[spawn_count++] = strdup("-all");
-      spawn_argv[spawn_count++] = strdup("/afs/nd.edu/user2/jsquyres/jeff/62b-local/sparc-sun-solaris2.7/bin/impid");
-      spawn_argv[spawn_count++] = rank_string;
-      spawn_argv[spawn_count++] = server_string;
-      spawn_argv[spawn_count++] = NULL;
-/*
- * This is the general case
- */
-    } else {
-      cmd = "impid";
-      spawn_argv[spawn_count++] = rank_string;
-      spawn_argv[spawn_count++] = server_string;  
-      spawn_argv[spawn_count++] = NULL;
-    }
+    cmd = "impid";
+    spawn_argv[spawn_count++] = rank_string;
+    spawn_argv[spawn_count++] = server_string;  
+    spawn_argv[spawn_count++] = NULL;
 
     DBUG("Spawning: %s ", cmd);
     for (i = 0; i < spawn_count; i++)
@@ -257,7 +237,7 @@ IMPI_Init(int *world_n, int *cid, struct _gps **worlds)
     free(lam_impi_clients);
     return LAMERROR;
   }
-  DBUG("Receiving: %d ints of clients, %d ints of hosts, and %d ints of procs\n",
+  DBUG("Receiving: %lu ints of clients, %lu ints of hosts, and %lu ints of procs\n",
        sizeof(IMPI_client) / 4 * impi_server_info.nclients,
        sizeof(IMPI_host) / 4 * impi_server_info.nhosts,
        sizeof(IMPI_proc) / 4 * impi_server_info.nprocs);
@@ -435,8 +415,8 @@ set_proc(int i, struct _gps* g)
   (*g).gps_grank = i;
 
   p = lam_procadd(g);
-  DBUG("Adding in IMPID proxy for rank %d: 0x%x (lam_impid_proc 0x%x)\n", 
-       i, (unsigned int) p, (unsigned int) lam_impid_proc);
+  DBUG("Adding in IMPID proxy for rank %d: %p (lam_impid_proc %p)\n", 
+       i, p, lam_impid_proc);
 
   /* Have to do a little more mucking around here since we joined the
      game late */
