@@ -10,8 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *
- *	$Id: ilsend.c,v 1.12.2.1 2002/10/09 19:48:56 brbarret Exp $
+ *	$Id: ilsend.c,v 1.14 2002/10/09 20:57:17 brbarret Exp $
  *
  *	Function:	- in the case of the msg being for an IMPI host send 
  *                        to the impid the meta-info in an IMPI_Lamgiappe msg
@@ -33,7 +34,7 @@
 #include <mpisys.h>
 #include <rpisys.h>
 #include <blktype.h>
-#include <debug.h>
+#include <lamdebug.h>
 
 
 /*
