@@ -10,8 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *
- *	$Id: imk_dtype.c,v 1.7.2.1 2002/10/09 19:48:56 brbarret Exp $
+ *	$Id: imk_dtype.c,v 1.9 2002/10/09 20:57:17 brbarret Exp $
  *
  *	Function:	Make a datatype for IMPI meta messages
  *                      
@@ -29,7 +30,7 @@
 #include <typical.h>
 #include <kreq.h>
 #include <events.h>
-#include <debug.h>
+#include <lamdebug.h>
 #include <impi-defs.h>
 #include <impi.h>
 
