@@ -10,8 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *
- *	$Id: lamgiappe.c,v 1.4.2.1 2002/10/09 19:48:57 brbarret Exp $
+ *	$Id: lamgiappe.c,v 1.6 2002/10/09 20:57:17 brbarret Exp $
  *
  *	Function:	- in the case of the msg being for an IMPI host send 
  *                        to the impid the meta-info in an IMPI_Lamgiappe msg
@@ -29,7 +30,7 @@
 
 #include <impi-defs.h> /* This file supplied by IMPI server package */
 #include <impi.h>
-#include <debug.h>
+#include <lamdebug.h>
 #include <mpi.h>
 #include <mpisys.h>
 #include <rpisys.h>
