@@ -10,8 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *
- *	$Id: regdatasync.c,v 1.1.2.1 2002/10/09 19:48:57 brbarret Exp $
+ *	$Id: regdatasync.c,v 1.3 2002/10/09 20:57:18 brbarret Exp $
  *
  *	Function:	- post a receive for a ping from the impid
  */
@@ -24,7 +25,7 @@
 #include <mpi.h>
 #include <mpisys.h>
 #include <rpisys.h>
-#include <debug.h>
+#include <lamdebug.h>
 
 /*
  * local variables
