@@ -10,8 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *
- *	$Id: regdatasyncinit.c,v 1.2.2.1 2002/10/09 19:48:57 brbarret Exp $
+ *	$Id: regdatasyncinit.c,v 1.4 2002/10/09 20:57:18 brbarret Exp $
  *
  *	Function:	- post a receive for a ping from the impid
  */
@@ -25,7 +26,7 @@
 #include <mpi.h>
 #include <mpisys.h>
 #include <rpisys.h>
-#include <debug.h>
+#include <lamdebug.h>
 
 
 /*
