@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2006 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,8 +12,6 @@
  * 
  * $HEADER$
  *
- *	$Id: MPISYSF.h,v 6.14 2003/11/06 18:22:48 jsquyres Exp $
- *
  *	Function:	- F77 wrappers for MPI library
  */
 
@@ -2001,14 +1999,14 @@ extern void		MPI_F_COMM_DUP_FN();
 extern void		MPI_F_TYPE_DUP_FN();
 extern void		MPI_F_WIN_DUP_FN();
 
-extern void		mpi_null_copy_fn_();
-extern void		mpi_null_delete_fn_();
-extern void		mpi_comm_null_copy_fn_();
-extern void		mpi_comm_null_delete_fn_();
-extern void		mpi_type_null_copy_fn_();
-extern void		mpi_type_null_delete_fn_();
-extern void		mpi_win_null_copy_fn_();
-extern void		mpi_win_null_delete_fn_();
+extern void		mpi_null_copy_fn_(void);
+extern void		mpi_null_delete_fn_(void);
+extern void		mpi_comm_null_copy_fn_(void);
+extern void		mpi_comm_null_delete_fn_(void);
+extern void		mpi_type_null_copy_fn_(void);
+extern void		mpi_type_null_delete_fn_(void);
+extern void		mpi_win_null_copy_fn_(void);
+extern void		mpi_win_null_delete_fn_(void);
 
 #ifdef __cplusplus
 }
