@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- *	$Id: freq.h,v 6.7 2003/03/11 00:46:31 jsquyres Exp $
+ *	$Id: freq.h,v 6.9 2003/11/02 19:30:52 brbarret Exp $
  *
  *	Function:	- filed request/reply templates and constants
  *
@@ -23,6 +23,7 @@
 
 #include <lam_config.h>
 #include <portable.h>
+#include <sys/param.h>
 
 /*
  * the bread and butter request codes
@@ -58,13 +59,14 @@
 #define FQFTRUNC	(19)
 #define FQOPENFD	(20)
 #define FQPATHFIND	(21)
+#define FQRENAME        (22)
 
 /*
  * requests for F77
  */
-#define FQF77READ	(22)
-#define FQF77BACK	(23)
-#define FQMAX		(24)		/* # of valid requests */
+#define FQF77READ	(23)
+#define FQF77BACK	(24)
+#define FQMAX		(25)		/* # of valid requests */
 
 /*
  * Trollius specific open flags
@@ -169,10 +171,18 @@ struct fstate {
 	char		fs_name[24];	/* file name */
 };
 
+struct fqrename {
+  char source[MAXPATHLEN];
+  char dest[MAXPATHLEN];
+};
+
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
+extern int              lam_rf77back __ARGS((int fd, char fmt));
+extern int4             lam_rf77read __ARGS((int fd, char *buf, int4 len, char fmt));
 extern char		*lam_rfgetwd __ARGS((int4 node, char *dir));
 extern int		lam_rfaccess __ARGS((const char *fname, int4 mode));
 extern int		lam_rfchdir __ARGS((int4 node, const char *dir));
@@ -187,6 +197,8 @@ extern int		lam_rfopen __ARGS((const char *fname,
 					int4 flags, int4 mode));
 extern char *		lam_rfpathfind __ARGS((const char *fname, 
 					       const char *cwd, int nodeid));
+extern int		lam_rfrename __ARGS((const char *rffrom, 
+					     const char *rfto));
 extern int		lam_rfrmdir __ARGS((const char *fname));
 extern int		lam_rfrmfd __ARGS((int4 node, int4 tfd));
 extern int		lam_rfstat __ARGS((const char *fname, char *status));
@@ -201,9 +213,37 @@ extern int4		lam_rfwrite __ARGS((int fd, const char *buf,
 					int4 len));
 extern int4		_lam_rfwrite __ARGS((int4 node, int4 tfd, int4 tflags,
 					const char *buf, int4 len));
-extern void		rfatexit __ARGS((void));
+extern void		lam_rfatexit __ARGS((void));
 extern int		lam_lfopenfd __ARGS((char *server));
 
+  /*
+   * Backward compatibility
+   */
+extern int		rfaccess __ARGS((const char *fname, int4 mode));
+extern void		rfatexit __ARGS((void));
+extern int		rfclose __ARGS((int fd));
+extern int		rffstat __ARGS((int fd, char *status));
+extern char		*rfgetwd __ARGS((int4 node, char *dir));
+extern int		rfaccess __ARGS((const char *fname, int4 mode));
+extern int		rfchdir __ARGS((int4 node, const char *dir));
+extern int		rfdup __ARGS((int fd));
+extern int		rfdup2 __ARGS((int fd, int newfd));
+extern int4		rflseek __ARGS((int fd, int4 offset, int whence));
+extern int		rfmkdir __ARGS((const char *fname, int4 mode));
+extern int		rfftruncate __ARGS((int fd, int4 len));
+extern int		rfincr __ARGS((int fd, int4 amount));
+extern int		rfopen __ARGS((const char *fname,
+					int4 flags, int4 mode));
+extern int4		rfread __ARGS((int fd, char *buf, int4 len));
+extern int		rfrmdir __ARGS((const char *fname));
+extern int		rfrmfd __ARGS((int4 node, int4 tfd));
+extern int		rfstat __ARGS((const char *fname, char *status));
+extern int		rfsystem __ARGS((int4 node, const char *cmd));
+extern int		rftruncate __ARGS((const char *fname, int4 len));
+extern int4		rfwrite __ARGS((int fd, const char *buf,
+					int4 len));
+extern int		rfunlink __ARGS((const char *fname));
+
 #ifdef __cplusplus
 }
 #endif
