@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- *	$Id: kreq.h,v 6.11.2.1 2004/02/04 03:21:29 jsquyres Exp $
+ * $Id: kreq.h,v 6.14 2004/02/04 03:06:21 jsquyres Exp $
  *
  *	Function:	- kernel request constants and templates
  */
@@ -182,7 +182,8 @@ struct kproc {
 extern "C" {
 #endif
 
-extern int		atkexit(void (*exitfunc)(), char *arg);
+extern void             kboot(int *argc, char **argv);
+extern int		atkexit(void (*exitfunc)(void), char *arg);
 extern int		kattach(int pri);
 extern int		kbgetpid(void);
 extern int		kcreate(const char *path, char **argv);
@@ -204,6 +205,14 @@ extern void		kexit(int status);
 extern void		_kexit(int status);
 extern void             lam_kexit(int status);
 
+extern void             _ksig_follow(void);
+extern void             _ksig_init(void);
+
+#if LAM_FORTRANNOUNDERSCORE
+#else
+extern void             kpause_(void);
+#endif
+
 #ifdef __cplusplus
 }
 #endif
