@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- *	$Id: lamnet.h,v 6.12 2003/04/04 04:38:16 vsahay Exp $
+ *	$Id: lamnet.h,v 6.13 2003/07/31 03:04:17 jsquyres Exp $
  * 
  *	Function:	- LAM network description
  */
@@ -39,7 +39,7 @@
  */
 #define DEFTHBOOT	"hboot"
 #define DEFTTKILL	"tkill"
-#define DEFTWIPE	"wipe"
+#define DEFTWIPE	"lamwipe"
 
 
 /* 
