@@ -110,6 +110,15 @@ typedef int	(MPI_Win_delete_attr_function)();
 #define MPI_GRAPH		2		/* graph topology */
 #define MPI_KEYVAL_INVALID	-1		/* invalid key value */
 
+/*
+ * one-sided constants
+ */
+#define MPI_MODE_NOCHECK             0
+#define MPI_MODE_NOPRECEDE           0
+#define MPI_MODE_NOPUT               0
+#define MPI_MODE_NOSTORE             0
+#define MPI_MODE_NOSUCCEED           0
+
 /*
  * Predefined attribute keyvals
  */
@@ -398,6 +407,28 @@ extern MPI_Fint			*MPI_F_STATUSES_IGNORE;
 #define MPI_LONG_LONG_INT	((MPI_Datatype) &lam_mpi_long_long_int)
 #define MPI_UNSIGNED_LONG_LONG	((MPI_Datatype) &lam_mpi_unsigned_long_long)
 
+#define MPI_INTEGER             ((MPI_Datatype) &lam_mpi_integer)
+#define MPI_INTEGER1            ((MPI_Datatype) &lam_mpi_integer1)
+#define MPI_INTEGER2            ((MPI_Datatype) &lam_mpi_integer2)
+#define MPI_INTEGER4            ((MPI_Datatype) &lam_mpi_integer4)
+#define MPI_INTEGER8            ((MPI_Datatype) &lam_mpi_integer8)
+#define MPI_INTEGER16           ((MPI_Datatype) &lam_mpi_integer16)
+#define MPI_REAL                ((MPI_Datatype) &lam_mpi_real)
+#define MPI_REAL4               ((MPI_Datatype) &lam_mpi_real4)
+#define MPI_REAL8               ((MPI_Datatype) &lam_mpi_real8)
+#define MPI_REAL16              ((MPI_Datatype) &lam_mpi_real16)
+#define MPI_COMPLEX8            ((MPI_Datatype) &lam_mpi_complex8)
+#define MPI_COMPLEX16           ((MPI_Datatype) &lam_mpi_complex16)
+#define MPI_COMPLEX32           ((MPI_Datatype) &lam_mpi_complex32)
+#define MPI_DOUBLE_PRECISION    ((MPI_Datatype) &lam_mpi_dblprec)
+#define MPI_CHARACTER           ((MPI_Datatype) &lam_mpi_character)
+#define MPI_LOGICAL             ((MPI_Datatype) &lam_mpi_logic)
+#define MPI_COMPLEX             ((MPI_Datatype) &lam_mpi_cplex)
+#define MPI_DOUBLE_COMPLEX      ((MPI_Datatype) &lam_mpi_dblcplex)
+#define MPI_2INTEGER            ((MPI_Datatype) &lam_mpi_2integer)
+#define MPI_2REAL               ((MPI_Datatype) &lam_mpi_2real)
+#define MPI_2DOUBLE_PRECISION   ((MPI_Datatype) &lam_mpi_2dblprec)
+
 #define MPI_ERRORS_ARE_FATAL	((MPI_Errhandler) &lam_mpi_errors_are_fatal)
 #define MPI_ERRORS_RETURN	((MPI_Errhandler) &lam_mpi_errors_return)
 
