@@ -18,6 +18,12 @@
 
 class Intracomm : public Comm {
 public:
+#if LAM_WANT_PROFILE
+  friend class MPI::Win;
+#if LAM_WANT_CPPFILE
+  friend class MPI::File;
+#endif
+#endif
 
   // construction
   Intracomm() { }
