@@ -27,7 +27,7 @@ public:
   Comm_Null(const MPI_Comm& data) : mpi_comm(data) { }
 
   // destruction
-  //JGS  virtual ~Comm_Null() { }
+  virtual ~Comm_Null() { }
 
   inline Comm_Null& operator=(const Comm_Null& data) {
     mpi_comm = data.mpi_comm; 
