@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2004 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: mpisys.h,v 6.57.2.2 2003/08/28 23:04:56 jsquyres Exp $
+ * $Id: mpisys.h,v 6.64 2004/03/02 03:43:26 jsquyres Exp $
  *
  *	Function:	- MPI system header file
  *			- the real meat is here
@@ -52,7 +52,14 @@
  * and should not be visible to C MPI user code.
  */
 #define	MPI_F_INTEGER		((MPI_Datatype) &lam_mpi_integer)
+#define MPI_F_INTEGER1          ((MPI_Datatype) &lam_mpi_integer1) 
+#define MPI_F_INTEGER2          ((MPI_Datatype) &lam_mpi_integer2)
+#define MPI_F_INTEGER4          ((MPI_Datatype) &lam_mpi_integer4)
+#define MPI_F_INTEGER8          ((MPI_Datatype) &lam_mpi_integer8)
 #define	MPI_F_REAL		((MPI_Datatype) &lam_mpi_real)
+#define MPI_F_REAL4             ((MPI_Datatype) &lam_mpi_real4)
+#define MPI_F_REAL8             ((MPI_Datatype) &lam_mpi_real8)
+#define MPI_F_REAL16            ((MPI_Datatype) &lam_mpi_real16)
 #define	MPI_F_DOUBLE_PRECISION	((MPI_Datatype) &lam_mpi_dblprec)
 #define	MPI_F_CHARACTER		((MPI_Datatype) &lam_mpi_character)
 #define	MPI_F_LOGICAL		((MPI_Datatype) &lam_mpi_logic)
@@ -78,7 +85,7 @@ typedef void (MPI_F_copy_function)(int *, int *, int *,
     					int *, int *, int *, int *);
 typedef void (MPI_F_delete_function)(int *, int *, int *, int *, int *);
 
-typedef void (void_fn)(void); 
+typedef void (*lam_void_fn_t)(void); 
 
 /*
  * One sided communication.
@@ -161,6 +168,7 @@ struct _comm {
 #define LAM_CIMPI	0x80			/* IMPI communicators */
 #define LAM_CHOMOG	0x100			/* this comm is endian homog */
 #define LAM_CHIDDEN	0x200			/* hidden communications */
+#define LAM_RBASIC      0x400                   /* lam_basic req - intercomm */
 	int		c_contextid;		/* context ID */
 	int		c_refcount;		/* reference count */
 	MPI_Group	c_group;		/* local group */
@@ -184,8 +192,18 @@ struct _comm {
         MPI_Comm        c_shadow;               /* shadow com for IMPI comms */
         long            c_reserved[4];          /* used in IMPI :-( */
 
-        lam_ssi_coll_actions_t  c_ssi_coll;
+        lam_ssi_coll_actions_1_1_0_t  c_ssi_coll;
         struct lam_ssi_coll_data *c_ssi_coll_data;
+        struct lam_ssi_coll_lam_basic_data *c_ssi_coll_lam_basic_data;
+
+  /* Store lam_basic_finalize pointer because we need to call 
+     lam_basic_finalize() whenever a module needs support of lam_basic.  This
+     typically happens in case of intercommunicators which need support
+     from lam_basic (local communicator that gets created in lam_basic).
+     lam_basic_finalize() should be called to destroy this local communicator
+     and free the local structure
+  */
+        lam_ssi_coll_finalize_fn_t lsca_basic_finalize;
 };
 
 struct _osdhdr {
@@ -241,8 +259,8 @@ struct _errhdl {
 };
 
 struct _attrkey {
-	void_fn		*ak_copy;		/* copy function */
-	void_fn		*ak_del;		/* delete function */
+	lam_void_fn_t	ak_copy;		/* copy function */
+	lam_void_fn_t	ak_del;		/* delete function */
 	void		*ak_extra;		/* extra info */
 	int		ak_refcount;		/* reference count */
 	int		ak_flags;		/* properties */
@@ -351,6 +369,7 @@ extern int lam_tv_comm_seqnum;
  * state checking macros
  */
 #define	LAM_IS_INTER(c)	((c)->c_flags & LAM_CINTER)	/* is an intercomm */
+#define LAM_REQ_COLL_BASIC(c) ((c)->c_flags & LAM_RBASIC)
 #define LAM_IS_INTRA(c) (!((c)->c_flags & LAM_CINTER))	/* is an intracomm */
 #if LAM_WANT_IMPI
 #define LAM_IS_IMPI(c)  ((c)->c_shadow != 0)            /* is an IMPI comm */
@@ -467,6 +486,7 @@ extern int lam_tv_comm_seqnum;
 #define MPI_Allreduce			PMPI_Allreduce 
 #define MPI_Alltoall			PMPI_Alltoall 
 #define MPI_Alltoallv			PMPI_Alltoallv 
+#define MPI_Alltoallw                   PMPI_Alltoallw
 #define MPI_Attr_delete			PMPI_Attr_delete 
 #define MPI_Attr_get			PMPI_Attr_get 
 #define MPI_Attr_put			PMPI_Attr_put 
@@ -526,6 +546,7 @@ extern int lam_tv_comm_seqnum;
 #define MPI_Errhandler_set		PMPI_Errhandler_set 
 #define MPI_Error_class			PMPI_Error_class 
 #define MPI_Error_string		PMPI_Error_string 
+#define MPI_Exscan                      PMPI_Exscan
 #define MPI_Finalize			PMPI_Finalize 
 #define MPI_Finalized			PMPI_Finalized
 #define MPI_Free_mem			PMPI_Free_mem
@@ -697,6 +718,10 @@ extern "C" {
 extern void	lam_band __ARGS((void *, void *, int *, MPI_Datatype *));
 extern void	lam_bkerr __ARGS((int, int *, int *, int *));
 extern void	lam_bor __ARGS((void *, void *, int *, MPI_Datatype *));
+extern int	lam_bottom_dtsnd __ARGS((void *, int, MPI_Datatype,
+				   void *, int, MPI_Datatype, int, MPI_Comm));
+extern int	lam_bottom_dtrcv __ARGS((void *, int, MPI_Datatype,
+				void *, int, MPI_Datatype, int, MPI_Comm));
 extern int	lam_bufattach __ARGS((void *, int));
 extern int	lam_bufdetach __ARGS((void *, int *));
 extern int	lam_buffreebsend_ __ARGS((MPI_Request));
@@ -765,8 +790,8 @@ extern int	lam_isend __ARGS((void *, int, MPI_Datatype, int,
 				int, MPI_Comm, MPI_Request *, int));
 extern int      lam_get_proc_array __ARGS((struct _gps **, int *, int *, 
 					   int *, int));
-extern int	lam_keyval_create __ARGS((void_fn *, void_fn *, int *,
-					void *, int));
+extern int	lam_keyval_create __ARGS((lam_void_fn_t, lam_void_fn_t,
+                                          int *, void *, int));
 extern void	lam_land __ARGS((void *, void *, int *, MPI_Datatype *));
 extern int	lam_linit __ARGS((int, char **, char *, int *, int *, int *, 
 				struct _gps **, int *));
@@ -939,7 +964,7 @@ extern int	_rpi_c2c_free_mem __ARGS((void *base));
  * Fortran support
  */
 
-#define LAM_MAXF77PREDEF	48		/* max # predef. F77 handles */
+#define LAM_MAXF77PREDEF	55	/* max # predef. F77 handles */
 #define LAM_TYPETBLSIZE		256		/* initial handle table size */
 
 /*
