@@ -1,35 +1,18 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
- * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *
- *	$Id: preq.h,v 6.6 1999/09/11 18:18:20 jsquyres Exp $
+ *	$Id: preq.h,v 6.11 2003/03/10 18:05:27 brbarret Exp $
  *
  *	Function:	- constants and templates for the
  *			  process control server (aka kenya)
@@ -45,20 +28,33 @@
 #include "kreq.h"
 #include "portable.h"
 
+/*
+ * Events recogized by the kenyad
+ */
 #define PQCREATE	1			/* create a process in place */
 #define PQDOOM		2			/* doom a process */
 #define PQSTATE		3			/* find state of a process */
 #define PQSPAWN		4			/* spawn an existing process */
 #define PQDETACH	5			/* detach an existing process */
 #define PQATTACH	6			/* attach an existing process */
-#define PREQS		6			/* number of kenya requests */
+#define PQDEATHNOTICE   7                       /* The kenyad signal
+                                                 *  handler got a
+                                                 *  SIGCHLD, and sent
+                                                 *  us a report.
+                                                 *  SHOULD NOT BE USED
+                                                 *  OUTSIDE THE KENYAD
+                                                 *  AND ITS SIGNAL
+                                                 *  HANDLER FOR
+                                                 *  SIGCHLD! 
+						 */
+#define PREQS		7			/* number of kenya requests */
 
 #ifndef NOTPROCESS
 #define NOTPROCESS	0x80000000
 #endif
 #define NOTSTATUS	0x80000000
 #define PSMAXNAME	256
-#define PMAX		80
+#define PMAX		256
 
 /*
  * process request selection flags
@@ -70,6 +66,16 @@
 #define SELECT_SYS	0x20
 #define SELECT_APPL	0x40
 
+/*
+ * exit status handling
+ */
+#define _LAM_WIFSIGNALED	0x10000
+#define _LAM_WIFNODETACH	0x20000
+#define LAM_WIFSIGNALED(s)	((s) & _LAM_WIFSIGNALED)
+#define LAM_WIFNODETACH(s)	((s) & _LAM_WIFNODETACH)
+#define LAM_WTERMSIG(s)		((s) & 0xFFFF)
+#define LAM_WEXITSTATUS(s)	LAM_WTERMSIG(s)
+
 /*
  * kenyad request
  */
