@@ -40,5 +40,7 @@
 
 #define	PRCMD		1095
 #define	PRDOOM		1095
+/* see note in otb/sys/kernel/kkill.c */
+#define PRLAMHALT       1094
 
 #endif
