@@ -10,8 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *
- *	$Id: typical.h,v 6.4.2.1 2002/10/09 19:49:01 brbarret Exp $
+ *	$Id: typical.h,v 6.6 2002/10/09 20:57:26 brbarret Exp $
  *
  *	Function:	- typically used constants and macros
  */
@@ -27,12 +28,12 @@
 #define TRUE		1
 #endif
 
-#ifndef ERROR
-#define ERROR		-1
-#endif
-
 #define LAMERROR	-1
 
+#ifndef ERROR
+#define ERROR		LAMERROR
+#endif
+
 /*
  * macros
  */
