@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,23 +12,7 @@
  * 
  * $HEADER$
  *
- *	Revision 6.1  1996/11/23 21:55:44  nevin
- *	Ohio Release
- *	
- * Revision 6.0  96/02/29  13:54:09  gdburns
- * Ohio Release
- * 
- * Revision 5.2  94/08/22  14:00:50  gdburns
- * Ohio Release
- * 
- * Revision 5.1  94/05/18  12:44:46  gdburns
- * Ohio Release
- * 
- * Revision 2.3  94/04/22  12:49:11  gdburns
- * Ohio Release
- * 
- * Revision 2.2  93/10/14  18:28:53  raja
- * pre-release to 2.3
+ * $Id: vctable.h,v 6.4 2003/07/05 21:54:43 jsquyres Exp $
  * 
  *	Function:	- virtual circuits templates and constants
  */
@@ -58,4 +42,17 @@ struct vcdesc {
 	int4		vc_path;	/* VC path */
 };
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+int _vcinsert(int4 node, int4 event, int4 type, int4 path);
+struct vcdesc *_vcfind(int4 node, int4 event, int4 type);
+int _vcdelete(int4 node, int4 event, int4 type);
+void _vcfree(void);
+
+#ifdef __cplusplus
+}
+#endif
+
 #endif
