@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -15,7 +15,7 @@
  *	Copyright 1997 The Ohio State University
  *	GDB/RBD
  *
- *	$Id: clientio.c,v 1.7 2003/03/21 23:24:21 brbarret Exp $
+ *	$Id: clientio.c,v 1.8 2003/11/02 20:08:40 brbarret Exp $
  *
  *	Function:	- interface between kernel runtime request library
  *			  and native environment
@@ -47,12 +47,13 @@
  */
 void			_cio_bail();		/* terminate self */
 void			_cio_cleanup();		/* mach. dep. cleanup */
-int			_cio_init();		/* initialize kernel I/O */
-int			_cio_kreq();		/* make a kernel request */
-int			_cio_kreqback();	/* 1st half of kreq */
-int			_cio_kreqfront();	/* 2nd half of kreq */
-int			_cio_send();		/* send data */
-int			_cio_recv();		/* recv data */
+int			_cio_init(void);	/* initialize kernel I/O */
+			/* make a kernel request */
+int			_cio_kreq(struct kreq *pkq, struct kreply *pkr);
+int			_cio_kreqback(struct kreply *pkr); /* 1st half of kreq */
+int			_cio_kreqfront(struct kreq *pkq);  /* 2nd half of kreq */
+int			_cio_send(struct kmsg *pkmsg);     /* send data */
+int			_cio_recv(struct kmsg *pkmsg);     /* recv data */
 
 /*
  * external variables
@@ -75,7 +76,6 @@ static int		sd_kernel;		/* kernel socket */
  */
 int
 _cio_init()
-
 {
 	char		*p;
 	int		errnosave;
@@ -180,11 +180,7 @@ _cio_init()
  *	Returns:	- 0 or ERROR
  */
 int
-_cio_kreq(pkq, pkr)
-
-struct kreq		*pkq;
-struct kreply		*pkr;
-
+_cio_kreq(struct kreq *pkq, struct kreply *pkr)
 {
 	if (_cio_kreqfront(pkq) < 0) {
 		return(ERROR);
@@ -203,10 +199,7 @@ struct kreply		*pkr;
  *	Returns:	- client/kernel socket or ERROR
  */
 int
-_cio_kreqfront(pkq)
-
-struct kreq		*pkq;
-
+_cio_kreqfront(struct kreq *pkq)
 {
 /*
  * Send the request to the kernel.
@@ -238,10 +231,7 @@ struct kreq		*pkq;
  *	Returns:	- 0 or ERROR
  */
 int
-_cio_kreqback(pkr)
-
-struct kreply		*pkr;
-
+_cio_kreqback(struct kreply *pkr)
 {
 	if (mread(sd_kernel, (char *) pkr, sizeof(struct kreply)) <
 			(int)sizeof(struct kreply)) {
@@ -263,10 +253,7 @@ struct kreply		*pkr;
  *	Returns:	- 0 or ERROR
  */
 int
-_cio_recv(pkmsg)
-
-struct kmsg		*pkmsg;
-
+_cio_recv(struct kmsg *pkmsg)
 {
 	int4		r;
 	int4		totlen;
@@ -314,10 +301,7 @@ struct kmsg		*pkmsg;
  *	Returns:	- 0 or ERROR
  */
 int
-_cio_send(pkmsg)
-
-struct kmsg		*pkmsg;
-
+_cio_send(struct kmsg *pkmsg)
 {
 	int4		r;
 	int4		totlen;
@@ -356,7 +340,6 @@ struct kmsg		*pkmsg;
  */
 void
 _cio_cleanup()
-
 {
 	close(sd_kernel);
 }
@@ -368,10 +351,7 @@ _cio_cleanup()
  *	Accepts:	- exit status
  */
 void
-_cio_bail(status)
-
-int			status;
-
+_cio_bail(int status)
 {
 	exit(status);
 }
