@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- *	$Id: couter.c,v 1.4 2002/10/29 02:15:17 brbarret Exp $
+ *	$Id: couter.c,v 1.5 2003/11/02 20:08:41 brbarret Exp $
  *
  *	Function:	- client protocols
  *			- OTB version
@@ -34,18 +34,31 @@
 /*
  * local functions
  */
-static void		cipc_preempt();
+static void		cipc_preempt(void);
+
+/*
+ * global functions
+ */
+int _cipc_init(void);
+int _cipc_ksend(struct kreq *pkq, struct kreply *pkr);
+int _cipc_krecvfront(struct kreq *pkq);
+int _cipc_ksrfront(struct kreq *pkq, struct kreply *pkr);
+int _cipc_krecvback(struct kreq *pkq, struct kreply *pkr);
+int _cipc_ksrback(struct kreq *pkq, struct kreply *pkr);
+int _cipc_kreq(struct kreq *pkq, struct kreply *pkr);
+void _cipc_cleanup(void);
 
 /*
  * external functions
  */
-extern int		_cio_kreq();		/* kernel request/reply */
-extern int		_cio_kreqfront();	/* kernel request */
-extern int		_cio_kreqback();	/* kernel reply */
-extern int		_cio_init();		/* init kernel interface */
-extern int		_cio_send();		/* transfer kernel msg */
-extern int		_cio_recv();		/* transfer kernel msg */
-extern void		_cio_cleanup();		/* frees resources */
+extern int		_cio_init(void);	/* initialize kernel I/O */
+			/* make a kernel request */
+extern int		_cio_kreq(struct kreq *pkq, struct kreply *pkr);
+extern int		_cio_kreqback(struct kreply *pkr); /* 1st half of kreq */
+extern int		_cio_kreqfront(struct kreq *pkq);  /* 2nd half of kreq */
+extern int		_cio_send(struct kmsg *pkmsg);     /* send data */
+extern int		_cio_recv(struct kmsg *pkmsg);     /* recv data */
+extern void		_cio_cleanup(void);	/* frees resources */
 extern void		_ksig_follow();		/* check signals */
 extern void		(*_lam_signal())();	/* portable signal() */
 
@@ -341,7 +354,7 @@ cipc_preempt()
 
 	if (_kio.ki_pid != lam_getpid()) return;
 
-        LAM_ZERO_ME(req);
+	LAM_ZERO_ME(req);
 	req.kq_req = KQSURRENDER;
 	req.kq_index = _kio.ki_index;
 
