@@ -10,17 +10,20 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB/RBD
  *
- *	$Id: kdetach.c,v 1.1.2.1 2002/10/09 19:49:03 brbarret Exp $
+ *	$Id: kdetach.c,v 1.3 2002/10/09 20:57:47 brbarret Exp $
  * 
  *	Function:	- detaches calling process from the kernel
  *	Accepts:	- process scheduling priority
  *	Returns:	- 0 or ERROR
  */
-			  
+
+#include <lam_config.h>
+#include <etc_misc.h>			  
 #include <kio.h>
 #include <kreq.h>
 #include <terror.h>
@@ -46,7 +49,7 @@ int			pid;
 {
 	struct kreq	req;			/* kernel request */
 
-	if (_kio.ki_pid != getpid()) {
+	if (_kio.ki_pid != lam_getpid()) {
 		errno = ENOTATTACHED;	
 		return(ERROR);
 	}
@@ -54,13 +57,13 @@ int			pid;
 	LAM_ZERO_ME(req);
 	req.kq_req = KQDETACH;
 	req.kq_index = _kio.ki_index;
-	req.kq_pid = (pid == 0) ? getpid() : pid;
+	req.kq_pid = (pid == 0) ? lam_getpid() : pid;
 
 	if (_cio_kreqfront(&req) < 0) {
 		return(ERROR);
 	}
 
-	if ((pid == 0) || (pid == getpid())) {
+	if ((pid == 0) || (pid == lam_getpid())) {
 		_kio.ki_rtf &= ~RTF_KERNEL;	
 		_kio.ki_pid = -1;	
 		_kio.ki_index = -1;
