@@ -10,11 +10,12 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
  *	Ohio Trollius
  *	Copyright 1994 The Ohio State University
  *	GDB
  *
- *	$Id: kdoom.c,v 6.4.2.1 2002/10/09 19:49:03 brbarret Exp $
+ *	$Id: kdoom.c,v 6.6 2002/10/09 20:57:47 brbarret Exp $
  *	
  *	Function:	- delivers a signal to a process
  *	Accepts:	- process identifier (0 means self)
@@ -76,10 +77,18 @@ int			signal;
 /*
  * Check signals.
  */
+#if 0
+		/* This seems to be redundant: the reply.kr_signal is
+                   checked (and potentially followed) in _cipc_kreq().
+                   No need to check/follow it again here.  I'm leaving
+                   the code and this comment here just to be explicit,
+                   and to document where the [LAM] signal is actually
+                   processed. */
 		if (reply.kr_signal) {
 			_kio.ki_signal |= reply.kr_signal;
 			_ksig_follow();
 		}
+#endif
 
 		if (reply.kr_reply) {
 			errno = reply.kr_reply;
