@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	GDB
+ * $HEADER$
  *
- *	$Id: kenter.c,v 6.3.2.1 2002/10/09 19:49:03 brbarret Exp $
+ *	$Id: kenter.c,v 6.6 2003/01/13 19:17:43 jsquyres Exp $
  * 
  *	Function:	- calls kinit() and lpattach()
  *	Accepts:	- program name
@@ -27,12 +25,9 @@
 #include <portable.h>
 #include <typical.h>
 
+
 int
-kenter(name, priority)
-
-CONST char		*name;
-int			priority;
-
+kenter(const char *name, int priority)
 {
 	if (kinit(priority)) {
 		return(ERROR);
