@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -15,7 +15,7 @@
  *	Copyright 1997 The Ohio State University
  *	GDB
  *
- *	$Id: ksignal.c,v 6.7 2002/10/09 20:57:47 brbarret Exp $
+ *	$Id: ksignal.c,v 6.8 2003/11/02 19:48:48 brbarret Exp $
  *
  *	Function:	- signal package
  *			- Any kernel request may return one or more signals.
@@ -324,13 +324,13 @@ lam_ksignal(int signo, lam_void_func sigfunc)
 
 int lam_kpause() { return(kpause()); }
 
-int lam_ksigsetmask(mask) int mask; { return(ksigsetmask(mask)); }
+int lam_ksigsetmask(int mask) { return(ksigsetmask(mask)); }
 
-int lam_ksigblock(mask) int mask; { return(ksigblock(mask)); }
+int lam_ksigblock(int mask) { return(ksigblock(mask)); }
 
-int lam_ksigsetretry(flags) int flags; { return(ksigsetretry(flags)); }
+int lam_ksigsetretry(int flags) { return(ksigsetretry(flags)); }
 
-int lam_ksigretry(flags) int flags; { return(ksigretry(flags)); }
+int lam_ksigretry(int flags) { return(ksigretry(flags)); }
 
 /*
  * Fortran wrapper.
