@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2003 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -10,8 +10,12 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
+ * $HEADER$
+ *	Ohio Trollius
+ *	Copyright 1995 The Ohio State University
+ *	GDB
  *
- *	$Id: kstate.c,v 6.3.2.2 2003/01/17 20:39:32 brbarret Exp $
+ *	$Id: kstate.c,v 6.5 2002/10/09 20:57:47 brbarret Exp $
  * 
  *	Function:	- obtains process status from kernel
  *	Accepts:	- process ID
