@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: ktrace.c,v 6.6.2.1 2004/02/04 03:21:30 jsquyres Exp $
+ * $Id: ktrace.c,v 6.9 2004/02/04 03:06:21 jsquyres Exp $
  * 
  *	Function:	- runtime trace package
  *			- an internal package, hence does not check or
@@ -39,7 +39,7 @@ extern struct kio_t	_kio;			/* Kernel Input/Output block */
 /*
  * local functions
  */
-static void		tralloc();		/* allocate trace buffers */
+static void		tralloc(int);		/* allocate trace buffers */
 
 /*
  * global functions
@@ -55,7 +55,6 @@ void			lam_trunload(int);	/* unload traces to traced */
  */
 void
 lam_trinit()
-
 {
 	int		i;			/* favourite index */
 /*
@@ -97,10 +96,7 @@ lam_trinit()
  *	Accepts:	- index of first trace buffer ptr
  */
 static void
-tralloc(idx)
-
-int			idx;
-
+tralloc(int idx)
 {
 	int		i;
 	int		imax;
@@ -154,10 +150,7 @@ lam_trunload(int sig)
  *	Returns:	- ptr to next trace location
  */
 char *
-lam_trpoint(size)
-
-int			size;
-
+lam_trpoint(int size)
 {
 	struct trhead	*p;
 
@@ -197,7 +190,6 @@ int			size;
  */
 void
 lam_trexit()
-
 {
 	int		i;
 /*
