@@ -426,7 +426,7 @@ malloc_starter(sz, caller) size_t sz; const Void_t *caller;
 
   victim = _int_malloc(&main_arena, sz);
 
-  return victim ? BOUNDED_N(victim, sz) : 0;
+  return victim ? BOUNDED_N(victim, sz) : NULL;
 }
 
 static void
