@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2003 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2006 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,8 +12,6 @@
  * 
  * $HEADER$
  *
- * $Id: MPI.c,v 6.10 2003/11/02 21:13:10 brbarret Exp $
- *
  *	Function:	- F77 support
  */
 
@@ -91,14 +89,14 @@ double			mpi_statuses_ignore_[2];
 /*
  * Null functions.
  */
-void mpi_null_copy_fn_() { }
-void mpi_null_delete_fn_() { }
-void mpi_comm_null_copy_fn_() { }
-void mpi_comm_null_delete_fn_() { }
-void mpi_type_null_copy_fn_() { }
-void mpi_type_null_delete_fn_() { }
-void mpi_win_null_copy_fn_() { }
-void mpi_win_null_delete_fn_() { }
+void mpi_null_copy_fn_(void) { }
+void mpi_null_delete_fn_(void) { }
+void mpi_comm_null_copy_fn_(void) { }
+void mpi_comm_null_delete_fn_(void) { }
+void mpi_type_null_copy_fn_(void) { }
+void mpi_type_null_delete_fn_(void) { }
+void mpi_win_null_copy_fn_(void) { }
+void mpi_win_null_delete_fn_(void) { }
 
 /*
  *	lam_F_alloc_hdl
