@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: address.c,v 6.3.2.1 2002/10/09 19:49:05 brbarret Exp $
+ * $Id: address.c,v 6.5 2002/12/11 19:15:09 jsquyres Exp $
  *
  *	Function:	- return address of location
  *	Accepts:	- location
@@ -46,7 +44,7 @@ int MPI_Address(void *loc, MPI_Aint *paddr)
 
 	if (paddr == 0) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPIADDRESS, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPIADDRESS, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	*paddr = ((MPI_Aint) loc) - ((MPI_Aint) MPI_BOTTOM);
