@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: allgather.c,v 6.12.2.3 2004/01/02 12:34:53 jsquyres Exp $
+ * $Id: allgather.c,v 6.18 2004/03/02 03:43:28 jsquyres Exp $
  *
  *	Function:	- gather buffers at all process ranks
  *	Accepts:	- send buffer
@@ -91,15 +91,13 @@ int MPI_Allgather(void *sbuf, int scount, MPI_Datatype sdtype,
 	  return(lam_errfunc(comm, BLKMPIALLGATHER,
 			     lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
-	func = LAM_IS_INTER(comm) ?
-	  comm->c_ssi_coll.lsca_allgather_inter :
-	  comm->c_ssi_coll.lsca_allgather_intra;
+	func = comm->c_ssi_coll.lsca_allgather;
 
 	if ((sdtype == MPI_DATATYPE_NULL) || (rdtype == MPI_DATATYPE_NULL)) {
 	  return(lam_errfunc(comm, BLKMPIALLGATHER,
 			     lam_mkerr(MPI_ERR_TYPE, EINVAL)));
 	}
-
+	
 	if ((scount < 0) || (rcount < 0)) {
 	  return(lam_errfunc(comm, BLKMPIALLGATHER,
 			     lam_mkerr(MPI_ERR_COUNT, EINVAL)));
