@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: allgatherv.c,v 6.9 2003/02/04 18:06:51 jsquyres Exp $
+ * $Id: allgatherv.c,v 6.11 2004/03/02 03:43:28 jsquyres Exp $
  *
  *	Function:	- gather varying length buffers at all process ranks
  *	Accepts:	- send buffer
@@ -96,9 +96,7 @@ int MPI_Allgatherv(void *sbuf, int scount, MPI_Datatype sdtype,
 	  return(lam_errfunc(comm, BLKMPIALLGATHERV,
 			     lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
-	func = LAM_IS_INTER(comm) ?
-	  comm->c_ssi_coll.lsca_allgatherv_inter :
-	  comm->c_ssi_coll.lsca_allgatherv_intra;
+	func = comm->c_ssi_coll.lsca_allgatherv;
 
 	if ((sdtype == MPI_DATATYPE_NULL) || (rdtype == MPI_DATATYPE_NULL)) {
 	  return(lam_errfunc(comm, BLKMPIALLGATHERV,
