@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: alltoall.c,v 6.11 2003/02/04 18:06:51 jsquyres Exp $
+ * $Id: alltoall.c,v 6.13 2004/03/02 03:43:28 jsquyres Exp $
  *
  *	Function:	- send/recv data from each node to all nodes
  *	Accepts:	- send buffer
@@ -91,9 +91,7 @@ int MPI_Alltoall(void *sbuf, int scount, MPI_Datatype sdtype,
 	  return(lam_errfunc(comm, BLKMPIALLTOALL,
 			     lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
-	func = LAM_IS_INTER(comm) ?
-	  comm->c_ssi_coll.lsca_alltoall_inter :
-	  comm->c_ssi_coll.lsca_alltoall_intra;
+	func = comm->c_ssi_coll.lsca_alltoall;
 
 	if ((sdtype == MPI_DATATYPE_NULL) || (rdtype == MPI_DATATYPE_NULL)) {
 	  return(lam_errfunc(comm, BLKMPIALLTOALL,
