@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: alltoallv.c,v 6.12 2003/02/09 19:20:30 jsquyres Exp $
+ * $Id: alltoallv.c,v 6.14 2004/03/02 03:43:28 jsquyres Exp $
  *
  *	Function:	- send/recv var. len. data from each node to all nodes
  *	Accepts:	- send buffer
@@ -98,9 +98,7 @@ int MPI_Alltoallv(void *sbuf, int *scounts, int *sdisps,
 	  return(lam_errfunc(comm, BLKMPIALLTOALLV,
 			     lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
-	func = LAM_IS_INTER(comm) ?
-	  comm->c_ssi_coll.lsca_alltoallv_inter :
-	  comm->c_ssi_coll.lsca_alltoallv_intra;
+	func = comm->c_ssi_coll.lsca_alltoallv;
 
 	if ((sdtype == MPI_DATATYPE_NULL) || (rdtype == MPI_DATATYPE_NULL)) {
 	  return(lam_errfunc(comm, BLKMPIALLTOALLV,
