@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD/NJN
+ * $HEADER$
  *
- *	$Id: attrput.c,v 6.4.2.1 2002/10/09 19:49:05 brbarret Exp $
+ * $Id: attrput.c,v 6.6 2002/12/11 19:15:09 jsquyres Exp $
  *
  *	Function:	- put value in attribute
  *			- assign attribute to communicator
