@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: barrier.c,v 6.10 2003/02/04 18:06:51 jsquyres Exp $
+ * $Id: barrier.c,v 6.12 2004/03/02 03:43:29 jsquyres Exp $
  *
  *	Function:	- barrier synchronization
  *	Accepts:	- communicator
@@ -79,9 +79,7 @@ int MPI_Barrier(MPI_Comm comm)
 		return(lam_errfunc(comm,
 			BLKMPIBARRIER, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
-	func = LAM_IS_INTER(comm) ?
-	  comm->c_ssi_coll.lsca_barrier_inter :
-	  comm->c_ssi_coll.lsca_barrier_intra;
+	func = comm->c_ssi_coll.lsca_barrier;
 
 	if (func == NULL) {
 	  return(lam_errfunc(comm, BLKMPIBARRIER,
