@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: bcast.c,v 6.13 2003/02/04 18:06:51 jsquyres Exp $
+ * $Id: bcast.c,v 6.15 2004/03/02 03:43:29 jsquyres Exp $
  *
  *	Function:	- broadcast info to all nodes SIMD-style
  *	Accepts:	- buffer
@@ -90,9 +90,7 @@ int MPI_Bcast(void *buff, int count, MPI_Datatype datatype,
       return(lam_errfunc(comm, BLKMPIBCAST, 
 			 lam_mkerr(MPI_ERR_COMM, EINVAL)));
     }
-    func = LAM_IS_INTER(comm) ?
-      comm->c_ssi_coll.lsca_bcast_inter :
-      comm->c_ssi_coll.lsca_bcast_intra;
+    func = comm->c_ssi_coll.lsca_bcast;
 
     if (datatype == MPI_DATATYPE_NULL) {
       return(lam_errfunc(comm, BLKMPIBCAST, 
@@ -104,11 +102,44 @@ int MPI_Bcast(void *buff, int count, MPI_Datatype datatype,
 			 lam_mkerr(MPI_ERR_COUNT, EINVAL)));
     }
 
-    MPI_Comm_size(comm, &size);
-    if ((root >= size) || (root < 0)) {
-      return(lam_errfunc(comm, BLKMPIBCAST, 
-			 lam_mkerr(MPI_ERR_ROOT, EINVAL)));
-    }
+    if (LAM_IS_INTRA(comm)) {
+      MPI_Comm_size(comm, &size);
+      if ((root >= size) || (root < 0)) {
+	return(lam_errfunc(comm, BLKMPIBCAST, 
+			   lam_mkerr(MPI_ERR_ROOT, EINVAL)));
+      }
+      /*
+       * Set debugging parameters 
+       */
+      
+      p = &(comm->c_group->g_procs[root]->p_gps);
+      lam_setparam(BLKMPIBCAST,
+		   root | (p->gps_grank << 16), 
+		   (p->gps_node << 16) | p->gps_idx);
+      /*
+       * Check for zero count case.
+       */
+      if (count == 0 && comm->c_ssi_coll.lsca_bcast_optimization) {
+	LAM_TRACE(lam_tr_cffend(BLKMPIBCAST, root, comm, datatype, count));
+	lam_resetfunc(BLKMPIBCAST);
+	return(MPI_SUCCESS);
+      }
+
+      /* If there's only one node, we're done */
+      
+      else if (size <= 1) {
+	LAM_TRACE(lam_tr_cffend(BLKMPIBCAST, root, comm, datatype, count));
+	lam_resetfunc(BLKMPIBCAST);
+	return(MPI_SUCCESS);
+      }
+    } else {
+      MPI_Comm_remote_size(comm, &size);
+      if (!(((root < size) && (root >= 0)) 
+	|| (root == MPI_ROOT) || (root == MPI_PROC_NULL))) {
+	return(lam_errfunc(comm, BLKMPIBCAST, 
+			   lam_mkerr(MPI_ERR_ROOT, EINVAL)));
+      }
+    } 
 
     if (func == NULL) {
       return(lam_errfunc(comm, BLKMPIBCAST,
@@ -116,28 +147,6 @@ int MPI_Bcast(void *buff, int count, MPI_Datatype datatype,
     }
 
     LAM_TRACE(lam_tr_cffstart(BLKMPIBCAST));
-/*
- * Set debugging parameters.
- */
-    p = &(comm->c_group->g_procs[root]->p_gps);
-    lam_setparam(BLKMPIBCAST,
-	    root | (p->gps_grank << 16), (p->gps_node << 16) | p->gps_idx);
-/*
- * Check for zero count case.
- */
-    if (count == 0 && comm->c_ssi_coll.lsca_bcast_optimization) {
-	LAM_TRACE(lam_tr_cffend(BLKMPIBCAST, root, comm, datatype, count));
-	lam_resetfunc(BLKMPIBCAST);
-	return(MPI_SUCCESS);
-    }
-
-    /* If there's only one node, we're done */
-
-    else if (size <= 1) {
-	LAM_TRACE(lam_tr_cffend(BLKMPIBCAST, root, comm, datatype, count));
-	lam_resetfunc(BLKMPIBCAST);
-	return(MPI_SUCCESS);
-    }
 
     /* Call the coll SSI to actually perform the barrier */
     
