@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: bsend.c,v 6.5.2.1 2002/10/09 19:49:05 brbarret Exp $
+ * $Id: bsend.c,v 6.8 2003/02/20 19:57:13 jsquyres Exp $
  *
  *	Function:	- buffered send
  *	Accepts:	- buffer
@@ -123,9 +121,9 @@ int MPI_Bsend(void *buf, int count, MPI_Datatype dtype,
 /*
  * Check the tag.
  */
-	if (tag < 0 || tag > LAM_MAXTAG) {
+	if (tag < 0 || tag > lam_mpi_max_tag) {
 		return(lam_errfunc(comm, BLKMPIBSEND,
-				lam_mkerr(MPI_ERR_TAG, 0)));
+				lam_mkerr(MPI_ERR_TAG, EINVAL)));
 	}
 	
 	if ((fl_trace = LAM_TRACE_TOP())) startt = MPI_Wtime();
