@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: bsendinit.c,v 6.12.2.1 2002/10/09 19:49:05 brbarret Exp $
+ * $Id: bsendinit.c,v 6.16 2003/02/20 19:57:13 jsquyres Exp $
  *
  *	Function:	- create a buffered send request
  *	Accepts:	- buffer
@@ -33,7 +31,7 @@
 #include <rpisys.h>
 #if LAM_WANT_IMPI
 #include <impi.h>
-#include <debug.h>
+#include <lamdebug.h>
 #endif
 
 /*
@@ -109,14 +107,14 @@ int MPI_Bsend_init(void *buf, int count, MPI_Datatype dtype,
 	lam_initerr_m();
 	lam_setfunc_m(BLKMPIBSINIT);
 
-	if (tag < 0 || tag > LAM_MAXTAG) {
+	if (tag < 0 || tag > lam_mpi_max_tag) {
 		return(lam_errfunc(comm, BLKMPIBSINIT,
-				lam_mkerr(MPI_ERR_TAG, 0)));
+				lam_mkerr(MPI_ERR_TAG, EINVAL)));
 	}
 
 	if (dest == MPI_ANY_SOURCE) {
 		return(lam_errfunc(comm, BLKMPIBSINIT,
-				lam_mkerr(MPI_ERR_RANK, 0)));
+				lam_mkerr(MPI_ERR_RANK, EINVAL)));
 	}
 
 #if LAM_WANT_IMPI
