@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: bufdetach.c,v 6.3.2.1 2002/10/09 19:49:05 brbarret Exp $
+ * $Id: bufdetach.c,v 6.5 2002/12/11 19:15:09 jsquyres Exp $
  *
  *	Function:	- detach buffer from process
  *	Accepts:	- ptr buffer address
