@@ -1,38 +1,18 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
- * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: cartget.c,v 6.3 1999/12/31 21:27:18 jsquyres Exp $
+ * $Id: cartget.c,v 6.5 2002/12/11 19:15:09 jsquyres Exp $
  *
  *	Function:	- get info on cartesian topology
  *	Accepts:	- communicator
@@ -88,23 +68,23 @@ int MPI_Cart_get(MPI_Comm comm, int maxndims, int *dims,
  */
 	if (comm == MPI_COMM_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPICARTGET, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPICARTGET, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (LAM_IS_INTER(comm)) {
 		return(lam_errfunc(comm,
-			BLKMPICARTGET, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPICARTGET, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (!LAM_IS_CART(comm)) {
 		return(lam_errfunc(comm, BLKMPICARTGET,
-				lam_mkerr(MPI_ERR_TOPOLOGY, 0)));
+				lam_mkerr(MPI_ERR_TOPOLOGY, EINVAL)));
 	}
 
 	if ((maxndims < 0) || ((maxndims > 0) &&
 			((dims == 0) || (periods == 0) || (coords == 0)))) {
 		return(lam_errfunc(comm,
-			BLKMPICARTGET, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPICARTGET, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 /*
  * Fill the dimension, period, and coordinate arrays.
