@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: cartmap.c,v 6.3.2.1 2002/10/09 19:49:06 brbarret Exp $
+ * $Id: cartmap.c,v 6.5 2002/12/11 19:15:09 jsquyres Exp $
  *
  *	Function:	- map processes to cartesian coordinates
  *	Accepts:	- communicator
@@ -72,22 +70,22 @@ int MPI_Cart_map(MPI_Comm comm, int ndims, int *dims,
  */
 	if (comm == MPI_COMM_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPICARTMAP, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPICARTMAP, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (LAM_IS_INTER(comm)) {
 		return(lam_errfunc(comm,
-			BLKMPICARTMAP, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPICARTMAP, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (ndims < 1) {
 		return(lam_errfunc(comm,
-			BLKMPICARTMAP, lam_mkerr(MPI_ERR_DIMS, 0)));
+			BLKMPICARTMAP, lam_mkerr(MPI_ERR_DIMS, EINVAL)));
 	}
 
 	if ((dims == 0) || (periods == 0) || (newrank == 0)) {
 		return(lam_errfunc(comm,
-			BLKMPICARTMAP, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPICARTMAP, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 /*
  * Compute the # of processes in the grid.
@@ -96,7 +94,7 @@ int MPI_Cart_map(MPI_Comm comm, int ndims, int *dims,
 	for (i = 0, p = dims; i < ndims; ++i, ++p) {
 		if (*p <= 0) {
 			return(lam_errfunc(comm, BLKMPICARTMAP,
-					lam_mkerr(MPI_ERR_DIMS, 0)));
+					lam_mkerr(MPI_ERR_DIMS, EINVAL)));
 		}
 
 		nprocs *= *p;
@@ -111,7 +109,7 @@ int MPI_Cart_map(MPI_Comm comm, int ndims, int *dims,
 
 	if (nprocs > size) {
 		return(lam_errfunc(comm, BLKMPICARTMAP,
-					lam_mkerr(MPI_ERR_DIMS, 0)));
+					lam_mkerr(MPI_ERR_DIMS, EINVAL)));
 	}
 /*
  * Compute my new rank.
