@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD/NJN
+ * $HEADER$
  *
- *	$Id: ccmp.c,v 6.4.2.1 2002/10/09 19:49:06 brbarret Exp $
+ * $Id: ccmp.c,v 6.6 2002/12/11 19:15:09 jsquyres Exp $
  *
  *	Function:	- compare two communicators
  *	Accepts:	- first communicator
@@ -79,12 +77,12 @@ int MPI_Comm_compare(MPI_Comm c1, MPI_Comm c2,
  */
 	if (result == 0) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPICOMMCMP, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPICOMMCMP, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	if (c1 == MPI_COMM_NULL || c2 == MPI_COMM_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPICOMMCMP, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPICOMMCMP, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 /*
  * Handle the trivial cases.
