@@ -1,38 +1,18 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
- * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD/GDB
+ * $HEADER$
  *
- *	$Id: ccreate.c,v 6.4 1999/12/31 21:27:19 jsquyres Exp $
+ * $Id: ccreate.c,v 6.9 2003/02/20 19:45:27 jsquyres Exp $
  *
  *	Function:	- create a new communicator
  *	Accepts:	- old communicator
@@ -48,12 +28,8 @@
 #include <mpi.h>
 #include <mpisys.h>
 #include <terror.h>
+#include <lam-ssi-coll.h>
 
-/*
- * external functions
- */
-extern int		lam_cubedim();
-extern int		lam_tr_comm();
 
 /*@
 
@@ -87,7 +63,6 @@ When a communicator is no longer being used, it should be freed with
 int MPI_Comm_create(MPI_Comm comm, MPI_Group group, 
 		    MPI_Comm *newcomm)
 {
-	int		mycid;			/* local max context ID */
 	int		cid;			/* global max context ID */
 	int		rank;			/* process rank */
 	int		err;			/* error code */
@@ -99,40 +74,28 @@ int MPI_Comm_create(MPI_Comm comm, MPI_Group group,
  */
 	if (comm == MPI_COMM_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD, BLKMPICOMMCREATE,
-				lam_mkerr(MPI_ERR_COMM, 0)));
+				lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (LAM_IS_INTER(comm)) {
 		return(lam_errfunc(comm, BLKMPICOMMCREATE,
-				lam_mkerr(MPI_ERR_COMM, 0)));
+				lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (group == MPI_GROUP_NULL) {
 		return(lam_errfunc(comm, BLKMPICOMMCREATE,
-				lam_mkerr(MPI_ERR_GROUP, 0)));
+				lam_mkerr(MPI_ERR_GROUP, EINVAL)));
 	}
 
 	if (newcomm == 0) {
 		return(lam_errfunc(comm, BLKMPICOMMCREATE,
-				lam_mkerr(MPI_ERR_ARG, 0)));
-	}
-/*
- * Create the new context ID using MPI_Allreduce().
- * Processes not in group participate but do not affect the context ID.
- */
-	rank = group->g_myrank;
-
-	mycid = (rank == MPI_UNDEFINED) ? 0 : lam_getcid();
-	if (mycid < 0) {
-		return(lam_errfunc(comm, BLKMPICOMMCREATE,
-				lam_mkerr(MPI_ERR_INTERN, EFULL)));
+				lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 #if LAM_WANT_IMPI
-
 	/* Remove this when IMPI collectives are implemented */
         if (LAM_IS_IMPI(comm)) {
-	  return lam_err_comm(comm, MPI_ERR_COMM, 0, 
+	  return lam_err_comm(comm, MPI_ERR_COMM, ENOSYS, 
 			      "Collectives not yet implemented on IMPI communicators");
 	}
 #endif
@@ -142,7 +105,13 @@ int MPI_Comm_create(MPI_Comm comm, MPI_Group group,
  */
 	LAM_TRACE(lam_tr_cffstart(BLKMPICOMMCREATE));
 
-	err = MPI_Allreduce(&mycid, &cid, 1, MPI_INT, MPI_MAX, comm);
+	/* Collectively decide what the new CID will be.  Processes
+	   not in the group participate but do not affect the final
+	   CID. */
+
+	rank = group->g_myrank;
+	err = lam_coll_alloc_intra_cid(comm, (rank == MPI_UNDEFINED) ? 0 : 1,
+				       BLKMPICOMMCREATE, &cid);
 	if (err != MPI_SUCCESS) {
 		LAM_TRACE(lam_tr_cffend(BLKMPICOMMCREATE, -1, comm, 0, 0));
 		lam_resetfunc(BLKMPICOMMCREATE);
@@ -180,6 +149,15 @@ int MPI_Comm_create(MPI_Comm comm, MPI_Group group,
 
  	lam_setcid(cid);
 
+	/* Let the collective SSI modules battle over who will do
+	   collectives on this new communicator.  It'll likely be the
+	   same as the one that's on this communicator, but we still
+	   give them the option to do something different anyway... */
+
+	if (lam_ssi_coll_base_init_comm(*newcomm) != 0)
+	  return(lam_errfunc(comm, BLKMPICOMMCREATE,
+			     lam_mkerr(MPI_ERR_INTERN, ENOSYS)));
+
 	LAM_TRACE(lam_tr_cffend(BLKMPICOMMCREATE, -1, comm, 0, 0));
 
 	lam_resetfunc(BLKMPICOMMCREATE);
