@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN
+ * $HEADER$
  *
- *	$Id: ccreateerr.c,v 1.1.2.1 2002/10/09 19:49:06 brbarret Exp $
+ * $Id: ccreateerr.c,v 1.3 2002/12/11 19:15:09 jsquyres Exp $
  *
  *	Function:	- create communicator error handler
  *	Accepts:	- error function
