@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: ccreatekey.c,v 1.4 2002/12/11 19:15:09 jsquyres Exp $
+ * $Id: ccreatekey.c,v 1.5 2003/11/23 15:01:23 jsquyres Exp $
  *
  *	Function:	- create a communicator attribute key
  *	Accepts:	- copy function
@@ -59,7 +59,8 @@ MPI_Comm_create_keyval(MPI_Comm_copy_attr_function *cpyfunc,
 	lam_initerr_m();
 	lam_setfunc_m(BLKMPICOMMCREATEKEYVAL);
 
-	err = lam_keyval_create((void_fn *) cpyfunc, (void_fn *) delfunc, 
+	err = lam_keyval_create((lam_void_fn_t) cpyfunc, 
+                                (lam_void_fn_t) delfunc, 
 				key, extra, LAM_AKCOMM);
 
 	if (err != MPI_SUCCESS) {
