@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD/NJN
+ * $HEADER$
  *
- *	$Id: cdelattr.c,v 1.3.2.1 2002/10/09 19:49:06 brbarret Exp $
+ * $Id: cdelattr.c,v 1.5 2002/12/11 19:15:10 jsquyres Exp $
  *
  *	Function:	- delete attribute
  *			- detach attribute from communicator
@@ -67,14 +65,14 @@ MPI_Comm_delete_attr(MPI_Comm comm, int key)
 
 	p = lam_getattr(key);
 	if (p == 0) {
-		return(lam_err_comm(comm, MPI_ERR_KEYVAL, 0, ""));
+		return(lam_err_comm(comm, MPI_ERR_KEYVAL, EINVAL, ""));
 	}
 /*
  * Check if the key is attached to the communicator.
  */
 	pk = lam_getkey(comm->c_keys, key);
 	if (pk == 0) {
-		return(lam_err_comm(comm, MPI_ERR_KEYVAL, 0,
+		return(lam_err_comm(comm, MPI_ERR_KEYVAL, EINVAL,
 			"not on communicator"));
 	}
 /*
@@ -89,12 +87,13 @@ MPI_Comm_delete_attr(MPI_Comm comm, int key)
 				(int *) &(pk->a_value),
 				(int *) &(p->ak_extra), &err);
 		} else {
-			err = (*((MPI_Comm_delete_attr_function *) (p->ak_del)))
+			err = (*((MPI_Comm_delete_attr_function *) 
+				 (p->ak_del)))
 				(comm, key, pk->a_value, p->ak_extra);
 		}
 
 		if (err != MPI_SUCCESS) {
-			return(lam_err_comm(comm, err, 0,
+			return(lam_err_comm(comm, err, EINVAL,
 					"deleting attribute"));
 		}
 	}
