@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN
+ * $HEADER$
  *
- *	$Id: cfreekey.c,v 1.3.2.1 2002/10/09 19:49:06 brbarret Exp $
+ * $Id: cfreekey.c,v 1.5 2002/12/11 19:15:10 jsquyres Exp $
  *
  *	Function:	- free communicator attribute key
  *	Accepts:	- key value (in-out)
@@ -55,14 +53,15 @@ MPI_Comm_free_keyval(int *key)
  * Check the arguments.
  */
 	if (key == 0) {
-		return(lam_err_comm(MPI_COMM_WORLD, MPI_ERR_ARG, 0,
+		return(lam_err_comm(MPI_COMM_WORLD, MPI_ERR_ARG, EINVAL,
 			"null pointer"));
 	}
 /*
  * Free the key, if it is valid.
  */
 	if (lam_freekey(*key, LAM_AKCOMM) != MPI_SUCCESS) {
-		return(lam_err_comm(MPI_COMM_WORLD, MPI_ERR_KEYVAL, 0, ""));
+		return(lam_err_comm(MPI_COMM_WORLD, MPI_ERR_KEYVAL, 
+				    EINVAL, ""));
 	}
 
 	*key = MPI_KEYVAL_INVALID;
