@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD/NJN
+ * $HEADER$
  *
- *	$Id: cgeterr.c,v 1.1.2.1 2002/10/09 19:49:06 brbarret Exp $
+ * $Id: cgeterr.c,v 1.3 2002/12/11 19:15:10 jsquyres Exp $
  *
  *	Function:	- get error handler of communicator
  *	Accepts:	- communicator
