@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN
+ * $HEADER$
  *
- *	$Id: cgetname.c,v 1.3.2.1 2002/10/09 19:49:06 brbarret Exp $
+ * $Id: cgetname.c,v 1.7 2003/06/01 14:04:07 jsquyres Exp $
  *
  *	Function:	- get communicator name
  *	Accepts:	- communicator
@@ -28,6 +26,7 @@
 #include <blktype.h>
 #include <mpi.h>
 #include <mpisys.h>
+#include <etc_misc.h>
 
 
 /*@
@@ -67,15 +66,15 @@ MPI_Comm_get_name(MPI_Comm comm, char *name, int *length)
  */
 	if (comm == MPI_COMM_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPICOMMGETNAME, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPICOMMGETNAME, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if ((name == 0) || (length == 0)) {
 		return(lam_errfunc(comm,
-			BLKMPICOMMGETNAME, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPICOMMGETNAME, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
-	strncpy(name, comm->c_name, MPI_MAX_OBJECT_NAME);
+	lam_strncpy(name, comm->c_name, MPI_MAX_OBJECT_NAME);
 	name[MPI_MAX_OBJECT_NAME - 1] = 0;
 	*length = strlen(name);
 
