@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN
+ * $HEADER$
  *
- *	$Id: cgetparent.c,v 1.1.2.1 2002/10/09 19:49:06 brbarret Exp $
+ * $Id: cgetparent.c,v 1.3 2002/12/11 19:15:10 jsquyres Exp $
  *
  *	Function:	- get parent communicator
  *	Accepts:	- communicator (out)
@@ -53,7 +51,7 @@ MPI_Comm_get_parent(MPI_Comm *parent)
  * Check the argument.
  */
 	if (parent == 0) {
-		return(lam_err_comm(MPI_COMM_WORLD, MPI_ERR_ARG, 0,
+		return(lam_err_comm(MPI_COMM_WORLD, MPI_ERR_ARG, EINVAL,
 			"null pointer"));
 	}
 
