@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: cgroup.c,v 6.3.2.1 2002/10/09 19:49:06 brbarret Exp $
+ * $Id: cgroup.c,v 6.5 2002/12/11 19:15:10 jsquyres Exp $
  *
  *	Function:	- get communicator group (create a new group)
  *	Accepts:	- communicator
@@ -65,12 +63,12 @@ int MPI_Comm_group(MPI_Comm comm, MPI_Group *pgroup)
 
 	if (comm == MPI_COMM_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPICOMMGROUP, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPICOMMGROUP, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (pgroup == 0) {
 		return(lam_errfunc(comm,
-			BLKMPICOMMGROUP, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPICOMMGROUP, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	*pgroup = comm->c_group;
