@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: crank.c,v 6.4.2.1 2002/10/09 19:49:07 brbarret Exp $
+ * $Id: crank.c,v 6.6 2002/12/11 19:15:10 jsquyres Exp $
  *
  *	Function:	- get caller's rank in communicator
  *	Accepts:	- communicator
@@ -56,11 +54,11 @@ int MPI_Comm_rank(MPI_Comm comm, int *rank)
 	}
 	else if (comm == MPI_COMM_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPICOMMRANK, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPICOMMRANK, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 	else {
 		return(lam_errfunc(comm,
-			BLKMPICOMMRANK, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPICOMMRANK, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	lam_resetfunc_m(BLKMPICOMMRANK);
