@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: crgroup.c,v 6.3.2.1 2002/10/09 19:49:07 brbarret Exp $
+ * $Id: crgroup.c,v 6.5 2002/12/11 19:15:10 jsquyres Exp $
  *
  *	Function:	- get remote group (create a new group)
  *	Accepts:	- inter-communicator
@@ -53,17 +51,17 @@ int MPI_Comm_remote_group(MPI_Comm comm, MPI_Group *pgroup)
 
 	if (comm == MPI_COMM_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPICOMMRGROUP, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPICOMMRGROUP, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (LAM_IS_INTRA(comm)) {
 		return(lam_errfunc(comm,
-			BLKMPICOMMRGROUP, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPICOMMRGROUP, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (pgroup == 0) {
 		return(lam_errfunc(comm,
-			BLKMPICOMMRGROUP, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPICOMMRGROUP, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	*pgroup = comm->c_rgroup;
