@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN
+ * $HEADER$
  *
- *	$Id: csetattr.c,v 1.3.2.1 2002/10/09 19:49:07 brbarret Exp $
+ * $Id: csetattr.c,v 1.5 2002/12/11 19:15:10 jsquyres Exp $
  *
  *	Function:	- put value in attribute
  *			- assign attribute to communicator
@@ -63,13 +61,13 @@ MPI_Comm_set_attr(MPI_Comm comm, int key, void *value)
 */
 	if (comm == MPI_COMM_NULL) {
 		return(lam_err_comm(MPI_COMM_WORLD,
-					MPI_ERR_COMM, 0, "null handle"));
+				    MPI_ERR_COMM, EINVAL, "null handle"));
 	}
 
 	p = lam_getattr(key);
 	if (p == 0 || (p->ak_flags & LAM_PREDEF)
 			|| !(p->ak_flags & LAM_AKCOMM)) {
-		return(lam_err_comm(comm, MPI_ERR_KEYVAL, 0, ""));
+		return(lam_err_comm(comm, MPI_ERR_KEYVAL, EINVAL, ""));
 	}
 /*
 * If the key is not attached to the communicator, attach and fill it.
@@ -100,8 +98,8 @@ MPI_Comm_set_attr(MPI_Comm comm, int key, void *value)
 		}
 
 		if (err != MPI_SUCCESS) {
-			return(lam_err_comm(comm, err, 0,
-					"deleting old attribute"));
+			return(lam_err_comm(comm, err, EINVAL,
+					    "deleting old attribute"));
 		}
 	}
 
