@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN
+ * $HEADER$
  *
- *	$Id: cseterr.c,v 1.1.2.1 2002/10/09 19:49:07 brbarret Exp $
+ * $Id: cseterr.c,v 1.3 2002/12/11 19:15:10 jsquyres Exp $
  *
  *	Function:	- set error handler for communicator
  *	Accepts:	- communicator
@@ -58,12 +56,12 @@ MPI_Comm_set_errhandler(MPI_Comm comm, MPI_Errhandler errhdl)
  * Check the arguments.
  */
 	if (comm == MPI_COMM_NULL) {
-		return(lam_err_comm(MPI_COMM_WORLD, MPI_ERR_COMM, 0,
+		return(lam_err_comm(MPI_COMM_WORLD, MPI_ERR_COMM, EINVAL,
 			"null handle"));
 	}
 
 	if (errhdl == MPI_ERRHANDLER_NULL || !(errhdl->eh_flags & LAM_EHCOMM)) {
-		return(lam_err_comm(comm, MPI_ERR_ARG, 0,
+		return(lam_err_comm(comm, MPI_ERR_ARG, EINVAL,
 			"illegal error handler"));
 	}
 /*
