@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN
+ * $HEADER$
  *
- *	$Id: csetname.c,v 1.3.2.1 2002/10/09 19:49:07 brbarret Exp $
+ * $Id: csetname.c,v 1.7 2003/05/31 22:28:50 jsquyres Exp $
  *
  *	Function:	- set communicator name
  *	Accepts:	- communicator
@@ -22,11 +20,10 @@
  *	Returns:	- MPI_SUCCESS or error code
  */
 
-#include <string.h>
-
 #include <blktype.h>
 #include <mpi.h>
 #include <mpisys.h>
+#include <etc_misc.h>
 
 
 /*@
@@ -76,19 +73,23 @@ MPI_Comm_set_name(MPI_Comm comm, char *name)
  */
 	if (comm == MPI_COMM_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPICOMMSETNAME, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPICOMMSETNAME, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (name == 0) {
 		return(lam_errfunc(comm,
-			BLKMPICOMMSETNAME, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPICOMMSETNAME, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
-	strncpy(comm->c_name, name, MPI_MAX_OBJECT_NAME);
+	lam_strncpy(comm->c_name, name, MPI_MAX_OBJECT_NAME);
 	comm->c_name[MPI_MAX_OBJECT_NAME - 1] = 0;
 	if (LAM_TRACE_TOP())
 	  lam_tr_commname(comm->c_name, comm->c_contextid, MPI_Wtime());
 
 	lam_resetfunc_m(BLKMPICOMMSETNAME);
+	
+	/* Force TotalView DLL to take note of this name setting */
+	++lam_tv_comm_seqnum;
+
 	return(MPI_SUCCESS);
 }
