@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: csplit.c,v 6.10 2003/02/20 19:45:27 jsquyres Exp $
+ * $Id: csplit.c,v 6.11 2003/08/20 21:49:32 jsquyres Exp $
  *
  *	Function:	- split communicator into disjoint subsets
  *	Accepts:	- old communicator
@@ -136,7 +136,7 @@ int MPI_Comm_split(MPI_Comm comm, int colour, int key,
  */
 	MPI_Comm_size(comm, &nprocs);
 
-	procs = (int *) malloc((unsigned) 3 * nprocs * sizeof(int));
+	procs = (int *) malloc((unsigned) 3 * (nprocs + 1) * sizeof(int));
 	if (procs == 0) {
 		return(lam_errfunc(comm, BLKMPICOMMSPLIT,
 				lam_mkerr(MPI_ERR_OTHER, errno)));
@@ -144,7 +144,7 @@ int MPI_Comm_split(MPI_Comm comm, int colour, int key,
 /*
  * Gather all process information at all processes.
  */
-	p = &procs[3 * myrank];
+	p = &procs[3 * nprocs];
 	p[0] = colour;
 	p[1] = key;
 	p[2] = myrank;
