@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: ctestinter.c,v 6.3.2.1 2002/10/09 19:49:07 brbarret Exp $
+ * $Id: ctestinter.c,v 6.5 2002/12/11 19:15:10 jsquyres Exp $
  *
  *	Function:	- check if inter-communicator
  *	Accepts:	- communicator
@@ -52,12 +50,12 @@ int MPI_Comm_test_inter(MPI_Comm comm, int *flag)
 
 	if (comm == MPI_COMM_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPICOMMTESTINTER, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPICOMMTESTINTER, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (flag == 0) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPICOMMTESTINTER, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPICOMMTESTINTER, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	*flag = LAM_IS_INTER(comm) ? 1 : 0;
