@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: dimscreate.c,v 6.5 2002/12/11 19:15:10 jsquyres Exp $
+ * $Id: dimscreate.c,v 6.6 2003/11/02 21:13:10 brbarret Exp $
  *
  *	Function:	- select "best" grid dimensions
  *			- "Greed is good, greed works!" (Gecko)
@@ -33,9 +33,10 @@
 /*
  * static functions
  */
-static int		assignprocs();
-static int		getfactors();
-static int		getprimes();
+static int		assignprocs(int ndim, int nfactor, int *pfacts, 
+                                    int *counts, int **pdims);
+static int		getfactors(int num, int nprime, int *primes, int **pcounts);
+static int		getprimes(int num, int *pnprime, int **pprimes);
 
 /*@
 
@@ -179,14 +180,7 @@ int MPI_Dims_create(int nprocs, int ndims, int *dims)
  *	Returns:	- 0 or ERROR
  */
 static int
-assignprocs(ndim, nfactor, pfacts, counts, pdims)
-
-int			ndim;
-int			nfactor;
-int			*pfacts;
-int			*counts;
-int			**pdims;
-
+assignprocs(int ndim, int nfactor, int *pfacts, int *counts, int **pdims)
 {
 	int		*bins;
 	int		i, j;
@@ -258,13 +252,7 @@ int			**pdims;
  *	Returns:	- 0 or ERROR
  */
 static int
-getfactors(num, nprime, primes, pcounts)
-
-int			num;
-int			nprime;
-int			*primes;
-int			**pcounts;
-
+getfactors(int num, int nprime, int *primes, int **pcounts)
 {
 	int		*counts;
 	int		i;
@@ -317,12 +305,7 @@ int			**pcounts;
  *	Returns:	- 0 or ERROR
  */
 static int
-getprimes(num, pnprime, pprimes)
-
-int			num;
-int			*pnprime;
-int			**pprimes;
-
+getprimes(int num, int *pnprime, int **pprimes)
 {
 	int		i, j;
 	int		n;
