@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD/NJN
+ * $HEADER$
  *
- *	$Id: dupfn.c,v 6.4.2.1 2002/10/09 19:49:07 brbarret Exp $
+ * $Id: dupfn.c,v 6.7 2003/06/02 04:03:30 brbarret Exp $
  *
  *	Function:	- pre-defined simple attribute copy functions
  *	Accepts:	- communicator/datatytpe/window
@@ -27,6 +25,7 @@
  */
 
 #include <mpi.h>
+#include <mpisys.h>
 
 /*@
 
