@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: errclass.c,v 6.3.2.1 2002/10/09 19:49:07 brbarret Exp $
+ * $Id: errclass.c,v 6.5 2002/12/11 19:15:10 jsquyres Exp $
  *
  *	Function:	- get error class of error code
  *	Accepts:	- error code
@@ -54,7 +52,7 @@ int MPI_Error_class(int errcode, int *class)
  */
 	if (class == 0) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPIERRCLASS, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPIERRCLASS, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	lam_bkerr(errcode, class, &func, &error);
