@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD/NJN
+ * $HEADER$
  *
- *	$Id: errget.c,v 6.5.2.1 2002/10/09 19:49:07 brbarret Exp $
+ * $Id: errget.c,v 6.7 2002/12/11 19:15:10 jsquyres Exp $
  *
  *	Function:	- get error handler of communicator
  *	Accepts:	- communicator
@@ -48,12 +46,13 @@ int MPI_Errhandler_get(MPI_Comm comm, MPI_Errhandler *errhdl)
  * Check the arguments.
  */
 	if (comm == MPI_COMM_NULL) {
-		return(lam_err_comm(MPI_COMM_WORLD, MPI_ERR_COMM, 0,
+		return(lam_err_comm(MPI_COMM_WORLD, MPI_ERR_COMM, EINVAL,
 			"null handle"));
 	}
 
 	if (errhdl == 0) {
-		return(lam_err_comm(comm, MPI_ERR_ARG, 0, "null pointer"));
+		return(lam_err_comm(comm, MPI_ERR_ARG, EINVAL, 
+				    "null pointer"));
 	}
 /*
  * Get the communicator's error handler.
