@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD/NJN
+ * $HEADER$
  *
- *	$Id: errstring.c,v 6.7.2.1 2002/10/09 19:49:07 brbarret Exp $
+ * $Id: errstring.c,v 6.10 2003/05/31 22:28:50 jsquyres Exp $
  *
  *	Function:	- return the MPI error message
  *	Accepts:	- error code
@@ -33,6 +31,8 @@
 #include <mpisys.h>
 #include <terror.h>
 #include <typical.h>
+#include <etc_misc.h>
+
 
 /*
  * error messages
@@ -122,7 +122,7 @@ int MPI_Error_string(int errcode, char *msg,
  */
 	if ((msg == 0) || (plen == 0)) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPIERRSTRING, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPIERRSTRING, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 /*
  * Create the error message string.
@@ -150,7 +150,7 @@ int MPI_Error_string(int errcode, char *msg,
 			strcat(buf, mpierrmsg[class]);
 		} else {
 			strcat(buf, "unknown error class");
-			err = lam_mkerr(MPI_ERR_ARG, 0);
+			err = lam_mkerr(MPI_ERR_ARG, EINVAL);
 		}
 
 		if (error > 0) {
@@ -163,7 +163,7 @@ int MPI_Error_string(int errcode, char *msg,
 /*
  * Fill the user's message buffer.
  */
-	strncpy(msg, buf, MPI_MAX_ERROR_STRING - 1);
+	lam_strncpy(msg, buf, MPI_MAX_ERROR_STRING - 1);
 	msg[MPI_MAX_ERROR_STRING - 1] = '\0';
 	*plen = strlen(msg);
 
