@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio	State University
- *	NJN/RBD
+ * $HEADER$
  *
- *	$Id: init_f.c,v 6.5.2.1 2002/10/09 19:49:33 brbarret Exp $
+ *	$Id: init_f.c,v 6.8 2003/05/07 20:13:41 brbarret Exp $
  *
  *	Function:	- MPI_Init F77 wrapper
  */
@@ -29,20 +27,21 @@
 #include <MPISYSF.h>
 #include <mpisys.h>
 
+
 void
-mpi_init_(ierror)
-
-int			*ierror;
-
+mpi_init_(int *ierror)
 {
 	int		argc;
-	char		*argv[1];
+	char		*argv[2];
 	char		**pargv;
 /*
  * Do an MPI_Init().
  */
 	argc = 1;
-	argv[0]	= "LAM_MPI_Fortran_program";
+	argv[0] = getenv("LAM_MPI_PROCESS_NAME");
+	if (argv[0] == NULL)
+	  argv[0]	= "LAM_MPI_Fortran_program";
+	argv[1] = NULL;
 	pargv =	argv;
 
 	lam_f77init = 1;
