@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2006 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -11,11 +11,6 @@
  * LAM/MPI source distribution.
  * 
  * $HEADER$
- *	Ohio Trollius
- *	Copyright 1996 The Ohio	State University
- *	RBD/NJN
- *
- *	$Id: keycreate_f.c,v 6.8 2002/10/09 20:59:05 brbarret Exp $
  *
  *	Function:	- MPI_Keyval_create F77	wrapper
  */
@@ -58,7 +53,7 @@ int	*k, *es, *ierr;
 	}
 
 	df_C = (df == mpi_null_delete_fn_ || df == mpi_comm_null_delete_fn_)
-	    		? 0 : (MPI_Delete_function *) df;
+	    		? NULL : (MPI_Delete_function *) df;
 
 	*ierr =	MPI_Keyval_create(cf_C, df_C, k, 
 				  (void *) LAM_INT_TO_VOID_P *es);
