@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -11,11 +11,8 @@
  * LAM/MPI source distribution.
  * 
  * $HEADER$
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN
  *
- *	$Id: spawnmult_f.c,v 6.9 2002/12/18 17:14:20 jsquyres Exp $
+ * $Id: spawnmult_f.c,v 6.10 2003/07/06 10:44:02 jsquyres Exp $
  *
  *	Function:	- MPI_Comm_spawn_multiple F77 wrapper
  */
@@ -25,7 +22,7 @@
 #include <errno.h>
 #include <stdlib.h>
 
-#include <args.h>
+#include <sfh.h>
 #include <blktype.h>
 #include <mpi.h>
 #include <MPISYSF.h>
@@ -67,16 +64,16 @@ f2c_argvs(int dim, char *array, int len, char ****argvs)
 
 			if (cstr == 0) {
 				for (j = 0; j <= i; j++) {
-					argvfree(argvarr[j]);
+					sfh_argv_free(argvarr[j]);
 				}
 				return(LAMERROR);
 			}
 
 			if (*cstr == 0) break;
 
-			if (argvadd(&argc, &argvarr[i], cstr)) {
+			if (sfh_argv_add(&argc, &argvarr[i], cstr)) {
 				for (j = 0; j <= i; j++) {
-					argvfree(argvarr[j]);
+					sfh_argv_free(argvarr[j]);
 				}
 				return(LAMERROR);
 			}
@@ -103,7 +100,7 @@ f2c_argvs_free(int n, char ***argvs)
 
 	if (argvs) {
 		for (i = 0; i < n; i++)
-			argvfree(argvs[i]);
+			sfh_argv_free(argvs[i]);
 
 		free(argvs);
 	}
@@ -111,7 +108,8 @@ f2c_argvs_free(int n, char ***argvs)
 
 void
 mpi_comm_spawn_multiple_(int *n, char *cmd, char *av, int *mps, int *infs, 
-	int *root, int *comm, int *icomm, int *ec, int *ierr, int nc, int na)
+                         int *root, int *comm, int *icomm, int *ec, 
+                         int *ierr, int nc, int na)
 {
 	MPI_Comm	intercomm;
 	MPI_Info	*infos;
@@ -125,7 +123,7 @@ mpi_comm_spawn_multiple_(int *n, char *cmd, char *av, int *mps, int *infs,
 	if (*n <= 0) {
 		lam_setfunc(BLKMPICOMMSPAWNMULT);
 		*ierr = lam_errfunc(GETHDL(*comm), BLKMPICOMMSPAWNMULT,
-					lam_mkerr(MPI_ERR_ARG, 0));
+                                    lam_mkerr(MPI_ERR_ARG, 0));
 		return;
 	}
 /*
@@ -134,7 +132,7 @@ mpi_comm_spawn_multiple_(int *n, char *cmd, char *av, int *mps, int *infs,
 	if ((infos = (MPI_Info *) malloc(*n * sizeof(MPI_Info *))) == 0) {
 		lam_setfunc(BLKMPICOMMSPAWNMULT);
 		*ierr = lam_errfunc(GETHDL(*comm), BLKMPICOMMSPAWNMULT,
-					lam_mkerr(MPI_ERR_SPAWN, errno));
+                                    lam_mkerr(MPI_ERR_SPAWN, errno));
 		return;
 	}
 
@@ -159,7 +157,7 @@ mpi_comm_spawn_multiple_(int *n, char *cmd, char *av, int *mps, int *infs,
 		if (f2c_argvs(*n, av, na, &argvs)) {
 			lam_setfunc(BLKMPICOMMSPAWNMULT);
 			*ierr = lam_errfunc(GETHDL(*comm), BLKMPICOMMSPAWNMULT,
-					lam_mkerr(MPI_ERR_SPAWN, errno));
+                                            lam_mkerr(MPI_ERR_SPAWN, errno));
 			free((char *) infos);
 			return;
 		}
@@ -170,20 +168,21 @@ mpi_comm_spawn_multiple_(int *n, char *cmd, char *av, int *mps, int *infs,
 	if (lam_F2C_argv(cmd, nc, &commands)) {
 		lam_setfunc(BLKMPICOMMSPAWNMULT);
 		*ierr = lam_errfunc(GETHDL(*comm), BLKMPICOMMSPAWNMULT,
-					lam_mkerr(MPI_ERR_SPAWN, errno));
+                                    lam_mkerr(MPI_ERR_SPAWN, errno));
 		f2c_argvs_free(*n, argvs);
 		free((char *) infos);
 		return;
 	}
 
 	*ierr = MPI_Comm_spawn_multiple(*n, commands, argvs, mps, infos,
-				*root, GETHDL(*comm), &intercomm, errs);
+                                        *root, GETHDL(*comm), &intercomm, 
+                                        errs);
 
 	if (lam_F_make_hdl(icomm, ierr, intercomm, BLKMPICOMMSPAWNMULT)) {
 		intercomm->c_f77handle = *icomm;
 	}
 
-	argvfree(commands);
+	sfh_argv_free(commands);
 	f2c_argvs_free(*n, argvs);
 	free((char *) infos);
 }
