@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- *      $Id: wcallerr_f.c,v 1.1 2003/01/17 08:28:11 vsahay Exp $
+ *      $Id: wcallerr_f.c,v 1.2 2003/08/05 23:19:15 vsahay Exp $
  *
  *      Function:       - MPI_Win_callerr F77 wrapper
  */
@@ -26,5 +26,5 @@
 void
 mpi_win_call_errhandler_(int *w, int *e, int *ierr)
 {
-  *ierr = MPI_Win_call_errhandler(GETHDL(*w), e);
+  *ierr = MPI_Win_call_errhandler(GETHDL(*w), *e);
 }
