@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- *      $Id: wunlock_f.c,v 1.1 2003/01/17 08:28:11 vsahay Exp $
+ *      $Id: wunlock_f.c,v 1.2 2003/08/05 23:19:15 vsahay Exp $
  *
  *      Function:       - MPI_Win_unlock F77 wrapper
  */
@@ -26,5 +26,5 @@
 void
 mpi_win_unlock_(int *r, int *w, int *ierr)
 {
-  *ierr = MPI_Win_unlock(r, GETHDL(*w));
+  *ierr = MPI_Win_unlock(*r, GETHDL(*w));
 }
