@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: finalize.c,v 6.36.2.1 2003/08/19 20:21:19 jsquyres Exp $
+ * $Id: finalize.c,v 6.40 2004/03/02 03:43:29 jsquyres Exp $
  *
  *	Function:	- terminate the MPI session
  *	Returns:	- MPI_SUCCESS or error code
@@ -180,8 +180,13 @@ MPI_Finalize(void)
 	lam_ssi_rpi_base_close();
 
         /* MPI SSI kind: CRMPI */
+
         lam_ssi_crmpi_base_close();
 
+        /* Shut down SSI itself */
+
+        lam_ssi_base_close();
+
         /* Kill all the procs */
 
  	lam_nukeprocs();
@@ -301,7 +306,7 @@ free_comm_self(void)
 	/* Tell the collective SSI module that this communicator is
 	   gone.  It's too late to worry about errors. */
 
-	MPI_COMM_SELF->c_ssi_coll.lsca_finalize(MPI_COMM_SELF);
+	lam_ssi_coll_base_finalize_comm(MPI_COMM_SELF);
 
 	/* Free the error handler, if a user error handler was defined
  	   on it (otherwise, we have a memory leak) */
@@ -342,7 +347,7 @@ free_comms(void)
 	for (comm = al_top(lam_comms); comm != NULL; 
 	     comm = al_next(lam_comms, comm))
 	  if (*comm != MPI_COMM_SELF)
-	    (*comm)->c_ssi_coll.lsca_finalize(*comm);
+	    lam_ssi_coll_base_finalize_comm(*comm);
 
 /*
  * Free the "parent" communicator if any.
