@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: finalized.c,v 6.1.2.1 2002/10/09 19:49:07 brbarret Exp $
+ * $Id: finalized.c,v 6.4 2002/12/11 19:15:10 jsquyres Exp $
  *
  *	Function:	- check if MPI has been finalized
  *	Accepts:	- result flag (out)
@@ -45,6 +43,12 @@ This function always returns 'MPI_SUCCESS'.
 @*/
 int MPI_Finalized(int *flag)
 {
+  /*
+   * This function (like MPI_INITIALIZED) is called from MPI_INIT and
+   * MPI_FINALIZE.  Because of this, badness may occur if
+   * lam_initerr() is called within this function.
+   */
+
   if (flag)
     *flag = lam_finalized();
   
