@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: gather.c,v 6.14 2003/02/04 18:06:51 jsquyres Exp $
+ * $Id: gather.c,v 6.16 2004/03/02 03:43:29 jsquyres Exp $
  *
  *	Function:	- gather buffers at root in process rank order
  *	Accepts:	- send buffer
@@ -87,26 +87,38 @@ int MPI_Gather(void *sbuf, int scount, MPI_Datatype sdtype,
 	  return(lam_errfunc(comm, BLKMPIGATHER,
 			     lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
-	func = LAM_IS_INTER(comm) ?
-	  comm->c_ssi_coll.lsca_gather_inter :
-	  comm->c_ssi_coll.lsca_gather_intra;
+	func = comm->c_ssi_coll.lsca_gather;
 
-	MPI_Comm_rank(comm, &rank);
-	MPI_Comm_size(comm, &size);
-	if ((root >= size) || (root < 0)) {
-	  return(lam_errfunc(comm, BLKMPIGATHER,
-			     lam_mkerr(MPI_ERR_ROOT, EINVAL)));
-	}
-
-	if ((sdtype == MPI_DATATYPE_NULL) ||
-	    (rank == root && rdtype == MPI_DATATYPE_NULL)) {
-	  return(lam_errfunc(comm, BLKMPIGATHER,
-			     lam_mkerr(MPI_ERR_TYPE, EINVAL)));
-	}
-
-	if ((scount < 0) || (rank == root && rcount < 0)) {
+	if (LAM_IS_INTRA(comm)) {
+	  /* conditions for intracomm */
+	  MPI_Comm_size(comm, &size);
+	  MPI_Comm_rank(comm, &rank);
+	  if ((root >= size) || (root < 0)) {
+	    return(lam_errfunc(comm, BLKMPIGATHER,
+			       lam_mkerr(MPI_ERR_ROOT, EINVAL)));
+	  }
+	  if ((scount < 0) || (rank == root && rcount < 0)) {
 	  return(lam_errfunc(comm, BLKMPIGATHER,
 			     lam_mkerr(MPI_ERR_COUNT, EINVAL)));
+	  }
+	  if ((sdtype == MPI_DATATYPE_NULL) ||
+	      (rank == root && rdtype == MPI_DATATYPE_NULL)) {
+	    return(lam_errfunc(comm, BLKMPIGATHER,
+			       lam_mkerr(MPI_ERR_TYPE, EINVAL)));
+	  }
+	} else {
+	  /* Conditions for intercomm */
+	  MPI_Comm_remote_size(comm, &size);
+	  if (((root != MPI_PROC_NULL) && (sdtype == MPI_DATATYPE_NULL)) ||
+	      (root == MPI_ROOT  && rdtype == MPI_DATATYPE_NULL)) {
+	    return(lam_errfunc(comm, BLKMPIGATHER,
+			       lam_mkerr(MPI_ERR_TYPE, EINVAL)));
+	  }
+	  if (!(((root < size) && (root >= 0)) 
+		|| (root == MPI_ROOT) || (root == MPI_PROC_NULL))) {
+	    return(lam_errfunc(comm, BLKMPIGATHER, 
+			       lam_mkerr(MPI_ERR_ROOT, EINVAL)));
+	  }
 	}
 
 	if (func == NULL) {
