@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN
+ * $HEADER$
  *
- *	$Id: get.c,v 1.3.2.1 2002/10/09 19:49:07 brbarret Exp $
+ * $Id: get.c,v 1.5 2002/12/11 19:15:10 jsquyres Exp $
  *
  *	Function:	- get data from a window
  *	Accepts:	- origin address
@@ -100,7 +98,7 @@ MPI_Win			win;
  * Check arguments.
  */
 	if (win == MPI_WIN_NULL) {
-		return(lam_err_comm(MPI_COMM_WORLD, MPI_ERR_WIN, 0,
+		return(lam_err_comm(MPI_COMM_WORLD, MPI_ERR_WIN, EINVAL,
 			"null handle"));
 	}
 
