@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN
+ * $HEADER$
  *
- *	$Id: getaddress.c,v 1.2.2.1 2002/10/09 19:49:08 brbarret Exp $
+ * $Id: getaddress.c,v 1.4 2002/12/11 19:15:10 jsquyres Exp $
  *
  *	Function:	- get address of location
  *	Accepts:	- location
@@ -53,7 +51,7 @@ MPI_Get_address(void *loc, MPI_Aint *addr)
 	lam_setfunc_m(BLKMPIGETADDRESS);
 
 	if (addr == 0) {
-		return(lam_err_comm(MPI_COMM_WORLD, MPI_ERR_ARG, 0,
+		return(lam_err_comm(MPI_COMM_WORLD, MPI_ERR_ARG, EINVAL,
 			"null pointer"));
 	}
 
