@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: getelem.c,v 6.7 2002/12/11 19:15:10 jsquyres Exp $
+ * $Id: getelem.c,v 6.8 2003/11/02 21:13:10 brbarret Exp $
  *
  *	Function:	- get # bottom-level elements
  *	Accepts:	- status
@@ -28,7 +28,7 @@
 /*
  * private functions
  */
-static int		subcount();
+static int		subcount(int left, MPI_Datatype dtype);
 
 
 /*@
@@ -120,11 +120,7 @@ int MPI_Get_elements(MPI_Status *stat, MPI_Datatype dtype,
  *	Returns:	- count of bottom level elements
  */
 static int
-subcount(left, dtype)
-
-int			left;
-MPI_Datatype		dtype;
-
+subcount(int left, MPI_Datatype dtype)
 {
 	int		i;
 	int		elts;			/* # basic elements */
