@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: getprocname.c,v 6.3.2.1 2002/10/09 19:49:08 brbarret Exp $
+ * $Id: getprocname.c,v 6.6 2002/12/11 19:15:10 jsquyres Exp $
  *
  *	Function:	- get the host name
  *	Accepts:	- name buffer (returned value)
@@ -29,8 +27,8 @@
 #include <mpisys.h>
 #include <terror.h>
 
-extern int		gethostname();
-
+#include <laminternal.h>
+#include <lam_network.h>
 
 /*@
   MPI_Get_processor_name - Gets the name of the processor
@@ -55,7 +53,7 @@ int MPI_Get_processor_name(char *name, int *len)
 	lam_initerr();
 	lam_setfunc(BLKMPIGETPNAME);
 
-	if (gethostname(name, MPI_MAX_PROCESSOR_NAME - 1)) {
+	if (lam_gethostname(name, MPI_MAX_PROCESSOR_NAME - 1)) {
 		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIGETPNAME,
 				lam_mkerr(MPI_ERR_OTHER, errno)));
 	} else {
