@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: gfree.c,v 6.5.2.1 2002/10/09 19:49:08 brbarret Exp $
+ * $Id: gfree.c,v 6.7 2002/12/11 19:15:11 jsquyres Exp $
  *
  *	Function:	- free a group
  *	Accepts:	- group (in-out)
@@ -59,7 +57,7 @@ int MPI_Group_free(MPI_Group *grp)
 
 	if (grp == 0 || *grp == MPI_GROUP_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPIGROUPFREE, lam_mkerr(MPI_ERR_GROUP, 0)));
+			BLKMPIGROUPFREE, lam_mkerr(MPI_ERR_GROUP, EINVAL)));
 	} else {
 		if ((--(*grp)->g_refcount) == 0) {
 /*
@@ -71,7 +69,7 @@ int MPI_Group_free(MPI_Group *grp)
 				(*grp)->g_refcount++;
 				return(lam_errfunc(MPI_COMM_WORLD,
 					BLKMPIGROUPFREE,
-					lam_mkerr(MPI_ERR_GROUP, 0)));
+					lam_mkerr(MPI_ERR_GROUP, EINVAL)));
 			}
 
 			for (i = (*grp)->g_nprocs, p = (*grp)->g_procs; i > 0;
