@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: grank.c,v 6.3.2.1 2002/10/09 19:49:08 brbarret Exp $
+ * $Id: grank.c,v 6.5 2002/12/11 19:15:11 jsquyres Exp $
  *
  *	Function:	- get caller's rank in group
  *	Accepts:	- group
@@ -56,11 +54,11 @@ MPI_Group_rank(MPI_Group group, int *prank)
 	}
 	else if (group == MPI_GROUP_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPIGROUPRANK, lam_mkerr(MPI_ERR_GROUP, 0)));
+			BLKMPIGROUPRANK, lam_mkerr(MPI_ERR_GROUP, EINVAL)));
 	}
 	else {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPIGROUPRANK, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPIGROUPRANK, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	lam_resetfunc(BLKMPIGROUPRANK);
