@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: graphdimsget.c,v 6.3.2.1 2002/10/09 19:49:08 brbarret Exp $
+ * $Id: graphdimsget.c,v 6.5 2002/12/11 19:15:11 jsquyres Exp $
  *
  *	Function:	- get # nodes/edges in graph topology
  *	Accepts:	- communicator
@@ -58,22 +56,22 @@ int MPI_Graphdims_get(MPI_Comm comm, int *pnodes, int *pedges)
  */
 	if (comm == MPI_COMM_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPIGRAPHDIMSGET, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPIGRAPHDIMSGET, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (LAM_IS_INTER(comm)) {
 		return(lam_errfunc(comm,
-			BLKMPIGRAPHDIMSGET, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPIGRAPHDIMSGET, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (!LAM_IS_GRAPH(comm)) {
 		return(lam_errfunc(comm, BLKMPIGRAPHDIMSGET,
-				lam_mkerr(MPI_ERR_TOPOLOGY, 0)));
+				lam_mkerr(MPI_ERR_TOPOLOGY, EINVAL)));
 	}
 
 	if ((pnodes == 0) || (pedges == 0)) {
 		return(lam_errfunc(comm,
-			BLKMPIGRAPHDIMSGET, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPIGRAPHDIMSGET, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	*pnodes = comm->c_topo_nprocs;
