@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: graphnbr.c,v 6.3.2.1 2002/10/09 19:49:08 brbarret Exp $
+ * $Id: graphnbr.c,v 6.5 2002/12/11 19:15:11 jsquyres Exp $
  *
  *	Function:	- get neighbours of a process
  *	Accepts:	- communicator
@@ -67,27 +65,27 @@ int MPI_Graph_neighbors(MPI_Comm comm, int rank,
  */
 	if (comm == MPI_COMM_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPIGRAPHNBR, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPIGRAPHNBR, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (LAM_IS_INTER(comm)) {
 		return(lam_errfunc(comm,
-			BLKMPIGRAPHNBR, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPIGRAPHNBR, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (!LAM_IS_GRAPH(comm)) {
 		return(lam_errfunc(comm, BLKMPIGRAPHNBR,
-				lam_mkerr(MPI_ERR_TOPOLOGY, 0)));
+				lam_mkerr(MPI_ERR_TOPOLOGY, EINVAL)));
 	}
 
 	if ((rank < 0) || (rank >= comm->c_group->g_nprocs)) {
 		return(lam_errfunc(comm,
-			BLKMPIGRAPHNBR, lam_mkerr(MPI_ERR_RANK, 0)));
+			BLKMPIGRAPHNBR, lam_mkerr(MPI_ERR_RANK, EINVAL)));
 	}
 
 	if ((maxnbrs < 0) || ((maxnbrs > 0) && (nbrs == 0))) {
 		return(lam_errfunc(comm,
-			BLKMPIGRAPHNBR, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPIGRAPHNBR, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 /*
  * Fill the neighbours.
