@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: graphnbrcount.c,v 6.3.2.1 2002/10/09 19:49:08 brbarret Exp $
+ * $Id: graphnbrcount.c,v 6.5 2002/12/11 19:15:11 jsquyres Exp $
  *
  *	Function:	- get # neighbours for a process
  *	Accepts:	- communicator
@@ -60,27 +58,27 @@ int MPI_Graph_neighbors_count(MPI_Comm comm, int rank,
  */
 	if (comm == MPI_COMM_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPIGRAPHNBRCOUNT, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPIGRAPHNBRCOUNT, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (LAM_IS_INTER(comm)) {
 		return(lam_errfunc(comm,
-			BLKMPIGRAPHNBRCOUNT, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPIGRAPHNBRCOUNT, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (!LAM_IS_GRAPH(comm)) {
 		return(lam_errfunc(comm, BLKMPIGRAPHNBRCOUNT,
-				lam_mkerr(MPI_ERR_TOPOLOGY, 0)));
+				lam_mkerr(MPI_ERR_TOPOLOGY, EINVAL)));
 	}
 
 	if ((rank < 0) || (rank >= comm->c_group->g_nprocs)) {
 		return(lam_errfunc(comm,
-			BLKMPIGRAPHNBRCOUNT, lam_mkerr(MPI_ERR_RANK, 0)));
+			BLKMPIGRAPHNBRCOUNT, lam_mkerr(MPI_ERR_RANK, EINVAL)));
 	}
 
 	if (pnbr == 0) {
 		return(lam_errfunc(comm,
-			BLKMPIGRAPHNBRCOUNT, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPIGRAPHNBRCOUNT, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	*pnbr = comm->c_topo_index[rank];
