@@ -1,38 +1,18 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
- * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: gtranks.c,v 6.4 1999/12/31 21:27:28 jsquyres Exp $
+ * $Id: gtranks.c,v 6.6 2002/12/11 19:15:11 jsquyres Exp $
  *
  *	Function:	- get process ranks in a second group
  *	Accepts:	- first group
@@ -86,7 +66,7 @@ int MPI_Group_translate_ranks(MPI_Group g1, int n,
  */
 	if ((g1 == MPI_GROUP_NULL) || (g2 == MPI_GROUP_NULL)) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPIGROUPTRANKS, lam_mkerr(MPI_ERR_GROUP, 0)));
+			BLKMPIGROUPTRANKS, lam_mkerr(MPI_ERR_GROUP, EINVAL)));
 	}
 
 	if (n == 0) {
@@ -96,7 +76,7 @@ int MPI_Group_translate_ranks(MPI_Group g1, int n,
 
 	if ((n < 0) || (r1 == 0) || (r2 == 0)) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPIGROUPTRANKS, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPIGROUPTRANKS, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 /*
  * Loop over the processes, translating their ranks.
@@ -117,7 +97,8 @@ int MPI_Group_translate_ranks(MPI_Group g1, int n,
 		}
 		else {
 			return(lam_errfunc(MPI_COMM_WORLD,
-				BLKMPIGROUPTRANKS, lam_mkerr(MPI_ERR_RANK, 0)));
+					   BLKMPIGROUPTRANKS, 
+					   lam_mkerr(MPI_ERR_RANK, EINVAL)));
 		}
 	}
 
