@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: ibsend.c,v 6.5.2.1 2002/10/09 19:49:08 brbarret Exp $
+ * $Id: ibsend.c,v 6.8 2003/02/20 19:57:13 jsquyres Exp $
  *
  *	Function:	- immediate buffered send
  *	Accepts:	- buffer
@@ -96,9 +94,9 @@ int MPI_Ibsend(void *buf, int count, MPI_Datatype dtype,
 /*
  * Check the tag.
  */
-	if (tag < 0 || tag > LAM_MAXTAG) {
+	if (tag < 0 || tag > lam_mpi_max_tag) {
 		return(lam_errfunc(comm, BLKMPIIBSEND,
-				lam_mkerr(MPI_ERR_TAG, 0)));
+				lam_mkerr(MPI_ERR_TAG, EINVAL)));
 	}
 /*
  * Create the fake user request.  We do not add it into the
