@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2004 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: icmerge.c,v 6.9.2.1 2003/07/17 19:13:08 jsquyres Exp $
+ * $Id: icmerge.c,v 6.10 2003/07/17 19:12:38 jsquyres Exp $
  *
  *	Function:	- merge inter-communicator into intra-communicator
  *	Accepts:	- inter-communicator
@@ -59,12 +59,16 @@ Output Parameter:
 int MPI_Intercomm_merge(MPI_Comm comm, int high, 
 			MPI_Comm *newcomm)
 {
-	MPI_Request	req;
 	MPI_Group	newgroup;		/* new group */
 	MPI_Group	g1, g2;			/* 2 groups to merge */
 	int		cid;			/* global context ID */
 	int		rhigh;			/* remote high value */
 	int		err;			/* error code */
+	int             lower;                  /* used only during merging
+                                                 * during coll init for an
+						 * intercomm 
+						 */
+	int             rsize, rank, i;
 
 	lam_initerr_m();
 	lam_setfunc_m(BLKMPIICOMMMERGE);
@@ -104,31 +108,32 @@ int MPI_Intercomm_merge(MPI_Comm comm, int high,
 	err = lam_coll_alloc_inter_cid(comm, 0, comm, 0, MPI_MERGE_TAG, 
 				       BLKMPIICOMMMERGE, &cid);
 	if (err != MPI_SUCCESS)
-	  return(lam_errfunc(comm, BLKMPIICOMMCREATE, err));
+	  return(lam_errfunc(comm, BLKMPIICOMMMERGE, err));
 
-	/* Swap "high" values between group leaders */
-
-	if (comm->c_group->g_myrank == 0) {
-	  err = lam_irecv(&rhigh, 1, MPI_INT, 0, MPI_MERGE_TAG, comm, &req);
-	  if (err == MPI_SUCCESS)
-	    err = lam_send(&high, 1, MPI_INT, 0, MPI_MERGE_TAG, comm, 
-			   LAM_RQISEND);
-
-	  if (err == MPI_SUCCESS)
-	    err = MPI_Wait(&req, MPI_STATUS_IGNORE);
-
-	  if (err != MPI_SUCCESS)
-	    return(lam_errfunc(comm, BLKMPIICOMMMERGE, err));
+	/* Send high value to all the remote processes */
+	MPI_Comm_remote_size(comm, &rsize);
+	MPI_Comm_rank(comm, &rank);
+	lower = (lam_proccmp(comm->c_group->g_procs[0],
+			     comm->c_rgroup->g_procs[0]) < 0) ? 1 : 0;
+	
+	if (lower) {
+	  if (rank == 0) {
+	    for (i = 0; i < rsize; ++i) {
+	      MPI_Send(&high, 1, MPI_INT, i, BLKMPIICOMMMERGE, comm);
+	    }
+	  }
+	  MPI_Recv(&rhigh, 1, MPI_INT, 0, BLKMPIICOMMMERGE, comm, 
+		   MPI_STATUS_IGNORE);
+	} else {
+	  MPI_Recv(&rhigh, 1, MPI_INT, 0, BLKMPIICOMMMERGE, comm,
+		   MPI_STATUS_IGNORE);
+	  if (rank == 0) {
+	    for (i = 0; i < rsize; ++i) {
+	      MPI_Send(&high, 1, MPI_INT, i, BLKMPIICOMMMERGE, comm);
+	    }
+	  }
 	}
 
-	/* Now broadcast the remote group's high value to my local
-	   group.  Fake swapping this comm to an intracomm so that we
-	   can do a local broadcast on it. */
-
-	comm->c_flags &= ~LAM_CINTER;
-	MPI_Bcast(&rhigh, 1, MPI_INT, 0, comm);
-	comm->c_flags |= LAM_CINTER;
-
 /*
  * All procs know the "high" for local and remote groups and the context ID.
  * Create the properly ordered union group.  In case of equal high values,
