@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: infocreate.c,v 6.7 2002/12/11 19:15:11 jsquyres Exp $
+ * $Id: infocreate.c,v 6.8 2003/11/02 21:13:10 brbarret Exp $
  *
  *	Function:	- info object constructor
  *	Accepts:	- info (out)
@@ -31,7 +31,7 @@
 /*
  * private functions
  */
-static int		info_key_cmp();
+static int		info_key_cmp(struct _infoent *a, struct _infoent *b);
 
 
 /*@
@@ -94,11 +94,7 @@ int MPI_Info_create(MPI_Info *info)
  *	Returns:	- string comparison of keys
  */
 static int
-info_key_cmp(a, b)
-
-struct _infoent	*a;
-struct _infoent	*b;
-
+info_key_cmp(struct _infoent *a, struct _infoent *b)
 {
 	return(strcmp(a->ie_key, b->ie_key));
 }
