@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN
+ * $HEADER$
  *
- *	$Id: infodel.c,v 6.5.2.1 2002/10/09 19:49:09 brbarret Exp $
+ * $Id: infodel.c,v 6.7 2002/12/11 19:15:11 jsquyres Exp $
  *
  *	Function:	- delete info key and associated value
  *	Accepts:	- info (inout)
@@ -62,13 +60,13 @@ int MPI_Info_delete(MPI_Info info, char *key)
 	
 	if (info == 0) {
 		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIINFODEL,
-					lam_mkerr(MPI_ERR_ARG, 0)));
+					lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	keylen = (key) ? strlen(key) : 0;
 	if (keylen == 0 || keylen > MPI_MAX_INFO_KEY) {
 		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIINFODEL,
-					lam_mkerr(MPI_ERR_INFO_KEY, 0)));
+					lam_mkerr(MPI_ERR_INFO_KEY, EINVAL)));
 	}
 
 	strcpy(search.ie_key, key);
@@ -77,11 +75,11 @@ int MPI_Info_delete(MPI_Info info, char *key)
 		if (found->ie_value) free(found->ie_value);
 		if (al_delete(info->info_list, found) < 0) {
 			return(lam_errfunc(MPI_COMM_WORLD, BLKMPIINFODEL,
-						lam_mkerr(MPI_ERR_INTERN, 0)));
+					   lam_mkerr(MPI_ERR_INTERN, EINVAL)));
 		}
 	} else {
 		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIINFODEL,
-					lam_mkerr(MPI_ERR_INFO_NOKEY, 0)));
+				   lam_mkerr(MPI_ERR_INFO_NOKEY, EINVAL)));
 	}
 
         lam_resetfunc_m(BLKMPIINFODEL);
