@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN
+ * $HEADER$
  *
- *	$Id: infofree.c,v 6.6.2.1 2002/10/09 19:49:09 brbarret Exp $
+ * $Id: infofree.c,v 6.8 2002/12/11 19:15:11 jsquyres Exp $
  *
  *	Function:	- free an info object
  *	Accepts:	- info (modified)
@@ -56,7 +54,7 @@ int MPI_Info_free(MPI_Info *info)
 
 	if (info == 0) {
 		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIINFOFREE,
-					lam_mkerr(MPI_ERR_ARG, 0)));
+					lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	for (p = al_top((*info)->info_list); p;
