@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN
+ * $HEADER$
  *
- *	$Id: infogetnth.c,v 6.5.2.1 2002/10/09 19:49:09 brbarret Exp $
+ * $Id: infogetnth.c,v 6.7 2002/12/11 19:15:11 jsquyres Exp $
  *
  *	Function:	- get n'th key in info object
  *	Accepts:	- info
@@ -60,7 +58,7 @@ int MPI_Info_get_nthkey(MPI_Info info, int n, char *key)
 
 	if (info == 0 || n >= al_count(info->info_list) || key == 0) {
 		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIINFOGETNTHKEY,
-					lam_mkerr(MPI_ERR_ARG, 0)));
+					lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	for (p = al_top(info->info_list); n > 0; n--) {
