@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: inited.c,v 6.3.2.1 2002/10/09 19:49:09 brbarret Exp $
+ * $Id: inited.c,v 6.6 2002/12/11 19:15:11 jsquyres Exp $
  *
  *	Function:	- check if MPI has been initialized
  *	Accepts:	- result flag (out)
@@ -42,6 +40,12 @@ This function always returns 'MPI_SUCCESS'.
 @*/
 int MPI_Initialized(int *flag)
 {
+  /*
+   * This function (like MPI_FINALIZED) is called from MPI_INIT and
+   * MPI_FINALIZE.  Because of this, badness may occur if
+   * lam_initerr() is called within this function.
+   */
+
 	if (flag) {
 		*flag = lam_inited();
 	}
