@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: isend.c,v 6.7.2.1 2002/10/09 19:49:09 brbarret Exp $
+ * $Id: isend.c,v 6.10 2003/02/20 19:57:13 jsquyres Exp $
  *
  *	Function:	- immediate send
  *	Accepts:	- buffer
@@ -93,9 +91,9 @@ int MPI_Isend(void *buf, int count, MPI_Datatype dtype,
 	lam_initerr_m();
 	lam_setfunc_m(BLKMPIISEND);
 
-	if (tag < 0 || tag > LAM_MAXTAG) {
+	if (tag < 0 || tag > lam_mpi_max_tag) {
 		return(lam_errfunc(comm, BLKMPIISEND,
-				lam_mkerr(MPI_ERR_TAG, 0)));
+				lam_mkerr(MPI_ERR_TAG, EINVAL)));
 	}
 
 	if ((fl_trace = LAM_TRACE_TOP())) startt = MPI_Wtime();
