@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: lamattr.c,v 6.9 2002/12/11 19:15:12 jsquyres Exp $
+ * $Id: lamattr.c,v 6.10 2003/11/23 15:02:24 jsquyres Exp $
  *
  *	Function:	- manage table of attribute keys
  */
@@ -27,14 +27,11 @@
 #include <portable.h>
 #include <terror.h>
 #include <typical.h>
+#include <etc_misc.h>
 
 #define DEFATTRSIZE	8
 #define DEFKEYSIZE	11			/* prime number */
 
-/*
- * external functions
- */
-extern int4		next_prime();
 
 /*
  * static variables
@@ -53,8 +50,7 @@ static int		intpos = -1;
  *	Returns:	- key or ERROR
  */
 int
-lam_mkkey()
-
+lam_mkkey(void)
 {
 	struct _attrkey	*p;
 	int		i;
@@ -114,6 +110,7 @@ lam_mkkey()
 	return(i);
 }
 
+
 /*
  *	lam_getattr
  *
@@ -122,10 +119,7 @@ lam_mkkey()
  *	Returns:	- ptr to attribute or NULL
  */
 struct _attrkey *
-lam_getattr(key)
-
-int			key;
-
+lam_getattr(int key)
 {
 	struct _attrkey	*p;
 
@@ -143,6 +137,7 @@ int			key;
 	return(p);
 }
 
+
 /*
  *	lam_freekey
  *
@@ -152,11 +147,7 @@ int			key;
  *	Returns:	- MPI_SUCCESS or error code
  */
 int
-lam_freekey(key, keytype)
-
-int			key;
-int			keytype;
-
+lam_freekey(int key, int keytype)
 {
 	struct _attrkey	*p;
 
@@ -173,6 +164,7 @@ int			keytype;
 	return(MPI_SUCCESS);
 }
 
+
 /*
  *	lam_putkey
  *
@@ -182,11 +174,7 @@ int			keytype;
  *	Returns:	- 0 or ERROR
  */
 int
-lam_putkey(keys, key)
-
-HASH			**keys;
-int			key;
-
+lam_putkey(HASH **keys, int key)
 {
 	struct _attr	elem;
 	struct _attrkey	*p;
@@ -234,6 +222,7 @@ int			key;
 	return(0);
 }
 
+
 /*
  *	lam_getkey
  *
@@ -243,11 +232,7 @@ int			key;
  *	Returns:	- ptr to entry or NULL
  */
 struct _attr *
-lam_getkey(keys, key)
-
-HASH			*keys;
-int			key;
-
+lam_getkey(HASH *keys, int key)
 {
 	struct _attr	*p;
 
@@ -260,6 +245,7 @@ int			key;
 	return(p);
 }
 
+
 /*
  *	lam_delkey
  *
@@ -269,23 +255,19 @@ int			key;
  *	Returns:	- 0 or ERROR
  */
 int
-lam_delkey(keys, key)
-
-HASH			*keys;
-int			key;
-
+lam_delkey(HASH *keys, int key)
 {
 	return(ah_delete(keys, key));
 }
 
+
 /*
  *	lam_nukekeys
  *
  *	Function:	- deallocate all keys (cleanup)
  */
 void
-lam_nukekeys()
-
+lam_nukekeys(void)
 {
 	if (attrs) {
 		free((char *) attrs);
@@ -294,6 +276,7 @@ lam_nukekeys()
 	}
 }
 
+
 /*
  *	lam_keyval_create
  *
@@ -306,14 +289,8 @@ lam_nukekeys()
  *	Returns:	- MPI_SUCCESS or error code
  */
 int
-lam_keyval_create(cpyfunc, delfunc, pkey, extra, keytype)
-
-void_fn			*cpyfunc;
-void_fn			*delfunc;
-int			*pkey;
-void			*extra;
-int			keytype;
-
+lam_keyval_create(lam_void_fn_t cpyfunc, lam_void_fn_t delfunc, int *pkey, 
+                  void *extra, int keytype)
 {
 	int		key;
 	struct _attrkey	*p;
@@ -356,7 +333,7 @@ int			keytype;
  *			  (int**), of where lower (sizeof(int)) bits are
  */
 int
-lam_int_pos()
+lam_int_pos(void)
 {
 #if LAM_SIZEOF_VOID_P <= LAM_SIZEOF_INT
   return 0;
