@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: lamclocks.c,v 6.5 2002/12/11 19:15:12 jsquyres Exp $
+ * $Id: lamclocks.c,v 6.6 2003/11/02 21:13:10 brbarret Exp $
  *
  *	Function:	- synchronize clocks for tracing
  */
@@ -39,15 +39,18 @@
 /*
  * global functions
  */
-int			lam_clocksync();
+int			lam_clocksync(int4 nworld, struct _gps *wgps, float8 *skew);
 
 /*
  * local functions
  */
-static int		sync_leaders();
-static int		sync_master();
-static int		sync_slave();
-static void		sync_fill();
+static int		sync_leaders(int me, int n, int *leaders, 
+                                     struct _gps *wgps, float8 *skew);
+static int		sync_master(struct _gps *master, struct _gps *slave, int iter);
+static int		sync_slave(struct _gps *master, struct _gps *slave, 
+                                   float8 *skew, int iter);
+static void		sync_fill(struct _gps *src, struct _gps *dest, 
+                                  struct nmsg *head);
 
 /*
  *	lam_clocksync
@@ -59,12 +62,7 @@ static void		sync_fill();
  *	Returns:	- 0 or LAMERROR
  */
 int 
-lam_clocksync(nworld, wgps, skew)
-
-int4			nworld;
-struct _gps		*wgps;
-float8			*skew;
-
+lam_clocksync(int4 nworld, struct _gps *wgps, float8 *skew)
 {
 	char	        *msg;			/* ptr message data */
 	struct nmsg	nhead;			/* network message header */
@@ -151,14 +149,7 @@ float8			*skew;
  *	Returns:	- 0 or LAMERROR
  */
 static int
-sync_leaders(me, n, leaders, wgps, skew)
-
-int			me;
-int			n;
-int			*leaders;
-struct _gps		*wgps;
-float8			*skew;
-
+sync_leaders(int me, int n, int *leaders, struct _gps *wgps, float8 *skew)
 {
 	int		i;			/* favourite index */
 
@@ -193,12 +184,7 @@ float8			*skew;
  *	Returns:	- 0 or LAMERROR
  */
 static int
-sync_master(master, slave, iter)
-
-struct _gps	*master;
-struct _gps	*slave;
-int		iter;
-
+sync_master(struct _gps *master, struct _gps *slave, int iter)
 {
 	float8 		local1;
 	float8 		local2;
@@ -267,13 +253,7 @@ int		iter;
  *	Returns:	- 0 or LAMERROR
  */
 static int
-sync_slave(master, slave, skew, iter)
-
-struct _gps	*master;
-struct _gps	*slave;
-float8		*skew;
-int		iter;
-
+sync_slave(struct _gps *master, struct _gps *slave, float8 *skew, int iter)
 {
 	float8		local;
 	char	        *imsg;
@@ -330,12 +310,7 @@ int		iter;
  *			- network message header (filled)
  */
 static void
-sync_fill(src, dest, head)
-
-struct _gps		*src;
-struct _gps		*dest;
-struct nmsg		*head;
-
+sync_fill(struct _gps *src, struct _gps *dest, struct nmsg *head)
 {
 /*
  * Use comm world cid zero and MPI_Init tag.
