@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: lamdeferr.c,v 6.12.2.1 2003/08/21 06:32:00 brbarret Exp $
+ * $Id: lamdeferr.c,v 6.14 2003/11/02 21:13:10 brbarret Exp $
  *
  *	Function:	- default MPI error handlers
  */
@@ -35,7 +35,8 @@
 /*
  * private functions
  */
-static void		report_error();
+static void		report_error(MPI_Comm comm, int errcode, 
+                                     char *errmsg, char *type);
 
 /*
  * public functions
@@ -156,13 +157,7 @@ va_dcl
  *			- handle type (win or comm)
  */
 static void
-report_error(comm, errcode, errmsg, type)
-
-MPI_Comm		comm;
-int			errcode;
-char			*errmsg;
-char			*type;
-
+report_error(MPI_Comm comm, int errcode, char *errmsg, char *type)
 {
 	char		mpierrmsg[MPI_MAX_ERROR_STRING];
 	char		name[MPI_MAX_OBJECT_NAME+1];
