@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2003 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2004 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: lamdtype.c,v 6.11.2.2 2003/09/11 12:40:56 jsquyres Exp $
+ * $Id: lamdtype.c,v 6.12 2003/09/11 12:26:04 jsquyres Exp $
  *
  *	Function:	- miscellaneous and conversion datatype functions
  */
@@ -32,6 +32,8 @@
  */
 int			lam_type_free();
 void			lam_type_setdefaults();
+int                     lam_bottom_dtsnd();
+int                     lam_bottom_dtrcv();
 int			lam_dtsndrcv();
 void			lam_dtcpy();
 void			lam_dtblock();
@@ -222,6 +224,163 @@ lam_type_setdefaults(MPI_Datatype dt)
 	memset(dt->dt_name, 0, sizeof(dt->dt_name));
 }
 
+/*
+ *	lam_dtsnd
+ *
+ *	Function:	- copy MPI message from a process buffer into 
+ *                        LAM buffer
+ *			- send/recv done if cannot optimize
+ *	Accepts:	- send buffer
+ *			- send count
+ *			- send datatype
+ *			- receive buffer
+ *			- receive count
+ *			- receive datatype
+ *	      	        - tag
+ *			- communicator
+ *	Returns:	- MPI_SUCCESS or error code
+ */
+int 
+lam_bottom_dtsnd(void *sbuf, int scount, MPI_Datatype sdtype, void *rbuf,
+		 int rcount, MPI_Datatype rdtype, int tag, MPI_Comm comm)
+{
+  int		err;			/* error code */
+  int		size;			/* packed size */
+  int		rank;			/* caller's rank */
+  MPI_Status	stat;			/* status info */
+
+  err = lam_mkerr(MPI_ERR_TRUNCATE, EIO);
+
+  /*
+   * If same datatypes used, just copy.
+   */
+  if (sdtype == rdtype) {
+    if (scount <= rcount) {
+      if (sbuf == MPI_BOTTOM) {
+	lam_pack(sbuf, scount, sdtype, rbuf, 
+		 scount * sdtype->dt_size);
+      } else {
+	lam_dtcpy((char *) rbuf, (char *) sbuf, rcount,
+		  rdtype);
+      }
+      err = MPI_SUCCESS;
+    }
+  }
+
+  /*
+   * If receive packed.
+   */
+  else if (rdtype == MPI_PACKED) {
+    MPI_Pack_size(scount, sdtype, MPI_COMM_WORLD, &size);
+    if (size <= rcount) {
+      if (lam_pack(sbuf, scount, sdtype,
+		   rbuf, rcount) == size) {
+	err = MPI_SUCCESS;
+      }
+    }
+  }
+  /*
+   * If send packed.
+   */
+  else if (sdtype == MPI_PACKED) {
+    MPI_Pack_size(rcount, rdtype, MPI_COMM_WORLD, &size);
+    if (size >= scount) {
+      if (lam_unpack(sbuf, scount,
+		     rbuf, rcount, rdtype) == scount) {
+	err = MPI_SUCCESS;
+      }
+    }
+  }
+  /*
+   * Let send/recv handle it.
+   */
+  else {
+    MPI_Comm_rank(comm, &rank);
+    err = MPI_Sendrecv(sbuf, scount, sdtype, rank, tag,
+		       rbuf, rcount, rdtype, rank, tag, comm, &stat);
+  }
+  
+  return(err);
+}
+
+/*
+ *	lam_bottom_dtrcv
+ *
+ *	Function:	- copy MPI message from a LAM buffer into 
+ *                        process buffer
+ *			- send/recv done if cannot optimize
+ *	Accepts:	- send buffer
+ *			- send count
+ *			- send datatype
+ *			- receive buffer
+ *			- receive count
+ *			- receive datatype
+ *	      	        - tag
+ *			- communicator
+ *	Returns:	- MPI_SUCCESS or error code
+ */
+int 
+lam_bottom_dtrcv(void *sbuf, int scount, MPI_Datatype sdtype, void *rbuf,
+		 int rcount, MPI_Datatype rdtype, int tag, MPI_Comm comm)
+{
+  int		err;			/* error code */
+  int		size;			/* packed size */
+  int		rank;			/* caller's rank */
+  MPI_Status	stat;			/* status info */
+
+  err = lam_mkerr(MPI_ERR_TRUNCATE, EIO);
+
+  /*
+   * If same datatypes used, just copy.
+   */
+  if (sdtype == rdtype) {
+    if (scount <= rcount) {
+      if (rbuf == MPI_BOTTOM) {
+	lam_unpack(sbuf, rcount * rdtype->dt_size, rbuf,
+		 rcount, rdtype);
+      } else {
+	lam_dtcpy((char *) rbuf, (char *) sbuf, rcount,
+		  rdtype);
+      }
+      err = MPI_SUCCESS;
+    }
+  }
+
+  /*
+   * If receive packed.
+   */
+  else if (rdtype == MPI_PACKED) {
+    MPI_Pack_size(scount, sdtype, MPI_COMM_WORLD, &size);
+    if (size <= rcount) {
+      if (lam_pack(sbuf, scount, sdtype,
+		   rbuf, rcount) == size) {
+	err = MPI_SUCCESS;
+      }
+    }
+  }
+  /*
+   * If send packed.
+   */
+  else if (sdtype == MPI_PACKED) {
+    MPI_Pack_size(rcount, rdtype, MPI_COMM_WORLD, &size);
+    if (size >= scount) {
+      if (lam_unpack(sbuf, scount,
+		     rbuf, rcount, rdtype) == scount) {
+	err = MPI_SUCCESS;
+      }
+    }
+  }
+  /*
+   * Let send/recv handle it.
+   */
+  else {
+    MPI_Comm_rank(comm, &rank);
+    err = MPI_Sendrecv(sbuf, scount, sdtype, rank, tag,
+		       rbuf, rcount, rdtype, rank, tag, comm, &stat);
+  }
+  
+  return(err);
+}
 
 /*
  *	lam_dtsndrcv
@@ -253,9 +412,9 @@ lam_dtsndrcv(void *sbuf, int scount, MPI_Datatype sdtype, void *rbuf,
  */
 	if (sdtype == rdtype) {
 		if (scount <= rcount) {
-			lam_dtcpy((char *) rbuf, (char *) sbuf, rcount,
-					rdtype);
-			err = MPI_SUCCESS;
+		    lam_dtcpy((char *) rbuf, (char *) sbuf, rcount,
+			      rdtype);
+		  err = MPI_SUCCESS;
 		}
 	}
 /*
@@ -499,7 +658,7 @@ cpy_struct(char *dest, char *src, int num, MPI_Datatype dtype)
 
 		for (j = 0; j < dtype->dt_count; ++j, ++len, ++disp, ++type) {
 
-			lam_dtcpy(dest + *disp, src + *disp, *len, *type);
+		  lam_dtcpy(dest + *disp, src + *disp, *len, *type);
 		}
 	}
 }
@@ -534,7 +693,6 @@ lam_dtblock(MPI_Datatype newdtype, MPI_Datatype old, int count, int disp)
 		}
 
 		extent = (old->dt_upper - old->dt_lower) * (count - 1);
-
 		if (extent > 0) {
 			upper = old->dt_upper + extent + disp;
 			dataup = old->dt_dataup + extent + disp;
@@ -554,7 +712,6 @@ lam_dtblock(MPI_Datatype newdtype, MPI_Datatype old, int count, int disp)
  * First block in the new type.
  */
 	if (newdtype->dt_size < 0) {
-
 		newdtype->dt_upper = upper;
 		newdtype->dt_dataup = dataup;
 		newdtype->dt_lower = lower;
@@ -603,6 +760,7 @@ lam_dtblock(MPI_Datatype newdtype, MPI_Datatype old, int count, int disp)
 				newdtype->dt_flags &= ~LAM_DTNOPACK;
 			}
 		}
+
 /*
  * Update the upper bound.
  */
@@ -639,9 +797,7 @@ lam_dtblock(MPI_Datatype newdtype, MPI_Datatype old, int count, int disp)
 		} else {
 			if (!(newdtype->dt_flags & LAM_DTHASLB)
 					&& (old->dt_size > 0)) {
-			  if (newdtype->dt_datalow < newdtype->dt_lower) {
 				newdtype->dt_lower = newdtype->dt_datalow;
-			  }
 				newdtype->dt_flags |= LAM_DTLOWSET;
 			}
 		}
@@ -660,12 +816,6 @@ lam_dtblock(MPI_Datatype newdtype, MPI_Datatype old, int count, int disp)
 			newdtype->dt_lower = newdtype->dt_upper;
 			newdtype->dt_flags |= LAM_DTLOWSET;
 		}
-	} else {
-	  /* If this is the last block and it is empty then we have to mark the
-	     upper bound for this new datatype */
-	  upper = disp;
-	  if (upper > newdtype->dt_upper)
-	    newdtype->dt_upper = upper;
 	}
 }
 
