@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2004 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2006 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -242,7 +242,7 @@ lam_mpi_init(int *pargc, char ***pargv, int requested, int *pprovided,
 
   /* Initialize LAM. */
 
-  name = (pargc && pargv && (*pargc > 0)) ? **pargv : 0;
+  name = (pargc && pargv && (*pargc > 0)) ? **pargv : NULL;
   if (pargc == NULL || pargv == NULL) {
     argc = 0;
     argv = NULL;
@@ -304,12 +304,15 @@ lam_mpi_init(int *pargc, char ***pargv, int requested, int *pprovided,
   if (lam_ssi_coll_base_query() == LAMERROR)
     fail_stop("mpi-init", "ssi-coll-fail-query");
 
-  /* Find out which SSI crmpi modules are available */
+  /* Find out which SSI crmpi modules are available.  Due to bug 682,
+     only do this if we were not MPI_COMM_SPAWN*'ed. */
 
-  if (lam_ssi_crmpi_base_open(lam_mpi_ao) == LAMERROR)
-    fail_stop("mpi-init", "ssi-crmpi-fail-open");
-  if (lam_ssi_crmpi_base_query() == LAMERROR)
-    fail_stop("mpi-init", "ssi-crmpi-fail-query");
+  if (mpi_nparent == 0) {
+    if (lam_ssi_crmpi_base_open(lam_mpi_ao) == LAMERROR)
+      fail_stop("mpi-init", "ssi-crmpi-fail-open");
+    if (lam_ssi_crmpi_base_query() == LAMERROR)
+      fail_stop("mpi-init", "ssi-crmpi-fail-query");
+  }
 
   /* Now that all SSI modules have been opened and we have lists of
      available modules, we can decide on which modules will be
@@ -566,16 +569,19 @@ lam_send_selected_ssi_modules(void)
   /*
    * Also copy the selected CRMPI module's name to send to mpirun.
    *
-   * It is possible that no CR modules were selected. So handle that case. 
+   * It is possible that no CR modules were selected. So handle that
+   * case.
+   *
+   * Ensure to only allow checkpointing of non-MPI_COMM_SPAWN*'ed
+   * processes.
    */
-#if 0
-  if (lam_ssi_crmpi_base_available != NULL)
-    module = (lam_ssi_module_t *) al_top(lam_ssi_crmpi_base_available);
-#else
-  /* JMS, for the moment, due to bug 682, we're just going to skip
-     checking cr modules. */
-  module = NULL;
-#endif
+  if (mpi_nparent == 0) {
+    if (lam_ssi_crmpi_base_available != NULL) {
+      module = (lam_ssi_module_t *) al_top(lam_ssi_crmpi_base_available);
+    }
+  } else {
+    module = NULL;
+  }
 
   if ((NULL == lam_ssi_crmpi_base_available) || 
       (NULL == module)) {
