@@ -1,44 +1,25 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
- * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN
+ * $HEADER$
  *
- *	$Id: lampack.c,v 6.6 1999/09/27 12:13:35 lamteam Exp $
+ * $Id: lampack.c,v 6.11 2003/04/08 01:33:05 jsquyres Exp $
  *
  *	Function:	- MPI data packing functions
  *			- handles recursive data types
  */
 
 #include <lam_config.h>
+
 #include <string.h>
 
 #include <mpi.h>
@@ -47,17 +28,24 @@
 #include <portable.h>
 #include <typical.h>
 
+
 /*
  * local functions
  */
-static void		pack();
-static void		pack_rev();
-static void		pack_hvector();
-static void		pack_rev_hvector();
-static void		pack_hindexed();
-static void		pack_rev_hindexed();
-static void		pack_struct();
-static void		pack_rev_struct();
+static void pack(char *dest, char *src, int count, MPI_Datatype dtype);
+static void pack_rev(char *dest, char *src, int count, MPI_Datatype dtype);
+static void pack_hvector(char *dest, char *src, int num, MPI_Datatype dtype, 
+                         int fl_vec);
+static void pack_rev_hvector(char *dest, char *src, int num, 
+                             MPI_Datatype dtype, int fl_vec);
+static void pack_hindexed(char *dest, char *src, int num, MPI_Datatype dtype,
+                          int fl_idx);
+static void pack_rev_hindexed(char *dest, char *src, int num, 
+                              MPI_Datatype dtype, int fl_idx);
+static void pack_struct(char *dest, char *src, int num, MPI_Datatype dtype);
+static void pack_rev_struct(char *dest, char *src, int num, 
+                            MPI_Datatype dtype);
+
 
 /*
  *	lam_pack
@@ -73,14 +61,7 @@ static void		pack_rev_struct();
  *	Returns:	- # bytes packed or LAMERROR
  */
 int
-lam_pack(src, count, dtype, dest, destlen)
-
-char			*src;
-int			count;
-MPI_Datatype		dtype;
-char			*dest;
-int			destlen;
-
+lam_pack(char *src, int count, MPI_Datatype dtype, char *dest, int destlen)
 {
 	int		size;			/* # bytes required */
 /*
@@ -96,7 +77,7 @@ int			destlen;
  * heterogeneous and the local archirecture is little-endian.  
  */
 	if (size > 0) {
-#if WORDS_BIGENDIAN
+#if LAM_WORDS_BIGENDIAN
 		pack(dest, src, count, dtype);
 #else
 		if (lam_homog) {
@@ -110,6 +91,7 @@ int			destlen;
 	return(size);
 }
 
+
 /*
  *	pack
  *
@@ -121,13 +103,7 @@ int			destlen;
  *			- datatype
  */
 static void
-pack(dest, src, count, dtype)
-
-char			*dest;
-char			*src;
-int			count;
-MPI_Datatype		dtype;
-
+pack(char *dest, char *src, int count, MPI_Datatype dtype)
 {
 /*
  * If no packing or extent adjustment is required do a direct copy.
@@ -135,7 +111,7 @@ MPI_Datatype		dtype;
  */
 	if ((dtype->dt_flags & LAM_DTNOPACK)
 	    	&& ((count == 1) || (dtype->dt_flags & LAM_DTNOXADJ))) {
-	    memcpy(dest, src, count * dtype->dt_size);
+	  lam_memcpy(dest, src, count * dtype->dt_size);
 	}
 	else {
 	    switch (dtype->dt_format) {
@@ -172,6 +148,7 @@ MPI_Datatype		dtype;
 	}
 }
 
+
 /*
  *	pack_rev
  *
@@ -183,13 +160,7 @@ MPI_Datatype		dtype;
  *			- datatype
  */
 static void
-pack_rev(dest, src, count, dtype)
-
-char			*dest;
-char			*src;
-int			count;
-MPI_Datatype		dtype;
-
+pack_rev(char *dest, char *src, int count, MPI_Datatype dtype)
 {
 	switch (dtype->dt_format) {
 /*
@@ -199,7 +170,7 @@ MPI_Datatype		dtype;
 	    switch (dtype->dt_size) {
 
 	    case 1:
-		memcpy(dest, src, count);
+	        lam_memcpy(dest, src, count);
 		break;
 		
 	    case 2:
@@ -251,20 +222,14 @@ MPI_Datatype		dtype;
 	}
 }		
 
+
 /*
  *	pack_hvector
  *
  *	Function:	- pack vector or hvector
  */
 static void
-pack_hvector(dest, src, num, dtype, fl_vec)
-
-char			*dest;
-char			*src;
-int			num;
-MPI_Datatype		dtype;
-int			fl_vec;
-
+pack_hvector(char *dest, char *src, int num, MPI_Datatype dtype, int fl_vec)
 {
 	MPI_Datatype	subtype;		/* type of vector elements */
 	char		*s;			/* ptr into source buffer */
@@ -329,7 +294,7 @@ int			fl_vec;
 		for (i = 0; i < num; ++i, src += extent) {
 		    s = src;
 		    for (j = 0; j < count; ++j) {
-			memcpy(dest, s, blksize);
+			lam_memcpy(dest, s, blksize);
 			dest += blksize;
 			s += stride;
 		    }
@@ -351,20 +316,15 @@ int			fl_vec;
 	}
 }
 
+
 /*
  *	pack_rev_hvector
  *
  *	Function:	- pack and reverse vector or hvector
  */
 static void
-pack_rev_hvector(dest, src, num, dtype, fl_vec)
-
-char			*dest;
-char			*src;
-int			num;
-MPI_Datatype		dtype;
-int			fl_vec;
-
+pack_rev_hvector(char *dest, char *src, int num, MPI_Datatype dtype, 
+		 int fl_vec)
 {
 	MPI_Datatype	subtype;		/* type of vector elements */
 	char		*s;			/* ptr into source buffer */
@@ -395,7 +355,7 @@ int			fl_vec;
 		for (i = 0; i < num; ++i, src += extent) {
 		    s = src;
 		    for (j = 0; j < dtype->dt_count; ++j) {
-			memcpy(dest, s, dtype->dt_length);
+			lam_memcpy(dest, s, dtype->dt_length);
 			dest += blksize;
 			s += stride;
 		    }
@@ -459,20 +419,15 @@ int			fl_vec;
 	}
 }
 
+
 /*
  *	pack_hindexed
  *
  *	Function:	- pack indexed or hindexed
  */
 static void
-pack_hindexed(dest, src, num, dtype, fl_idx)
-
-char			*dest;
-char			*src;
-int			num;
-MPI_Datatype		dtype;
-int			fl_idx;
-
+pack_hindexed(char *dest, char *src, int num, MPI_Datatype dtype,
+	      int fl_idx)
 {
 	int		i, j;
 	int		blksize;		/* size of block */
@@ -504,20 +459,15 @@ int			fl_idx;
 	}
 }
 
+
 /*
  *	pack_rev_hindexed
  *
  *	Function:	- pack and reverse indexed or hindexed
  */
 static void
-pack_rev_hindexed(dest, src, num, dtype, fl_idx)
-
-char			*dest;
-char			*src;
-int			num;
-MPI_Datatype		dtype;
-int			fl_idx;
-
+pack_rev_hindexed(char *dest, char *src, int num, MPI_Datatype dtype,
+		  int fl_idx)
 {
 	int		i, j;
 	int		blksize;		/* size of block */
@@ -551,19 +501,14 @@ int			fl_idx;
 	}
 }
 
+
 /*
  *	pack_struct
  *
  *	Function:	- pack struct
  */
 static void
-pack_struct(dest, src, num, dtype)
-
-char			*dest;
-char			*src;
-int			num;
-MPI_Datatype		dtype;
-
+pack_struct(char *dest, char *src, int num, MPI_Datatype dtype)
 {
 	int		i, j;
 	int		blksize;		/* size of block */
@@ -594,19 +539,14 @@ MPI_Datatype		dtype;
 	}
 }
 
+
 /*
  *	pack_rev_struct
  *
  *	Function:	- pack and reverse struct
  */
 static void
-pack_rev_struct(dest, src, num, dtype)
-
-char			*src;
-int			num;
-MPI_Datatype		dtype;
-char			*dest;
-
+pack_rev_struct(char *dest, char *src, int num, MPI_Datatype dtype)
 {
 	int		i, j;
 	int		blksize;		/* size of block */
