@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: lamports.c,v 6.5 2002/12/11 19:15:12 jsquyres Exp $
+ * $Id: lamports.c,v 6.6 2003/11/02 21:13:10 brbarret Exp $
  *
  *	Function:	- port management functions
  */
@@ -32,7 +32,7 @@
 /*
  * private functions
  */
-static int		port_cmp();
+static int		port_cmp(struct _port *p1, struct _port *p2);
 
 /*
  * private variables
@@ -47,7 +47,6 @@ static int		ports[LAM_PORTMAX];	/* port table */
  */
 int
 lam_ports_init()
-
 {
 	lam_ports = al_init(sizeof(struct _port), port_cmp);
 	return((lam_ports == 0) ? LAMERROR : 0);
@@ -60,7 +59,6 @@ lam_ports_init()
  */
 void
 lam_ports_free()
-
 {
 	al_free(lam_ports);
 }
@@ -73,7 +71,6 @@ lam_ports_free()
  */
 int
 lam_port_open()
-
 {
 	int		i;
 /*
@@ -96,10 +93,7 @@ lam_port_open()
  *	Returns:	- 1 if open, 0 if not open, or LAMERROR if illegal port
  */
 int
-lam_port_is_open(port)
-
-int			port;
-
+lam_port_is_open(int port)
 {
 	port -= LAM_PORTLOW;
 	if (!((0 <= port) && (port < LAM_PORTMAX))) {
@@ -117,10 +111,7 @@ int			port;
  *	Returns:	- 0 else LAMERROR
  */
 int
-lam_port_close(port)
-
-int			port;
-
+lam_port_close(int port)
 {
 	port -= LAM_PORTLOW;
 	if (!((0 <= port) && (port < LAM_PORTMAX))) {
@@ -140,10 +131,7 @@ int			port;
  *	Returns:	- string comparison of the port names
  */
 static int
-port_cmp(p1, p2)
-
-struct _port		*p1, *p2;
-
+port_cmp(struct _port *p1, struct _port *p2)
 {
 	return(strcmp(p1->prt_name, p2->prt_name));
 }
