@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2006 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -200,7 +200,7 @@ lam_procrm(struct _proc *proc)
 struct _proc *
 lam_topproc(void)
 {
-	curproc = (plist) ? al_top(plist) : 0;
+	curproc = (plist) ? al_top(plist) : NULL;
 	return(curproc);
 }
 
