@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN
+ * $HEADER$
  *
- *	$Id: lamreceive.c,v 1.2.2.1 2002/10/09 19:49:10 brbarret Exp $
+ * $Id: lamreceive.c,v 1.5 2002/12/11 19:15:12 jsquyres Exp $
  *
  *	Function:	- internal version of receives
  */
@@ -23,6 +21,7 @@
 #include <mpisys.h>
 #include <rpisys.h>
 
+
 /*
  *	lam_recv
  *
@@ -37,16 +36,8 @@
  *	Returns: 	- MPI_SUCCESS or error code
  */
 int
-lam_recv(buf, count, dtype, src, tag, comm, stat)
-
-void			*buf;
-int			count;
-MPI_Datatype		dtype;
-int			src;
-int			tag;
-MPI_Comm		comm;
-MPI_Status		*stat;
-
+lam_recv(void *buf, int count, MPI_Datatype dtype, int src, int tag,
+	 MPI_Comm comm, MPI_Status *stat)
 {
 	int		err;
 	struct _req	req_storage;
@@ -55,7 +46,7 @@ MPI_Status		*stat;
 	LAM_ZERO_ME(req_storage);
 	req = &req_storage;
 	err = _mpi_req_build(buf, count, dtype, 
-				src, tag, comm, LAM_RQIRECV, &req);
+			     src, tag, comm, LAM_RQIRECV, &req);
 	if (err != MPI_SUCCESS) return(err);
 
 	req->rq_marks |= (LAM_RQFBLKTYPE | LAM_RQFMAND);
@@ -87,6 +78,7 @@ MPI_Status		*stat;
 	return(MPI_SUCCESS);
 }
 
+
 /*
  *	lam_irecv
  *
@@ -101,18 +93,10 @@ MPI_Status		*stat;
  *	Returns: 	- MPI_SUCCESS or error code
  */
 int
-lam_irecv(buf, count, dtype, src, tag, comm, req)
-
-void			*buf;
-int			count;
-MPI_Datatype		dtype;
-int			src;
-int			tag;
-MPI_Comm		comm;
-MPI_Request		*req;
-
+lam_irecv(void *buf, int count, MPI_Datatype dtype, int src, int tag,
+	  MPI_Comm comm, MPI_Request *req)
 {
-	int		err;			/* error code */
+        int err;
 
 	*req = MPI_REQUEST_NULL;
 	err = _mpi_req_build(buf, count, dtype, src, tag, comm,
