@@ -86,7 +86,16 @@ lam_max(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
 #if LAM_SIZEOF_FORTRAN_INTEGER8
         LAM_FORTRAN_C_TYPE_INTEGER8 *pfint8in, *pfint8out;
 #endif
-	
+#if LAM_SIZEOF_FORTRAN_REAL4 
+        LAM_FORTRAN_C_TYPE_REAL4 *pfr4in, *pfr4out;
+#endif
+#if LAM_SIZEOF_FORTRAN_REAL8 
+        LAM_FORTRAN_C_TYPE_REAL8 *pfr8in, *pfr8out;
+#endif
+#if LAM_SIZEOF_FORTRAN_REAL16 
+        LAM_FORTRAN_C_TYPE_REAL16 *pfr16in, *pfr16out;
+#endif
+
 	if (*datatype == MPI_INT || *datatype == MPI_F_INTEGER) {
 		piin = (int *) invec;
 		piout = (int *) inoutvec;
@@ -275,6 +284,45 @@ lam_max(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
         }
 #endif
 
+#if LAM_SIZEOF_FORTRAN_REAL4
+	if (*datatype == MPI_F_REAL4) {
+		pfr4in = (LAM_FORTRAN_C_TYPE_REAL4 *) invec;
+		pfr4out = (LAM_FORTRAN_C_TYPE_REAL4 *) inoutvec;
+		for (i = 0; i < *len; ++i, ++pfr4in, ++pfr4out) {
+			if (*pfr4in > *pfr4out) {
+				*pfr4out = *pfr4in;
+			}
+		}
+		return;
+	}
+#endif
+
+#if LAM_SIZEOF_FORTRAN_REAL8
+	if (*datatype == MPI_F_REAL8) {
+		pfr8in = (LAM_FORTRAN_C_TYPE_REAL8 *) invec;
+		pfr8out = (LAM_FORTRAN_C_TYPE_REAL8 *) inoutvec;
+		for (i = 0; i < *len; ++i, ++pfr8in, ++pfr8out) {
+			if (*pfr8in > *pfr8out) {
+				*pfr8out = *pfr8in;
+			}
+		}
+		return;
+	}
+#endif
+
+#if LAM_SIZEOF_FORTRAN_REAL16
+	if (*datatype == MPI_F_REAL16) {
+		pfr16in = (LAM_FORTRAN_C_TYPE_REAL16 *) invec;
+		pfr16out = (LAM_FORTRAN_C_TYPE_REAL16 *) inoutvec;
+		for (i = 0; i < *len; ++i, ++pfr16in, ++pfr16out) {
+			if (*pfr16in > *pfr16out) {
+				*pfr16out = *pfr16in;
+			}
+		}
+		return;
+	}
+#endif
+
 	(void) lam_errfunc(MPI_COMM_WORLD,
 			   lam_getfunc(), lam_mkerr(MPI_ERR_OP, EINVAL));
 }
@@ -315,6 +363,15 @@ lam_min(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
 #if LAM_SIZEOF_FORTRAN_INTEGER8
         LAM_FORTRAN_C_TYPE_INTEGER8 *pfint8in, *pfint8out;
 #endif
+#if LAM_SIZEOF_FORTRAN_REAL4 
+        LAM_FORTRAN_C_TYPE_REAL4 *pfr4in, *pfr4out;
+#endif
+#if LAM_SIZEOF_FORTRAN_REAL8 
+        LAM_FORTRAN_C_TYPE_REAL8 *pfr8in, *pfr8out;
+#endif
+#if LAM_SIZEOF_FORTRAN_REAL16 
+        LAM_FORTRAN_C_TYPE_REAL16 *pfr16in, *pfr16out;
+#endif
 	
 	if (*datatype == MPI_INT || *datatype == MPI_F_INTEGER) {
 		piin = (int *) invec;
@@ -504,6 +561,45 @@ lam_min(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
         }
 #endif
 
+#if LAM_SIZEOF_FORTRAN_REAL4
+	if (*datatype == MPI_F_REAL4) {
+		pfr4in = (LAM_FORTRAN_C_TYPE_REAL4 *) invec;
+		pfr4out = (LAM_FORTRAN_C_TYPE_REAL4 *) inoutvec;
+		for (i = 0; i < *len; ++i, ++pfr4in, ++pfr4out) {
+			if (*pfr4in < *pfr4out) {
+				*pfr4out = *pfr4in;
+			}
+		}
+		return;
+	}
+#endif
+
+#if LAM_SIZEOF_FORTRAN_REAL8
+	if (*datatype == MPI_F_REAL8) {
+		pfr8in = (LAM_FORTRAN_C_TYPE_REAL8 *) invec;
+		pfr8out = (LAM_FORTRAN_C_TYPE_REAL8 *) inoutvec;
+		for (i = 0; i < *len; ++i, ++pfr8in, ++pfr8out) {
+			if (*pfr8in < *pfr8out) {
+				*pfr8out = *pfr8in;
+			}
+		}
+		return;
+	}
+#endif
+
+#if LAM_SIZEOF_FORTRAN_REAL16
+	if (*datatype == MPI_F_REAL16) {
+		pfr16in = (LAM_FORTRAN_C_TYPE_REAL16 *) invec;
+		pfr16out = (LAM_FORTRAN_C_TYPE_REAL16 *) inoutvec;
+		for (i = 0; i < *len; ++i, ++pfr16in, ++pfr16out) {
+			if (*pfr16in < *pfr16out) {
+				*pfr16out = *pfr16in;
+			}
+		}
+		return;
+	}
+#endif
+
 	(void) lam_errfunc(MPI_COMM_WORLD,
 			   lam_getfunc(), lam_mkerr(MPI_ERR_OP, EINVAL));
 }
@@ -547,6 +643,15 @@ lam_sum(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
 #if LAM_SIZEOF_FORTRAN_INTEGER8
         LAM_FORTRAN_C_TYPE_INTEGER8 *pfint8in, *pfint8out;
 #endif
+#if LAM_SIZEOF_FORTRAN_REAL4 
+        LAM_FORTRAN_C_TYPE_REAL4 *pfr4in, *pfr4out;
+#endif
+#if LAM_SIZEOF_FORTRAN_REAL8 
+        LAM_FORTRAN_C_TYPE_REAL8 *pfr8in, *pfr8out;
+#endif
+#if LAM_SIZEOF_FORTRAN_REAL16 
+        LAM_FORTRAN_C_TYPE_REAL16 *pfr16in, *pfr16out;
+#endif
 
 	if (*datatype == MPI_INT || *datatype == MPI_F_INTEGER) {
 		piin = (int *) invec;
@@ -737,6 +842,39 @@ lam_sum(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
         }
 #endif
 
+#if LAM_SIZEOF_FORTRAN_REAL4
+	if (*datatype == MPI_F_REAL4) {
+		pfr4in = (LAM_FORTRAN_C_TYPE_REAL4 *) invec;
+		pfr4out = (LAM_FORTRAN_C_TYPE_REAL4 *) inoutvec;
+		for (i = 0; i < *len; ++i, ++pfr4in, ++pfr4out) {
+			*pfr4out += *pfr4in;
+		}
+		return;
+	}
+#endif
+
+#if LAM_SIZEOF_FORTRAN_REAL8
+	if (*datatype == MPI_F_REAL8) {
+		pfr8in = (LAM_FORTRAN_C_TYPE_REAL8 *) invec;
+		pfr8out = (LAM_FORTRAN_C_TYPE_REAL8 *) inoutvec;
+		for (i = 0; i < *len; ++i, ++pfr8in, ++pfr8out) {
+			*pfr8out += *pfr8in;
+		}
+		return;
+	}
+#endif
+
+#if LAM_SIZEOF_FORTRAN_REAL16
+	if (*datatype == MPI_F_REAL16) {
+		pfr16in = (LAM_FORTRAN_C_TYPE_REAL16 *) invec;
+		pfr16out = (LAM_FORTRAN_C_TYPE_REAL16 *) inoutvec;
+		for (i = 0; i < *len; ++i, ++pfr16in, ++pfr16out) {
+			*pfr16out += *pfr16in;
+		}
+		return;
+	}
+#endif
+
 	(void) lam_errfunc(MPI_COMM_WORLD,
 			   lam_getfunc(), lam_mkerr(MPI_ERR_OP, EINVAL));
 }
@@ -784,6 +922,15 @@ lam_prod(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
 #if LAM_SIZEOF_FORTRAN_INTEGER8
         LAM_FORTRAN_C_TYPE_INTEGER8 *pfint8in, *pfint8out;
 #endif
+#if LAM_SIZEOF_FORTRAN_REAL4 
+        LAM_FORTRAN_C_TYPE_REAL4 *pfr4in, *pfr4out;
+#endif
+#if LAM_SIZEOF_FORTRAN_REAL8 
+        LAM_FORTRAN_C_TYPE_REAL8 *pfr8in, *pfr8out;
+#endif
+#if LAM_SIZEOF_FORTRAN_REAL16 
+        LAM_FORTRAN_C_TYPE_REAL16 *pfr16in, *pfr16out;
+#endif
 
 	if (*datatype == MPI_INT || *datatype == MPI_F_INTEGER) {
 		piin = (int *) invec;
@@ -981,6 +1128,39 @@ lam_prod(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
         }
 #endif
 
+#if LAM_SIZEOF_FORTRAN_REAL4
+	if (*datatype == MPI_F_REAL4) {
+		pfr4in = (LAM_FORTRAN_C_TYPE_REAL4 *) invec;
+		pfr4out = (LAM_FORTRAN_C_TYPE_REAL4 *) inoutvec;
+		for (i = 0; i < *len; ++i, ++pfr4in, ++pfr4out) {
+			*pfr4out *= *pfr4in;
+		}
+		return;
+	}
+#endif
+
+#if LAM_SIZEOF_FORTRAN_REAL8
+	if (*datatype == MPI_F_REAL8) {
+		pfr8in = (LAM_FORTRAN_C_TYPE_REAL8 *) invec;
+		pfr8out = (LAM_FORTRAN_C_TYPE_REAL8 *) inoutvec;
+		for (i = 0; i < *len; ++i, ++pfr8in, ++pfr8out) {
+			*pfr8out *= *pfr8in;
+		}
+		return;
+	}
+#endif
+
+#if LAM_SIZEOF_FORTRAN_REAL16
+	if (*datatype == MPI_F_REAL16) {
+		pfr16in = (LAM_FORTRAN_C_TYPE_REAL16 *) invec;
+		pfr16out = (LAM_FORTRAN_C_TYPE_REAL16 *) inoutvec;
+		for (i = 0; i < *len; ++i, ++pfr16in, ++pfr16out) {
+			*pfr16out *= *pfr16in;
+		}
+		return;
+	}
+#endif
+
 	(void) lam_errfunc(MPI_COMM_WORLD,
 			   lam_getfunc(), lam_mkerr(MPI_ERR_OP, EINVAL));
 }
@@ -2171,6 +2351,9 @@ lam_replace(void *invec, void *inoutvec, int *len, MPI_Datatype *datatype)
 		|| *datatype == MPI_UNSIGNED_LONG
 		|| *datatype == MPI_FLOAT
 		|| *datatype == MPI_F_REAL
+		|| *datatype == MPI_F_REAL4
+		|| *datatype == MPI_F_REAL8
+		|| *datatype == MPI_F_REAL16
 		|| *datatype == MPI_DOUBLE
 		|| *datatype == MPI_F_DOUBLE_PRECISION
 		|| *datatype == MPI_LONG_DOUBLE
