@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: lamreqs.c,v 6.25 2003/04/16 13:31:17 jsquyres Exp $
+ * $Id: lamreqs.c,v 6.28 2004/03/02 03:43:29 jsquyres Exp $
  *
  *	Function:	- requests management functions
  */
@@ -48,8 +48,8 @@ int			lam_rq_flblock = 0;	/* some block reqs? */
 int			lam_rq_nreqs = 0;	/* # requests in list */
 int			lam_rq_nactv = 0;	/* # active requests in list */
 int			lam_seqnum = 0;		/* message sequence number */
-MPI_Request		lam_rq_top = 0;		/* top list of requests */
-MPI_Request		lam_rq_bottom = 0;	/* bottom list of requests */
+MPI_Request lam_rq_top = MPI_REQUEST_NULL;	/* top list of requests */
+MPI_Request lam_rq_bottom = MPI_REQUEST_NULL;	/* bottom list of requests */
 
 
 /*
@@ -106,9 +106,9 @@ _mpi_req_build(void *buf, int count, MPI_Datatype dtype, int rank,
           if (req_mpid == -1)
             req_mpid = lam_mp_init(sizeof(struct _req), NULL, NULL,
                                    LAM_DEFAULT_MP_POOL_SIZE,
-                                   LAM_DEFAULT_MP_INCR_SIZE);
+                                   LAM_DEFAULT_MP_INCR_SIZE, 1);
           *preq = (MPI_Request) lam_mp_malloc(req_mpid);
-          if (*preq == 0) 
+          if (*preq == NULL) 
             return(lam_mkerr(MPI_ERR_OTHER, errno));
           (*preq)->rq_marks = LAM_RQFDYNREQ;
 	} else {
@@ -123,9 +123,9 @@ _mpi_req_build(void *buf, int count, MPI_Datatype dtype, int rank,
 	if (rank == MPI_PROC_NULL) {
 		req->rq_state = LAM_RQSINIT;
 		req->rq_rank = MPI_PROC_NULL;
-		req->rq_hdlr = 0;
+		req->rq_hdlr = NULL;
 		req->rq_flags = 0;
-		req->rq_comm = 0;
+		req->rq_comm = MPI_COMM_NULL;
 		req->rq_shadow = MPI_REQUEST_NULL;
 		return(MPI_SUCCESS);
 	}
@@ -135,10 +135,10 @@ _mpi_req_build(void *buf, int count, MPI_Datatype dtype, int rank,
 	req->rq_type = reqtype;
 	req->rq_state = LAM_RQSINIT;
 	req->rq_flags = 0;
-	req->rq_next = 0;
-	req->rq_hdlr = 0;
+	req->rq_next = MPI_REQUEST_NULL;
+	req->rq_hdlr = NULL;
 	req->rq_shadow = MPI_REQUEST_NULL;
-	req->rq_extra = 0;
+	req->rq_extra = NULL;
 	req->rq_f77handle = -1;
 /*
  * Save the original communication parameters.
@@ -159,7 +159,7 @@ _mpi_req_build(void *buf, int count, MPI_Datatype dtype, int rank,
  * Set peer process.
  */
 	if (rank == MPI_ANY_SOURCE) {
-		req->rq_proc = 0;
+		req->rq_proc = NULL;
 	} else {
 		req->rq_proc = ((LAM_IS_INTER(comm)) ?
 				comm->c_rgroup->g_procs[rank] :
@@ -171,7 +171,7 @@ _mpi_req_build(void *buf, int count, MPI_Datatype dtype, int rank,
  * if this is a proxy send to the impid, reset the proc to point to
  * the one, true proc to the impid (not the proxy).
  */
-		if (lam_impid_proc != 0) {
+		if (lam_impid_proc != NULL) {
 		  if (LAM_GPSCMP(&req->rq_proc->p_gps, 
 				 &lam_impid_proc->p_gps) == 0) {
 		    req->rq_proc = lam_impid_proc;
@@ -189,7 +189,7 @@ _mpi_req_build(void *buf, int count, MPI_Datatype dtype, int rank,
 		req->rq_packbuf = (char *) req->rq_buf;
 		req->rq_packsize = 0;
 	} else if (reqtype == LAM_RQIPROBE) {
-		req->rq_buf = 0;
+		req->rq_buf = NULL;
 		req->rq_packbuf = (char *) req->rq_buf;
 		req->rq_packsize = 0;
 	} else if ((reqtype != LAM_RQIBSEND)) {
@@ -211,7 +211,7 @@ _mpi_req_build(void *buf, int count, MPI_Datatype dtype, int rank,
 		req->rq_marks |= LAM_RQFSOURCE;
 	}
 
-	req->rq_rpi = 0;
+	req->rq_rpi = NULL;
 	if (RPI_BUILD(req)) {
 		err = lam_mkerr(MPI_ERR_INTERN, errno);
 		if (err != MPI_SUCCESS) 
@@ -295,7 +295,7 @@ _mpi_req_start(MPI_Request req)
  * last completed.
  */
 	  else if (cur->rq_rank == MPI_ANY_SOURCE) {
-		cur->rq_proc = 0;
+		cur->rq_proc = NULL;
 	  }
 
 	  if (RPI_START(lam_rq_top, cur)) {
@@ -343,7 +343,7 @@ _mpi_req_destroy(MPI_Request *preq)
 	  /* Tell the coll SSI module that this comm is now gone */
 
 	  if ((err = 
-	       req->rq_comm->c_ssi_coll.lsca_finalize(req->rq_comm)) != 0)
+	       lam_ssi_coll_base_finalize_comm(req->rq_comm)) != 0)
 	    ret = err;
 
 		err = lam_comm_free(req->rq_comm);
@@ -399,14 +399,14 @@ _mpi_req_add(MPI_Request req)
  */
 	if (req->rq_shadow != MPI_REQUEST_NULL)
 	  _mpi_req_add(req->rq_shadow);
-	if (lam_rq_top == 0) {
+	if (lam_rq_top == MPI_REQUEST_NULL) {
 		lam_rq_top = req;
 	} else {
 		lam_rq_bottom->rq_next = req;
 	}
 
 	lam_rq_bottom = req;
-	req->rq_next = 0;
+	req->rq_next = MPI_REQUEST_NULL;
 
 	++lam_rq_nreqs;
 }
@@ -425,8 +425,9 @@ _mpi_req_rem(MPI_Request req)
 /*
  * Locate the request in the list.
  */
-	for (p = lam_rq_top, p2 = 0; p && (p != req); p2 = p, p = p->rq_next);
-	if (p == 0) 
+	for (p = lam_rq_top, p2 = MPI_REQUEST_NULL; 
+             p != MPI_REQUEST_NULL && (p != req); p2 = p, p = p->rq_next);
+	if (p == MPI_REQUEST_NULL) 
 	  return;
 /*
  * Unlink the request from the list.
@@ -575,7 +576,7 @@ _mpi_req_advance(void)
  * many requests _rpi_advance() completed.  This keeps RPI implementations
  * simpler and we bear the pain here - a command decision.
  */
-	for (p = lam_rq_top, prev = 0; p; 
+	for (p = lam_rq_top, prev = MPI_REQUEST_NULL; p; 
 		p = (prev) ? prev->rq_next : lam_rq_top) {
 
 	    if (p->rq_state == LAM_RQSDONE) {
