@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,11 +12,13 @@
  * 
  * $HEADER$
  *
- * $Id: lamsend.c,v 6.27 2002/12/19 18:43:01 jsquyres Exp $
+ * $Id: lamsend.c,v 6.28 2003/10/28 12:39:44 jsquyres Exp $
  *
  *	Function:	- shared code for send functions
  */
 
+#include <errno.h>
+
 #include <mpi.h>
 #include <mpisys.h>
 #include <mpitrace.h>
@@ -94,20 +96,33 @@ lam_send(void *buf, int count, MPI_Datatype dtype, int dest, int tag,
 		return(lam_mkerr(MPI_ERR_COMM, EINVAL));
 
 	    if (LAM_IS_INTER(comm) || dest != comm->c_group->g_myrank) {
+                errno = 0;
 		err = RPI_FASTSEND(buf, count, dtype, dest, tag, comm);
-/*
- * Generate a trace.
- */
-		if (fl_trace) {
-		    finisht = MPI_Wtime();
 
-		    lam_tr_msg(TRTOUTPUT, startt,
-			LAM_S2US(finisht - startt - _kio.ki_blktime),
-			LAM_S2US(_kio.ki_blktime), dest, tag,
-			comm, dtype, count, 0, 0, lam_seqnum-1, reqtype);
-		}
+                /* The RPI's "fast" methods may be temporarily
+                   unavailable.  If the "fast" method returns
+                   something other than MPI_SUCCESS, and errno ==
+                   EBUSY, then just fail gracefully over to the normal
+                   send.  In all other cases, handle the
+                   success/failure here. */
 
-		return(err);
+                if (err == MPI_SUCCESS ||
+                    (err != MPI_SUCCESS && errno != EBUSY)) {
+
+                  /* Generate a trace */
+
+                  if (fl_trace) {
+                    finisht = MPI_Wtime();
+
+                    lam_tr_msg(TRTOUTPUT, startt,
+                               LAM_S2US(finisht - startt - _kio.ki_blktime),
+                               LAM_S2US(_kio.ki_blktime), dest, tag,
+                               comm, dtype, count, 0, 0, lam_seqnum-1, 
+                               reqtype);
+                  }
+
+                  return(err);
+                }
 	    }
 	}
 
