@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN
+ * $HEADER$
  *
- *	$Id: lamsig.c,v 1.7.2.1 2002/10/09 19:49:11 brbarret Exp $
+ * $Id: lamsig.c,v 1.15 2003/05/21 19:17:03 jsquyres Exp $
  *
  *	Function:	- exception signal catching
  */
@@ -33,6 +31,7 @@
 #include <portable.h>
 #include <preq.h>
 #include <priority.h>
+#include <etc_misc.h>
 #if LAM_WANT_IMPI
 #include <impi.h>
 #endif
@@ -49,7 +48,7 @@ void                    lam_printfunc(void);
 /*
  * private functions
  */
-static void		lam_mpi_sig_handler();
+static void		lam_mpi_sig_handler(int sig);
 
 /*
  * external functions
@@ -63,6 +62,7 @@ static sighandler_t	old_segv_handler;
 static sighandler_t	old_bus_handler;
 static sighandler_t	old_fpe_handler;
 static sighandler_t	old_ill_handler;
+static int              in_handler_already = 0;
 
 
 /*
@@ -73,8 +73,7 @@ static sighandler_t	old_ill_handler;
  *	Returns:	- 
  */
 int
-lam_mpi_set_sighandlers()
-
+lam_mpi_set_sighandlers(void)
 {
 	old_segv_handler = _lam_signal(SIGSEGV, lam_mpi_sig_handler);
 	if (old_segv_handler == SIG_ERR) return(LAMERROR);
@@ -100,8 +99,7 @@ lam_mpi_set_sighandlers()
  *	Returns:	- 
  */
 void
-lam_mpi_reset_sighandlers()
-
+lam_mpi_reset_sighandlers(void)
 {
 	_lam_signal(SIGSEGV, old_segv_handler);
 	_lam_signal(SIGBUS, old_bus_handler);
@@ -109,6 +107,7 @@ lam_mpi_reset_sighandlers()
 	_lam_signal(SIGILL, old_ill_handler);
 }
 
+
 /*
  *	lam_mpi_sig_handler
  *
@@ -116,10 +115,7 @@ lam_mpi_reset_sighandlers()
  *	Accepts:	- signal number
  */
 static void
-lam_mpi_sig_handler(sig)
-
-int 			sig;
-
+lam_mpi_sig_handler(int sig)
 {
 	struct _proc	**p;
 	sighandler_t	old_handler;
@@ -129,6 +125,8 @@ int 			sig;
 	char            prefix[512];
 	char            extra[512];
 
+	/* Now go handle this error */
+
 	switch (sig) {
 
 	case SIGSEGV:
@@ -154,7 +152,39 @@ int 			sig;
 		break;
 	}
 
-	if (old_handler == SIG_IGN) return;
+	/* Make sure we don't get caught it a loop.  An alternative
+	   way to handle this would be to reset the default signal
+	   handlers the first time this function is invoked and
+	   therefore let the default sighandler catch the signal next
+	   time through.  We decided to print out a friendly message
+	   and abort() instead.  It is quite possible that that could
+	   be configured via ./configure and/or an environment
+	   variable override.  
+
+	   For example, Dave T. at GE wants to get core dumps when
+	   things go wrong -- something that the default sig handler
+	   would provide This is actually a different issue (i.e.,
+	   we'd call the default signal handler at the end of this
+	   handler -- it's not a "second invocation of the handler"
+	   issue), but it's related so I mention it here. */
+
+	if (in_handler_already == 1) {
+	  fprintf(stderr, "\n\n\n------------------------------------------------------------------------\n"
+"LAM/MPI ERROR! A signal handler (%s / #%d) was invoked after we\n"
+"were already in a signal handler!  I'm aborting before trying to handle it\n"
+"to prevent thrashing...  You should check the exit behavior of your\n"
+"program, such as C++ destructors, functions registered with\n"
+"onexit()/atexit(), etc.\n"
+"------------------------------------------------------------------------\n\n\n", 
+		  err, sig);
+	  abort();
+	}
+	in_handler_already = 1;
+
+	/* Do something */
+
+	if (old_handler == SIG_IGN) 
+	  return;
 
 #if LAM_WANT_IMPI
 	if (LAM_GPSCMP(&lam_myproc->p_gps, &gimpid) == 0) {
@@ -188,7 +218,9 @@ int 			sig;
 #endif
 	    MPI_COMM_WORLD != 0 && MPI_COMM_WORLD->c_group) {
 
-		if (fork() == 0) {
+		if (lam_fork() == 0) {
+		  /* clear pid cache, since we want to have new pid */
+		  lam_reset_pid_cache();
 			if (kinit(PRCMD)) {
 				exit(errno);
 			}
