@@ -111,7 +111,10 @@ lam_match_ssi_modules(int4 world_n, struct _gps *world, char *prefix)
   struct nmsg msg;
   lam_ssi_module_t *module;
   lam_ssi_rpi_t rpi;
+#if 0
+  /* See comment below */
   lam_ssi_crmpi_t crmpi;
+#endif
   struct mpi_app_extra_info maei;
   char arg1[LAM_MPI_SSI_BASE_MAX_MODULE_NAME_LEN * 2],
        arg2[LAM_MPI_SSI_BASE_MAX_MODULE_NAME_LEN * 2],
@@ -171,7 +174,13 @@ lam_match_ssi_modules(int4 world_n, struct _gps *world, char *prefix)
                 prefix, arg1, arg2, arg3, NULL);
       return LAMERROR;
     }
-      
+
+#if 0
+    /* Due to bug 682, spawned processes cannot be checkpointable --
+       we can just ignore what they sent for crmpi modules, because
+       lam_mpi_init() is hard-wired to select no crmpi module when an
+       MPI process is MPI_COMM_SPAWN*'ed. */
+
     /* 
      * If we did not select any crmpi module to run, we must ensure that
      * the spawned processes send ("none", -1, -1, -1) for the selected
@@ -229,6 +238,7 @@ lam_match_ssi_modules(int4 world_n, struct _gps *world, char *prefix)
                 arg1, arg2, arg3, NULL);
       return LAMERROR;
     }
+#endif
   }
                
   return 0;
