@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: lamtest.c,v 6.15 2002/12/11 19:15:12 jsquyres Exp $
+ * $Id: lamtest.c,v 6.16 2003/11/02 21:13:10 brbarret Exp $
  *
  *	Function:	- test if request is done
  *			- destructive and non-destructive modes
@@ -63,6 +63,11 @@ The new plan (27 Sep 1999):
 */
 
 
+/*
+ * global functions
+ */
+int  lam_test_rqfmand(MPI_Request *preq);
+
 
 int
 lam_test(MPI_Request *preq, int destroy, int *flag, MPI_Status *stat)
