@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN
+ * $HEADER$
  *
- *	$Id: lamunpack.c,v 6.7.2.1 2002/10/09 19:49:11 brbarret Exp $
+ * $Id: lamunpack.c,v 6.12 2003/05/21 19:17:03 jsquyres Exp $
  *
  *	Function:	- MPI data unpacking functions
  *			- handles recursive data types
@@ -29,17 +27,27 @@
 #include <t_types.h>
 #include <typical.h>
 
+
 /*
  * local functions
  */
-static int		unpack();
-static int		unpack_rev();
-static int		unpack_hvector();
-static int		unpack_rev_hvector();
-static int		unpack_hindexed();
-static int		unpack_rev_hindexed();
-static int		unpack_struct();
-static int		unpack_rev_struct();
+static int unpack(char *dest, char *src, int srclen, int count, 
+                  MPI_Datatype dtype);
+static int unpack_rev(char *dest, char *src, int srclen, int count, 
+                      MPI_Datatype dtype);
+static int unpack_hvector(char *dest, char *src, int srclen, int num, 
+                          MPI_Datatype dtype, int fl_vec);
+static int unpack_rev_hvector(char *dest, char *src, int srclen, int num, 
+                              MPI_Datatype dtype, int fl_vec);
+static int unpack_hindexed(char *dest, char *src, int srclen, int num, 
+                           MPI_Datatype dtype, int fl_idx);
+static int unpack_rev_hindexed(char *dest, char *src, int srclen, int num, 
+                               MPI_Datatype dtype, int fl_idx);
+static int unpack_struct(char *dest, char *src, int srclen, int num, 
+                         MPI_Datatype dtype);
+static int unpack_rev_struct(char *dest, char *src, int srclen, int num, 
+                             MPI_Datatype dtype);
+
 
 /*
  *	lam_unpack
@@ -54,14 +62,7 @@ static int		unpack_rev_struct();
  *	Returns:	- # bytes unpacked or LAMERROR
  */
 int
-lam_unpack(src, srclen, dest, count, dtype)
-
-char			*src;
-int			srclen;
-char			*dest;
-int			count;
-MPI_Datatype		dtype;
-
+lam_unpack(char *src, int srclen, char *dest, int count, MPI_Datatype dtype)
 {
 	int		size;			/* # bytes unpacked */
 
@@ -81,7 +82,7 @@ MPI_Datatype		dtype;
  * Unpack the buffer.  Convert to little-endian format if the LAM is
  * heterogeneous and the local archirecture is little-endian.
  */
-#if WORDS_BIGENDIAN
+#if LAM_WORDS_BIGENDIAN
 	size = unpack(dest, src, srclen, count, dtype);
 #else
 	if (lam_homog) {
@@ -94,6 +95,7 @@ MPI_Datatype		dtype;
 	return(size);
 }
 
+
 /*
  *	unpack
  *
@@ -107,14 +109,7 @@ MPI_Datatype		dtype;
  *	Returns:	- # bytes unpacked
  */
 static int
-unpack(dest, src, srclen, count, dtype)
-
-char			*dest;
-char			*src;
-int			srclen;
-int			count;
-MPI_Datatype		dtype;
-
+unpack(char *dest, char *src, int srclen, int count, MPI_Datatype dtype)
 {
 	int		size;			/* number bytes unpacked */
 
@@ -131,7 +126,7 @@ MPI_Datatype		dtype;
 	    count = LAM_min(count, size);
 	    size = count * dtype->dt_size;
 
-	    memcpy(dest, src, size);
+	    lam_memcpy(dest, src, size);
 	    return(size);
 	}
 
@@ -144,7 +139,7 @@ MPI_Datatype		dtype;
  */
 	    size = count * dtype->dt_size;
 	    size = LAM_min(size, srclen);
-	    memcpy(dest, src, size);
+	    lam_memcpy(dest, src, size);
 	    return(size);
 	}
 	else {
@@ -182,6 +177,7 @@ MPI_Datatype		dtype;
 	}
 }
 
+
 /*
  *	unpack_rev
  *
@@ -194,14 +190,7 @@ MPI_Datatype		dtype;
  *			- datatype
  */
 static int
-unpack_rev(dest, src, srclen, count, dtype)
-
-char			*dest;
-char			*src;
-int			srclen;
-int			count;
-MPI_Datatype		dtype;
-
+unpack_rev(char *dest, char *src, int srclen, int count, MPI_Datatype dtype)
 {
 	if (dtype->dt_size == 0) {
 	    return(0);
@@ -219,7 +208,7 @@ MPI_Datatype		dtype;
 	    switch (dtype->dt_size) {
 
 	    case 1:
-		memcpy(dest, src, count);
+		lam_memcpy(dest, src, count);
 		break;
 
 	    case 2:
@@ -271,21 +260,15 @@ MPI_Datatype		dtype;
 	}
 }
 
+
 /*
  *	unpack_hvector
  *
  *	Function:	- unpack vector or hvector
  */
 static int
-unpack_hvector(dest, src, srclen, num, dtype, fl_vec)
-
-char			*dest;
-char			*src;
-int			srclen;
-int			num;
-MPI_Datatype		dtype;
-int			fl_vec;
-
+unpack_hvector(char *dest, char *src, int srclen, int num, MPI_Datatype dtype,
+	       int fl_vec)
 {
 	MPI_Datatype	subtype;		/* type of vector elements */
 	char		*d;			/* ptr into dest buffer */
@@ -378,7 +361,7 @@ int			fl_vec;
 		for (i = 0; i < num && left >= blksize; ++i, dest += extent) {
 		    d = dest;
 		    for (j = 0; j < count && left >= blksize; ++j) {
-			memcpy(d, src, blksize);
+			lam_memcpy(d, src, blksize);
 			src += blksize;
 			left -= blksize;
 			d += stride;
@@ -418,21 +401,15 @@ int			fl_vec;
 	}
 }
 
+
 /*
  *	unpack_rev_hvector
  *
  *	Function:	- unpack and reverse vector or hvector
  */
 static int
-unpack_rev_hvector(dest, src, srclen, num, dtype, fl_vec)
-
-char			*dest;
-char			*src;
-int			srclen;
-int			num;
-MPI_Datatype		dtype;
-int			fl_vec;
-
+unpack_rev_hvector(char *dest, char *src, int srclen, int num, 
+		   MPI_Datatype dtype, int fl_vec)
 {
 	MPI_Datatype	subtype;		/* type of vector elements */
 	char		*d;			/* ptr into dest buffer */
@@ -470,7 +447,7 @@ int			fl_vec;
 		for (i = 0; i < num && left >= blksize; ++i, dest += extent) {
 		    d = dest;
 		    for (j = 0; j < dtype->dt_count && left >= blksize; ++j) {
-			memcpy(d, src, blksize);
+			lam_memcpy(d, src, blksize);
 			src += blksize;
 			left -= blksize;
 			d += stride;
@@ -480,7 +457,7 @@ int			fl_vec;
  * Unpack last partial subtype block if any.
  */
 		if (left > 0) {
-		    memcpy(d, src, left);
+		    lam_memcpy(d, src, left);
 		    src += left;
 		}
 
@@ -581,21 +558,15 @@ int			fl_vec;
 	return(src - start);
 }
 
+
 /*
  *	unpack_hindexed
  *
  *	Function:	- unpack indexed or hindexed
  */
 static int
-unpack_hindexed(dest, src, srclen, num, dtype, fl_idx)
-
-char			*dest;
-char			*src;
-int			srclen;
-int			num;
-MPI_Datatype		dtype;
-int			fl_idx;
-
+unpack_hindexed(char *dest, char *src, int srclen, int num, MPI_Datatype dtype,
+		int fl_idx)
 {
 	int		i, j;
 	int		size;			/* size unpacked */
@@ -638,21 +609,15 @@ int			fl_idx;
 	return(src - start);
 }
 
+
 /*
  *	unpack_rev_hindexed
  *
  *	Function:	- unpack and reverse indexed or hindexed
  */
 static int
-unpack_rev_hindexed(dest, src, srclen, num, dtype, fl_idx)
-
-char			*dest;
-char			*src;
-int			srclen;
-int			num;
-MPI_Datatype		dtype;
-int			fl_idx;
-
+unpack_rev_hindexed(char *dest, char *src, int srclen, int num, 
+		    MPI_Datatype dtype, int fl_idx)
 {
 	int		i, j;
 	int		size;			/* size unpacked */
@@ -695,20 +660,14 @@ int			fl_idx;
 	return(src - start);
 }
 
+
 /*
  *	unpack_struct
  *
  *	Function:	- unpack struct
  */
 static int
-unpack_struct(dest, src, srclen, num, dtype)
-
-char			*dest;
-char			*src;
-int			srclen;
-int			num;
-MPI_Datatype		dtype;
-
+unpack_struct(char *dest, char *src, int srclen, int num, MPI_Datatype dtype)
 {
 	int		i, j;
 	int		size;			/* size unpacked */
@@ -751,20 +710,15 @@ MPI_Datatype		dtype;
 	return(src - start);
 }
 
+
 /*
  *	unpack_rev_struct
  *
  *	Function:	- unpack and reverse struct
  */
 static int
-unpack_rev_struct(dest, src, srclen, num, dtype)
-
-char			*dest;
-char			*src;
-int			srclen;
-int			num;
-MPI_Datatype		dtype;
-
+unpack_rev_struct(char *dest, char *src, int srclen, int num, 
+		  MPI_Datatype dtype)
 {
 	int		i, j;
 	int		size;			/* size unpacked */
