@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: lamupdown.c,v 6.24 2003/04/09 17:37:13 brbarret Exp $
+ * $Id: lamupdown.c,v 6.25 2003/11/02 21:13:10 brbarret Exp $
  *
  *	Function:	- take top level info down
  *			- take error info up
@@ -30,6 +30,11 @@
 #include <lammpithreads.h>
 #include <all_array.h>
 
+/*
+ * global functions
+ */
+void lam_printfunc(void);
+
 
 /*
  * global variables
