@@ -1,38 +1,18 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
- * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD/GDB
+ * $HEADER$
  *
- *	$Id: mpil_id.c,v 6.3 1999/12/31 21:27:33 jsquyres Exp $
+ * $Id: mpil_id.c,v 6.5 2002/12/11 19:15:12 jsquyres Exp $
  *
  *	Function:	- identifers for MPI opaque objects
  */
@@ -112,12 +92,12 @@ MPIL_Comm_id(MPI_Comm comm, int *pcid)
 
 	if (comm == MPI_COMM_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			lam_getfunc(), lam_mkerr(MPI_ERR_COMM, 0)));
+			lam_getfunc(), lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (pcid == 0) {
 		return(lam_errfunc(comm,
-			lam_getfunc(), lam_mkerr(MPI_ERR_ARG, 0)));
+			lam_getfunc(), lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	*pcid = comm->c_contextid;
@@ -205,12 +185,12 @@ int MPIL_Comm_gps(MPI_Comm comm, int rank, int *pnid,
 
 	if (comm == MPI_COMM_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			lam_getfunc(), lam_mkerr(MPI_ERR_COMM, 0)));
+			lam_getfunc(), lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if ((pnid == 0) || (ppid == 0)) {
 		return(lam_errfunc(comm,
-			lam_getfunc(), lam_mkerr(MPI_ERR_ARG, 0)));
+			lam_getfunc(), lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	grp = (LAM_IS_INTER(comm)) ? comm->c_rgroup : comm->c_group;
@@ -218,7 +198,7 @@ int MPIL_Comm_gps(MPI_Comm comm, int rank, int *pnid,
 	if ((rank == MPI_ANY_SOURCE) || (rank < 0) ||
 			(rank >= grp->g_nprocs)) {
 		return(lam_errfunc(comm,
-			lam_getfunc(), lam_mkerr(MPI_ERR_RANK, 0)));
+			lam_getfunc(), lam_mkerr(MPI_ERR_RANK, EINVAL)));
 	}
 
 	*pnid = grp->g_procs[rank]->p_gps.gps_node;
@@ -291,12 +271,12 @@ int MPIL_Type_id(MPI_Datatype dtype, int *ptid)
 
 	if (dtype == MPI_DATATYPE_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			lam_getfunc(), lam_mkerr(MPI_ERR_TYPE, 0)));
+			lam_getfunc(), lam_mkerr(MPI_ERR_TYPE, EINVAL)));
 	}
 
 	if (ptid == 0) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			lam_getfunc(), lam_mkerr(MPI_ERR_ARG, 0)));
+			lam_getfunc(), lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	*ptid = dtype->dt_label;
