@@ -48,6 +48,8 @@ completely apart from the signals provided by the underlying operating
 system.  LAM signals, defined in <lam_ksignal.h>, are listed below.
  
 .n LAM_SIGTRACE   1    unload trace data
+.n LAM_SIGC       2    user defined
+.n LAM_SIGARECV   3    async receive pending
 .n LAM_SIGUDIE    4    terminate
 .n LAM_SIGARREST  5    suspend execution
 .n LAM_SIGRELEASE 6    continue execution
@@ -62,7 +64,7 @@ conjunction with the 'LAM_MPI' C preprocessor macro
 
 .vb
   #if LAM_MPI
-     MPIL_Signal(MPI_COMM_WORLD, 0, SIGINT);
+     MPIL_Signal(MPI_COMM_WORLD, 0, LAM_SIGUDIE);
   #endif
 .ve
 
