@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	NJN
+ * $HEADER$
  *
- *	$Id: namelook.c,v 6.6.2.1 2002/10/09 19:49:11 brbarret Exp $
+ * $Id: namelook.c,v 6.9 2003/05/31 22:28:50 jsquyres Exp $
  *
  *	Function:	- get port name associated with service name
  *	Accepts:	- service name
@@ -30,6 +28,7 @@
 #include <blktype.h>
 #include <mpi.h>
 #include <mpisys.h>
+#include <etc_misc.h>
 
 
 /*@
@@ -79,7 +78,7 @@ MPI_Lookup_name(char *service_name, MPI_Info info, char *port_name)
  * Check arguments.
  */
 	if (port_name == 0 || service_name == 0) {
-		return(lam_err_comm(MPI_COMM_WORLD, MPI_ERR_ARG, 0, ""));
+		return(lam_err_comm(MPI_COMM_WORLD, MPI_ERR_ARG, EINVAL, ""));
 	}
 /*
  * Get port name.
@@ -88,7 +87,7 @@ MPI_Lookup_name(char *service_name, MPI_Info info, char *port_name)
 		return(lam_err_comm(MPI_COMM_WORLD, MPI_ERR_NAME, errno, "")); 
 	}
 
-	strncpy(port_name, port_buf, MPI_MAX_PORT_NAME);
+	lam_strncpy(port_name, port_buf, MPI_MAX_PORT_NAME);
 	free(port_buf);
 
         lam_resetfunc(BLKMPILOOKUPNAME);
