@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: opcreate.c,v 6.4.2.1 2002/10/09 19:49:12 brbarret Exp $
+ * $Id: opcreate.c,v 6.6 2002/12/11 19:15:13 jsquyres Exp $
  *
  *	Function:	- create a reduction operator
  *	Accepts:	- function
@@ -85,7 +83,7 @@ int MPI_Op_create(MPI_User_function func, int commute,
 	if ((pop == 0) || (func == 0)) {
 		class = (pop == 0) ? MPI_ERR_OP : MPI_ERR_ARG;
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPIOPCREATE, lam_mkerr(class, 0)));
+			BLKMPIOPCREATE, lam_mkerr(class, EINVAL)));
 	}
 
 	op = (MPI_Op) malloc(sizeof(struct _op));
