@@ -1,38 +1,18 @@
 /*
- * Copyright 1998-2001, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Arun Rodrigues, and Brian Barrett with
- *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ *                         All rights reserved.
+ * Copyright (c) 1998-2001 University of Notre Dame. 
+ *                         All rights reserved.
+ * Copyright (c) 1994-1998 The Ohio State University.  
+ *                         All rights reserved.
  * 
- * This file is part of the Notre Dame LAM implementation of MPI.
+ * This file is part of the LAM/MPI software package.  For license
+ * information, see the LICENSE file in the top level directory of the
+ * LAM/MPI source distribution.
  * 
- * You should have received a copy of the License Agreement for the Notre
- * Dame LAM implementation of MPI along with the software; see the file
- * LICENSE.  If not, contact Office of Research, University of Notre
- * Dame, Notre Dame, IN 46556.
- * 
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted subject to the conditions specified in the
- * LICENSE file.
- * 
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
- * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
- * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
- * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
- * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- * 
- * Additional copyrights may follow.
- * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: pack.c,v 6.4 1999/12/31 21:27:34 jsquyres Exp $
+ * $Id: pack.c,v 6.6 2002/12/11 19:15:13 jsquyres Exp $
  *
  *	Function:	- pack from data buffer
  *	Accepts:	- data buffer
@@ -94,32 +74,32 @@ int MPI_Pack(void *buf, int count, MPI_Datatype dtype,
  */
 	if (comm == MPI_COMM_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPIPACK, lam_mkerr(MPI_ERR_COMM, 0)));
+			BLKMPIPACK, lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
 
 	if (dtype == MPI_DATATYPE_NULL || (!dtype->dt_commit)) {
 		return(lam_errfunc(comm,
-			BLKMPIPACK, lam_mkerr(MPI_ERR_TYPE, 0)));
+			BLKMPIPACK, lam_mkerr(MPI_ERR_TYPE, EINVAL)));
 	}
 
 	if (count < 0) {
 		return(lam_errfunc(comm,
-			BLKMPIPACK, lam_mkerr(MPI_ERR_COUNT, 0)));
+			BLKMPIPACK, lam_mkerr(MPI_ERR_COUNT, EINVAL)));
 	}
 
 	if ((packsize < 0) || (packpos == 0)) {
 		return(lam_errfunc(comm,
-			BLKMPIPACK, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPIPACK, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	if ((*packpos < 0) || ((*packpos >= packsize) && (packsize > 0))) {
 		return(lam_errfunc(comm,
-			BLKMPIPACK, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPIPACK, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	if ((packsize > 0) && (packbuf == 0)) {
 		return(lam_errfunc(comm,
-			BLKMPIPACK, lam_mkerr(MPI_ERR_BUFFER, 0)));
+			BLKMPIPACK, lam_mkerr(MPI_ERR_BUFFER, EINVAL)));
 	}
 /*
  * Pack the data.
@@ -131,7 +111,7 @@ int MPI_Pack(void *buf, int count, MPI_Datatype dtype,
 
 	if (size < 0) {
 		return(lam_errfunc(comm,
-			BLKMPIPACK, lam_mkerr(MPI_ERR_TRUNCATE, 0)));
+			BLKMPIPACK, lam_mkerr(MPI_ERR_TRUNCATE, EIO)));
 	}
 
 	*packpos += size;
