@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2002 The Trustees of Indiana University.  
+ * Copyright (c) 2001-2003 The Trustees of Indiana University.  
  *                         All rights reserved.
  * Copyright (c) 1998-2001 University of Notre Dame. 
  *                         All rights reserved.
@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: recv.c,v 6.28 2003/02/20 19:57:13 jsquyres Exp $
+ * $Id: recv.c,v 6.29 2003/10/28 12:39:44 jsquyres Exp $
  *
  *	Function:	- receive a message
  *	Accepts:	- buffer
@@ -25,6 +25,8 @@
  *	Returns: 	- MPI_SUCCESS or error code
  */
 
+#include <errno.h>
+
 #include <blktype.h>
 #include <mpi.h>
 #include <mpisys.h>
@@ -154,27 +156,38 @@ int MPI_Recv(void *buf, int count, MPI_Datatype dtype,
 
 		if (src != MPI_ANY_SOURCE && (LAM_IS_INTER(comm)
 				|| src != comm->c_group->g_myrank)) {
+                  int seqnum;
 
-		        int seqnum;
+                  errno = 0;
+                  err = RPI_FASTRECV(buf, count, dtype, src, &tag, 
+                                     comm, stat, &seqnum);
 
-			err = RPI_FASTRECV(buf, count, dtype, src, &tag, 
-					   comm, stat, &seqnum);
+                  /* The RPI's "fast" methods may be temporarily
+                     unavailable.  If the "fast" method returns
+                     something other than MPI_SUCCESS, and errno ==
+                     EBUSY, then just fail gracefully over to the
+                     normal send.  In all other cases, handle the
+                     success/failure here. */
 
-			if (fl_trace) {
-			    finisht = MPI_Wtime();
+                  if (err == MPI_SUCCESS ||
+                      (err != MPI_SUCCESS && errno != EBUSY)) {
 
-			    lam_tr_msg(TRTINPUT, startt,
-				LAM_S2US(finisht - startt - _kio.ki_blktime),
-				LAM_S2US(_kio.ki_blktime), src, tag, comm,
-				dtype, count, src, tag, seqnum, LAM_RQIRECV);
-			}
+                    if (fl_trace) {
+                      finisht = MPI_Wtime();
 
-			if (err != MPI_SUCCESS)
-			  return lam_errfunc(comm, BLKMPIRECV, err);
+                      lam_tr_msg(TRTINPUT, startt,
+                                 LAM_S2US(finisht - startt - _kio.ki_blktime),
+                                 LAM_S2US(_kio.ki_blktime), src, tag, comm,
+                                 dtype, count, src, tag, seqnum, LAM_RQIRECV);
+                    }
 
-			lam_resetfunc_m(BLKMPIRECV);
-			return (MPI_SUCCESS);
-		}
+                    if (err != MPI_SUCCESS)
+                      return lam_errfunc(comm, BLKMPIRECV, err);
+
+                    lam_resetfunc_m(BLKMPIRECV);
+                    return (MPI_SUCCESS);
+                  }
+                }
 	}
 
 	LAM_ZERO_ME(req_storage);
