@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: reduce.c,v 6.12 2003/02/04 18:06:51 jsquyres Exp $
+ * $Id: reduce.c,v 6.14 2004/03/02 03:43:29 jsquyres Exp $
  *
  *	Function:	- reduce values to root
  *	Accepts:	- send buffer
@@ -98,31 +98,41 @@ int MPI_Reduce(void *sbuf, void* rbuf, int count,
 	  return(lam_errfunc(comm, BLKMPIREDUCE,
 			     lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
-	func = LAM_IS_INTER(comm) ?
-	  comm->c_ssi_coll.lsca_reduce_inter :
-	  comm->c_ssi_coll.lsca_reduce_intra;
+	func = comm->c_ssi_coll.lsca_reduce;
 
-	if (dtype == MPI_DATATYPE_NULL) {
-	  return(lam_errfunc(comm, BLKMPIREDUCE, 
-			     lam_mkerr(MPI_ERR_TYPE, EINVAL)));
+	if (LAM_IS_INTRA(comm)) {
+	  if (dtype == MPI_DATATYPE_NULL) {
+	    return(lam_errfunc(comm, BLKMPIREDUCE, 
+			       lam_mkerr(MPI_ERR_TYPE, EINVAL)));
+	  }
+	  MPI_Comm_size(comm, &size);
+	  if (count < 0) {
+	    return(lam_errfunc(comm, BLKMPIREDUCE,
+			       lam_mkerr(MPI_ERR_COUNT, EINVAL)));
+	  }
+	  if ((root < 0) || (root >= size)) {
+	    return(lam_errfunc(comm, BLKMPIREDUCE,
+			       lam_mkerr(MPI_ERR_ROOT, EINVAL)));
+	  }
+	  
+	  if (op == MPI_OP_NULL) {
+	    return(lam_errfunc(comm, BLKMPIREDUCE,
+			       lam_mkerr(MPI_ERR_OP, EINVAL)));
+	  }
+	} else {
+	  /* Conditions for intercommunicator */
+	  if ((op == MPI_OP_NULL || count < 0) && root != MPI_PROC_NULL) {
+	    return(lam_errfunc(comm, BLKMPIREDUCE,
+			       lam_mkerr(MPI_ERR_OP, EINVAL)));
+	  }
+
+	  MPI_Comm_remote_size(comm, &size);
+	  if (!(((root < size) && (root >= 0)) 
+		|| (root == MPI_ROOT) || (root == MPI_PROC_NULL))) {
+	    return(lam_errfunc(comm, BLKMPIGATHER, 
+			       lam_mkerr(MPI_ERR_ROOT, EINVAL)));
+	  }
 	}
-
-	if (count < 0) {
-	  return(lam_errfunc(comm, BLKMPIREDUCE,
-			     lam_mkerr(MPI_ERR_COUNT, EINVAL)));
-	}
-
-	MPI_Comm_size(comm, &size);
-	if ((root < 0) || (root >= size)) {
-	  return(lam_errfunc(comm, BLKMPIREDUCE,
-			     lam_mkerr(MPI_ERR_ROOT, EINVAL)));
-	}
-
-	if (op == MPI_OP_NULL) {
-	  return(lam_errfunc(comm, BLKMPIREDUCE,
-			     lam_mkerr(MPI_ERR_OP, EINVAL)));
-	}
-
 	if (func == NULL) {
 	  return(lam_errfunc(comm, BLKMPIREDUCE,
 			     lam_mkerr(MPI_ERR_OTHER, ENOT_IMPLEMENTED)));
@@ -132,10 +142,11 @@ int MPI_Reduce(void *sbuf, void* rbuf, int count,
 /*
  * Remember required parameters.
  */
-	p = &(comm->c_group->g_procs[root]->p_gps);
-	lam_setparam(BLKMPIREDUCE, root | (p->gps_grank << 16),
-				(p->gps_node << 16) | p->gps_idx);
-
+	if (LAM_IS_INTRA(comm)) {
+	  p = &(comm->c_group->g_procs[root]->p_gps);
+	  lam_setparam(BLKMPIREDUCE, root | (p->gps_grank << 16),
+		       (p->gps_node << 16) | p->gps_idx);
+	}
 /*
  * Check for zero count case.
  */
