@@ -12,7 +12,7 @@
  * 
  * $HEADER$
  *
- * $Id: reducescatter.c,v 6.10 2003/05/29 16:31:55 jsquyres Exp $
+ * $Id: reducescatter.c,v 6.12 2004/03/02 03:43:29 jsquyres Exp $
  *
  *	Function:	- reduce and scatter data to all processes
  *	Accepts:	- send buffer
@@ -84,9 +84,7 @@ int MPI_Reduce_scatter(void *sbuf, void *rbuf, int *rcounts,
 	  return (lam_errfunc(comm, BLKMPIREDUCESCATTER,
 			      lam_mkerr(MPI_ERR_COMM, EINVAL)));
 	}
-	func = LAM_IS_INTER(comm) ?
-	  comm->c_ssi_coll.lsca_reduce_scatter_inter :
-	  comm->c_ssi_coll.lsca_reduce_scatter_intra;
+	func = comm->c_ssi_coll.lsca_reduce_scatter;
 
 	if (dtype == MPI_DATATYPE_NULL) {
 	  return(lam_errfunc(comm, BLKMPIREDUCESCATTER,
