@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1996 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: reqfree.c,v 6.4.2.1 2002/10/09 19:49:12 brbarret Exp $
+ * $Id: reqfree.c,v 6.6 2002/12/11 19:15:13 jsquyres Exp $
  *
  *	Function:	- free communication request
  *	Accepts:	- ptr to request
@@ -80,12 +78,12 @@ int MPI_Request_free(MPI_Request *preq)
  */
 	if (preq == 0) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPIREQFREE, lam_mkerr(MPI_ERR_ARG, 0)));
+			BLKMPIREQFREE, lam_mkerr(MPI_ERR_ARG, EINVAL)));
 	}
 
 	if ((req = *preq) == MPI_REQUEST_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPIREQFREE, lam_mkerr(MPI_ERR_REQUEST, 0)));
+			BLKMPIREQFREE, lam_mkerr(MPI_ERR_REQUEST, EINVAL)));
 	}
 /*
  * Destroy all the shadows
