@@ -10,11 +10,9 @@
  * information, see the LICENSE file in the top level directory of the
  * LAM/MPI source distribution.
  * 
- *	Ohio Trollius
- *	Copyright 1997 The Ohio State University
- *	RBD
+ * $HEADER$
  *
- *	$Id: rsend.c,v 6.4.2.1 2002/10/09 19:49:12 brbarret Exp $
+ * $Id: rsend.c,v 6.7 2003/02/20 19:57:13 jsquyres Exp $
  *
  *	Function:	- ready-mode send
  *	Accepts:	- buffer
@@ -62,9 +60,9 @@ int MPI_Rsend(void *buf, int count, MPI_Datatype dtype,
 	lam_initerr_m();
 	lam_setfunc_m(BLKMPIRSEND);
 
-	if (tag < 0 || tag > LAM_MAXTAG) {
+	if (tag < 0 || tag > lam_mpi_max_tag) {
 		return(lam_errfunc(comm, BLKMPIRSEND,
-				lam_mkerr(MPI_ERR_TAG, 0)));
+				lam_mkerr(MPI_ERR_TAG, EINVAL)));
 	}
 
 	err = lam_send(buf, count, dtype, dest, tag, comm, LAM_RQIRSEND);
